@@ -157,7 +157,7 @@ EngineController::initializePhonon()
 
     // HACK we turn off replaygain manually on OSX, until the phonon coreaudio backend is fixed.
     // as the default is specified in the .cfg file, we can't just tell it to be a different default on OSX
-#ifdef Q_WS_MAC
+#ifdef Q_OS_APPLE
     AmarokConfig::setReplayGainMode( AmarokConfig::EnumReplayGainMode::Off );
     AmarokConfig::setFadeoutOnStop( false );
 #endif
@@ -566,8 +566,11 @@ EngineController::stop( bool forceInstant, bool playingWillContinue ) //SLOT
     }
     else
     {
+        // empty MediaSource() seems to cause Phonon-VLC to emit a volume of 0, BR 442319, so ignore it
+        m_ignoreVolumeChangeObserve = true;
         m_media->stop();
         m_media->setCurrentSource( Phonon::MediaSource() );
+        QTimer::singleShot( 0, [this]() { m_ignoreVolumeChangeObserve = false; } );
     }
 }
 
