@@ -94,16 +94,12 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardAction>
+#include <KWindowInfo>
 #include <KWindowSystem>
 
 #include <iostream>
 
-#ifdef Q_WS_X11
-#include <fixx11h.h>
-#include <KConfigGroup>
-#endif
-
-#ifdef Q_WS_MAC
+#ifdef Q_OS_APPLE
 #include "mac/GrowlInterface.h"
 #ifdef HAVE_NOTIFICATION_CENTER
 #include "mac/MacSystemNotify.h"
@@ -123,12 +119,13 @@ MainWindow::MainWindow()
     , m_showMenuBar( nullptr )
     , m_lastBrowser( 0 )
     , m_waitingForCd( false )
+    , m_expensiveDrawingPaused( false )
 {
     DEBUG_BLOCK
 
     setObjectName( "MainWindow" );
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_APPLE
     (void)new GrowlInterface( qApp->applicationName() );
 #ifdef HAVE_NOTIFICATION_CENTER
     (void)new OSXNotify( qApp->applicationName() );
@@ -171,6 +168,13 @@ MainWindow::MainWindow()
     connect( engine, &EngineController::paused, this, &MainWindow::slotPaused );
     connect( engine, &EngineController::trackPlaying, this, &MainWindow::slotNewTrackPlaying );
     connect( engine, &EngineController::trackMetadataChanged, this, &MainWindow::slotMetadataChanged );
+
+    connect( KWindowSystem::self(), &KWindowSystem::currentDesktopChanged, this, &MainWindow::checkIfExpensivesShouldBeDrawn );
+    connect( KWindowSystem::self(), qOverload<WId, NET::Properties, NET::Properties2>(&KWindowSystem::windowChanged),
+             [this](WId id, NET::Properties prop, NET::Properties2 ) {
+                 if ( id == winId() && ( prop & NET::WMDesktop || prop & NET::WMState || prop & NET::XAWMState ) )
+                     checkIfExpensivesShouldBeDrawn();
+            } );
 }
 
 MainWindow::~MainWindow()
@@ -411,7 +415,7 @@ MainWindow::showDock( AmarokDockId dockId )
 void
 MainWindow::closeEvent( QCloseEvent *e )
 {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_APPLE
     Q_UNUSED( e );
     hide();
 #else
@@ -714,8 +718,7 @@ void MainWindow::slotPutCurrentTrackToClipboard()
 void
 MainWindow::activate()
 {
-#ifdef Q_WS_X11
-    const KWindowInfo info = KWindowSystem::windowInfo( winId(), 0, 0 );
+    const KWindowInfo info( winId(), NET::WMState | NET::XAWMState | NET::WMDesktop );
 
     if( KWindowSystem::activeWindow() != winId() )
         setVisible( true );
@@ -723,9 +726,6 @@ MainWindow::activate()
         setVisible( true );
     if( !isHidden() )
         KWindowSystem::activateWindow( winId() );
-#else
-    setVisible( true );
-#endif
 }
 
 void
@@ -1062,7 +1062,7 @@ MainWindow::createMenus()
 
     //BEGIN Actions menu
     QMenu *actionsMenu = new QMenu( m_menubar );
-#ifdef Q_WS_MAC
+#ifdef Q_OS_APPLE
     // Add these functions to the dock icon menu in OS X
     //extern void qt_mac_set_dock_menu(QMenu *);
     //qt_mac_set_dock_menu(actionsMenu);
@@ -1080,7 +1080,7 @@ MainWindow::createMenus()
     actionsMenu->addAction( Amarok::actionCollection()->action("next") );
 
 
-#ifndef Q_WS_MAC    // Avoid duplicate "Quit" in OS X dock menu
+#ifndef Q_OS_APPLE    // Avoid duplicate "Quit" in OS X dock menu
     actionsMenu->addSeparator();
     actionsMenu->addAction( Amarok::actionCollection()->action( KStandardAction::name( KStandardAction::Quit ) ) );
 #endif
@@ -1136,7 +1136,7 @@ MainWindow::createMenus()
     // stops at about 5:40. while we get this resolved upstream, don't make playing amarok such on osx.
     // so we disable replaygain on osx
 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_APPLE
     m_settingsMenu->addAction( Amarok::actionCollection()->action("replay_gain_mode") );
     m_settingsMenu->addSeparator();
 #endif
@@ -1379,14 +1379,22 @@ MainWindow::isWaitingForCd() const
     return m_waitingForCd;
 }
 
-bool
-MainWindow::isOnCurrentDesktop() const
+void
+MainWindow::checkIfExpensivesShouldBeDrawn()
 {
-#ifdef Q_WS_X11
-    return KWindowSystem::windowInfo( winId(), NET::WMDesktop ).desktop() == KWindowSystem::currentDesktop();
-#else
-    return true;
-#endif
+    const KWindowInfo info( winId(), NET::WMState | NET::XAWMState | NET::WMDesktop );
+
+    bool newNeed = true;
+    if( !info.isOnCurrentDesktop() )
+        newNeed = false;
+    else if( info.isMinimized() )
+        newNeed = false;
+    if ( newNeed != m_expensiveDrawingPaused )
+    {
+        debug() << "need to draw expensive elements changed, new state"<< newNeed;
+        m_expensiveDrawingPaused = newNeed;
+        Q_EMIT drawNeedChanged( newNeed );
+    }
 }
 
 
