@@ -21,27 +21,24 @@
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 
-#include <KConfigGroup>
-#include <solid/device.h>
-#include <solid/deviceinterface.h>
-#include <solid/devicenotifier.h>
-#include <solid/genericinterface.h>
-#include <solid/opticaldisc.h>
-#include <solid/portablemediaplayer.h>
-#include <solid/storageaccess.h>
-#include <solid/storagedrive.h>
-#include <solid/block.h>
-#include <solid/storagevolume.h>
-
-#include <kdeversion.h>
-
-#include <kmountpoint.h>
+#include <Solid/Block>
+#include <Solid/Device>
+#include <Solid/DeviceInterface>
+#include <Solid/DeviceNotifier>
+#include <Solid/GenericInterface>
+#include <Solid/OpticalDisc>
+#include <Solid/PortableMediaPlayer>
+#include <Solid/StorageAccess>
+#include <Solid/StorageDrive>
+#include <Solid/StorageVolume>
 
 #include <QDir>
 #include <QFile>
 #include <QList>
 
-MediaDeviceCache* MediaDeviceCache::s_instance = 0;
+#include <KConfigGroup>
+
+MediaDeviceCache* MediaDeviceCache::s_instance = nullptr;
 
 MediaDeviceCache::MediaDeviceCache() : QObject()
                              , m_type()
@@ -50,15 +47,15 @@ MediaDeviceCache::MediaDeviceCache() : QObject()
 {
     DEBUG_BLOCK
     s_instance = this;
-    connect( Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)),
-             this, SLOT(slotAddSolidDevice(QString)) );
-    connect( Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)),
-             this, SLOT(slotRemoveSolidDevice(QString)) );
+    connect( Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceAdded,
+             this, &MediaDeviceCache::slotAddSolidDevice );
+    connect( Solid::DeviceNotifier::instance(), &Solid::DeviceNotifier::deviceRemoved,
+             this, &MediaDeviceCache::slotRemoveSolidDevice );
 }
 
 MediaDeviceCache::~MediaDeviceCache()
 {
-    s_instance = 0;
+    s_instance = nullptr;
 }
 
 void
@@ -92,8 +89,8 @@ MediaDeviceCache::refreshCache()
         {
             if( !m_volumes.contains( device.udi() ) )
             {
-                connect( ssa, SIGNAL(accessibilityChanged(bool,QString)),
-                    this, SLOT(slotAccessibilityChanged(bool,QString)) );
+                connect( ssa, &Solid::StorageAccess::accessibilityChanged,
+                    this, &MediaDeviceCache::slotAccessibilityChanged );
                 m_volumes.append( device.udi() );
             }
             if( ssa->isAccessible() )
@@ -171,8 +168,8 @@ MediaDeviceCache::slotAddSolidDevice( const QString &udi )
         debug() << "volume is generic storage";
         if( !m_volumes.contains( device.udi() ) )
         {
-            connect( ssa, SIGNAL(accessibilityChanged(bool,QString)),
-                this, SLOT(slotAccessibilityChanged(bool,QString)) );
+            connect( ssa, &Solid::StorageAccess::accessibilityChanged,
+                this, &MediaDeviceCache::slotAccessibilityChanged );
             m_volumes.append( device.udi() );
         }
         if( ssa->isAccessible() )
@@ -224,7 +221,7 @@ MediaDeviceCache::slotAddSolidDevice( const QString &udi )
             }
         }
 
-        debug() << "udi" << udi << "is AFC cabable (Apple mobile device)";
+        debug() << "udi" << udi << "is AFC capable (Apple mobile device)";
         m_type[udi] = MediaDeviceCache::SolidGenericType;
         m_name[udi] = device.vendor() + " - " + device.product();
     }
@@ -233,7 +230,7 @@ MediaDeviceCache::slotAddSolidDevice( const QString &udi )
         debug() << "udi " << udi << " does not describe a portable media player or storage volume";
         return;
     }
-    emit deviceAdded( udi );
+    Q_EMIT deviceAdded( udi );
 }
 
 void
@@ -244,20 +241,20 @@ MediaDeviceCache::slotRemoveSolidDevice( const QString &udi )
     Solid::Device device( udi );
     if( m_volumes.contains( udi ) )
     {
-        disconnect( device.as<Solid::StorageAccess>(), SIGNAL(accessibilityChanged(bool,QString)),
-                    this, SLOT(slotAccessibilityChanged(bool,QString)) );
+        disconnect( device.as<Solid::StorageAccess>(), &Solid::StorageAccess::accessibilityChanged,
+                    this, &MediaDeviceCache::slotAccessibilityChanged );
         m_volumes.removeAll( udi );
-        emit deviceRemoved( udi );
+        Q_EMIT deviceRemoved( udi );
     }
     if( m_type.contains( udi ) )
     {
         m_type.remove( udi );
         m_name.remove( udi );
-        emit deviceRemoved( udi );
+        Q_EMIT deviceRemoved( udi );
         return;
     }
     debug() << "Odd, got a deviceRemoved at udi " << udi << " but it did not seem to exist in the first place...";
-    emit deviceRemoved( udi );
+    Q_EMIT deviceRemoved( udi );
 }
 
 void
@@ -271,7 +268,7 @@ MediaDeviceCache::slotAccessibilityChanged( bool accessible, const QString &udi
         Solid::StorageAccess *ssa = device.as<Solid::StorageAccess>();
         if( ssa )
             m_name[udi] = ssa->filePath();
-        emit deviceAdded( udi );
+        Q_EMIT deviceAdded( udi );
         return;
     }
     else
@@ -280,13 +277,13 @@ MediaDeviceCache::slotAccessibilityChanged( bool accessible, const QString &udi
         {
             m_type.remove( udi );
             m_name.remove( udi );
-            emit deviceRemoved( udi );
+            Q_EMIT deviceRemoved( udi );
             return;
         }
         debug() << "Got accessibility changed to false but was not there in the first place...";
     }
 
-    emit accessibilityChanged( accessible, udi );
+    Q_EMIT accessibilityChanged( accessible, udi );
 }
 
 MediaDeviceCache::DeviceType
@@ -352,7 +349,7 @@ MediaDeviceCache::isGenericEnabled( const QString &udi ) const
         debug() << "Could convert parent to PortableMediaPlayer, returning true";
         return true;
     }
-    if( QFile::exists( ssa->filePath() + QDir::separator() + ".is_audio_player" ) )
+    if( QFile::exists( ssa->filePath() + QLatin1Char('/') + ".is_audio_player" ) )
     {
         return true;
     }
@@ -373,5 +370,4 @@ MediaDeviceCache::volumeMountPoint( const QString &udi ) const
     return ssa->filePath();
 }
 
-#include "MediaDeviceCache.moc"
 
