@@ -31,11 +31,7 @@ IpodCollectionFactory.
 #ifndef AMAROK_MEDIADEVICEMONITOR_H
 #define AMAROK_MEDIADEVICEMONITOR_H
 
-//#include "MediaDeviceInfo.h"
-
 #include "amarok_export.h"
-#include "core-impl/collections/mediadevicecollection/support/ConnectionAssistant.h"
-#include "core/support/Debug.h"
 
 #include <QHash>
 #include <QList>
@@ -55,7 +51,7 @@ class AMAROK_EXPORT MediaDeviceMonitor : public QObject
     static MediaDeviceMonitor* instance() { return s_instance ? s_instance : new MediaDeviceMonitor(); }
 
     MediaDeviceMonitor();
-    ~MediaDeviceMonitor();
+    ~MediaDeviceMonitor() override;
 
     void init(); // connect to MediaDeviceCache
 
@@ -76,18 +72,18 @@ class AMAROK_EXPORT MediaDeviceMonitor : public QObject
     */
     void registerDeviceType( ConnectionAssistant *assistant );
 
-    public slots:
+    public Q_SLOTS:
 
     /**
 
-    checkDevice checks if @param udi is a known device
+    checkDevice checks if @p udi is a known device
     and if so attempts to connect it
 
     checkOneDevice runs an identify check using the given
     assistant and udi
 
     checkDevicesFor checks if the device type described
-    by @param assistant matches any of the udi's in the
+    by @p assistant matches any of the udi's in the
     MediaDeviceCache, and if so, attempts to connect to
     it
 
@@ -98,12 +94,12 @@ class AMAROK_EXPORT MediaDeviceMonitor : public QObject
     void checkDevicesFor( ConnectionAssistant* assistant );
 
 
-    signals:
+    Q_SIGNALS:
         void deviceDetected( const MediaDeviceInfo &deviceinfo );
         void deviceRemoved( const QString &udi );
 
 
-    private slots:
+    private Q_SLOTS:
 
         void deviceAdded( const QString &udi );
         void slotDeviceRemoved( const QString &udi );
