@@ -18,16 +18,19 @@
 #define AMAROK_PLUGINMANAGER_H
 
 #include "amarok_export.h"
-#include "core/support/PluginFactory.h"
 
-class ServicePluginManager;
+#include <KPluginInfo>
+#include <KPluginMetaData>
+
+#include <QVector>
 
 namespace Plugins {
 
+class PluginFactory;
+
 class AMAROK_EXPORT PluginManager : public QObject
 {
     Q_OBJECT
-    Q_ENUMS( Type )
     Q_PROPERTY( int pluginFrameworkVersion READ pluginFrameworkVersion )
 
     public:
@@ -39,11 +42,12 @@ class AMAROK_EXPORT PluginManager : public QObject
         {
             Collection = 1, ///< the plugin implements a CollectionFactory
             Service = 2,    ///< this is a service plugin
-            Importer = 3,   ///< this plugin implements importer functionity
-            Storage = 4     ///< the plugin implements a StorageFactory
+            Importer = 3,   ///< this plugin implements importer functionality
+            Storage = 4,    ///< the plugin implements a StorageFactory
         };
+        Q_ENUM( Type )
 
-        ~PluginManager();
+        ~PluginManager() override;
 
         static PluginManager *instance();
 
@@ -62,17 +66,15 @@ class AMAROK_EXPORT PluginManager : public QObject
          */
         void init();
 
-        /** Returns plugin factories for the given plugin type */
-        KPluginInfo::List plugins( Type type ) const;
-
         /** Returns enabled plugin factories for the given plugin type.
          *
-         *  This function will only return enable factories.
-         *
-         *  Owner of the PluginFactory pointers is the PluginManager
-         *  and the pointers will only be valid while the PluginManager exists.
+         *  This function will only return factories for enabled plugins.
          */
-        QList<PluginFactory*> factories( Type type ) const;
+        QList<QSharedPointer<PluginFactory> > factories( Type type ) const;
+
+        KPluginInfo::List plugins( Type type ) const;
+
+        QVector<KPluginMetaData> enabledPlugins(Type type ) const;
 
         /** Check if any services were disabled and needs to be removed, or any
          *  that are hidden needs to be enabled
@@ -84,36 +86,29 @@ class AMAROK_EXPORT PluginManager : public QObject
 
     private:
         /** Tries finding Amarok plugins */
-        KPluginInfo::List findPlugins();
-
-        /** Does additional effort to find plugins.
-         *
-         *  Starts kbuildsycoca4 thingie
-         *  Stops Amarok if it still can't find plugins
-         */
-        void handleNoPluginsFound();
+        QVector<KPluginMetaData> findPlugins();
 
         /** Returns true if the plugin is enabled.
-         *  This function will theck the default enabled state,
+         *  This function will check the default enabled state,
          *  the Amarok configuration state and the primary collection.
          *
          *  @returns true if the plugin is enabled.
          */
-        bool isPluginEnabled( const KPluginInfo &factory ) const;
+        bool isPluginEnabled( const KPluginMetaData &plugin ) const;
 
-        /** Creates a factories for an info */
-        PluginFactory* createFactory( const KPluginInfo &plugin );
+        /** Creates a factories for a plugin */
+        QSharedPointer<PluginFactory> createFactory( const KPluginMetaData &pluginInfo );
 
         /// contains the names of all KPluginInfos that have factories created
-        QHash<QString, PluginFactory*> m_factoryCreated;
-        QHash<Type, QList<PluginFactory*> > m_factoriesByType;
-        KPluginInfo::List m_pluginInfos;
-        QHash<Type, KPluginInfo::List > m_pluginInfosByType;
+        QVector<KPluginMetaData> m_plugins;
+        QHash<Type, QList<KPluginMetaData> > m_pluginsByType;
+        QHash<Type, QList<QSharedPointer<PluginFactory> > > m_factoriesByType;
+        QHash<QString, QSharedPointer<PluginFactory>> m_factoryCreated;
 
         static const int s_pluginFrameworkVersion;
         static PluginManager *s_instance;
 
-        PluginManager( QObject *parent = 0 );
+        explicit PluginManager( QObject *parent = nullptr );
 };
 
 } // namespace Plugins
