@@ -358,68 +358,6 @@ QPixmap SvgHandler::addBordersToPixmap( const QPixmap &orgPixmap, int borderWidt
     return pixmap;
 }
 
-#if 0
-void SvgHandler::paintCustomSlider( QPainter *p, int x, int y, int width, int height, qreal percentage, bool active )
-{
-    int knobSize = height - 4;
-    int sliderRange = width - ( knobSize + 4 );
-    int knobRelPos = x + sliderRange * percentage + 2;
-    int knobY = y + ( height - knobSize ) / 2 + 1;
-
-    int sliderY = y + ( height / 2 ) - 1;
-
-
-    //first draw the played part
-    p->drawPixmap( x, sliderY,
-                   renderSvg(
-                   "new_slider_top_played",
-                   width, 2,
-                   "new_slider_top_played" ),
-                   0, 0, knobRelPos - x, 2 );
-
-    //and then the unplayed part
-    p->drawPixmap( knobRelPos + 1, sliderY,
-                   renderSvg(
-                   "new_slider_top",
-                   width, 2,
-                   "new_slider_top" ),
-                   knobRelPos + 1 - x, 0, -1, 2 );
-
-    //and then the bottom
-    p->drawPixmap( x, sliderY + 2,
-                   renderSvg(
-                   "new_slider_bottom",
-                   width, 2,
-                   "new_slider_bottom" ) );
-
-    //draw end markers
-    p->drawPixmap( x, y,
-                   renderSvg(
-                   "new_slider_end",
-                   2, height,
-                   "new_slider_end" ) );
-
-    p->drawPixmap( x + width - 2, y,
-                   renderSvg(
-                   "new_slider_end",
-                   2, height,
-                   "new_slider_endr" ) );
-
-
-    if ( active )
-        p->drawPixmap( knobRelPos, knobY,
-                       renderSvg(
-                       "new_slider_knob_active",
-                       knobSize, knobSize,
-                       "new_slider_knob_active" ) );
-    else
-        p->drawPixmap( knobRelPos, knobY,
-                       renderSvg(
-                       "new_slider_knob",
-                       knobSize, knobSize,
-                       "new_slider_knob" ) );
-}
-#endif
 
 QRect SvgHandler::sliderKnobRect( const QRect &slider, qreal percent, bool inverse ) const
 {
