@@ -18,7 +18,7 @@
 #define BOOKMARKMETAACTIONS_H
 
 #include "amarok_export.h"
-#include "meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 
 #include <QAction>
 
@@ -28,9 +28,9 @@ class AMAROK_EXPORT BookmarkAlbumAction : public QAction
     Q_OBJECT
 
 public:
-    BookmarkAlbumAction( QObject *parent, Meta::AlbumPtr album );
+    BookmarkAlbumAction( QObject *parent, const Meta::AlbumPtr &album );
 
-    private slots:
+    private Q_SLOTS:
         void slotTriggered();
 
     private:
@@ -43,9 +43,9 @@ class AMAROK_EXPORT BookmarkArtistAction : public QAction
     Q_OBJECT
 
     public:
-        BookmarkArtistAction( QObject *parent, Meta::ArtistPtr artist );
+        BookmarkArtistAction( QObject *parent, const Meta::ArtistPtr &artist );
 
-    private slots:
+    private Q_SLOTS:
         void slotTriggered();
 
     private:
@@ -60,7 +60,7 @@ class AMAROK_EXPORT BookmarkCurrentTrackPositionAction : public QAction
     public:
         explicit BookmarkCurrentTrackPositionAction( QObject *parent );
 
-    private slots:
+    private Q_SLOTS:
         void slotTriggered();
 };
 
