@@ -25,7 +25,7 @@
 #include <core-impl/storage/StorageManager.h>
 #include <core/storage/SqlStorage.h>
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QAbstractListModel>
 #include <QListIterator>
@@ -33,13 +33,13 @@
 #include <typeinfo>
 
 static const int BOOKMARK_DB_VERSION = 4;
-static const QString key("AMAROK_BOOKMARKS");
+static const QString key(QStringLiteral("AMAROK_BOOKMARKS"));
 
-BookmarkModel * BookmarkModel::s_instance = 0;
+BookmarkModel * BookmarkModel::s_instance = nullptr;
 
 BookmarkModel * BookmarkModel::instance()
 {
-    if ( s_instance == 0 )
+    if ( s_instance == nullptr )
         s_instance = new BookmarkModel();
 
     return s_instance;
@@ -51,7 +51,7 @@ BookmarkModel::BookmarkModel()
 {
     checkTables();
 
-    m_root = BookmarkGroupPtr( new BookmarkGroup( "root", BookmarkGroupPtr() ) );
+    m_root = BookmarkGroupPtr( new BookmarkGroup( QStringLiteral("root"), BookmarkGroupPtr() ) );
 }
 
 
@@ -108,13 +108,10 @@ BookmarkModel::data( const QModelIndex & index, int role ) const
     {
         if( index.column() == Name )
         {
-            if ( typeid( * item ) == typeid( BookmarkGroup ) )
-                return QVariant( KIcon( "folder-bookmark" ) );
-            else if ( typeid( * item ) == typeid( AmarokUrl ) )
-            {
-                AmarokUrl * url = static_cast<AmarokUrl *>( item.data() );
+            if ( BookmarkGroupPtr::dynamicCast( item ) )
+                return QVariant( QIcon::fromTheme( QStringLiteral("folder-bookmark") ) );
+            else if ( auto url = AmarokUrlPtr::dynamicCast( item ) )
                 return The::amarokUrlHandler()->iconForCommand( url->command() );
-            }
         }
     }
 
@@ -236,7 +233,7 @@ BookmarkModel::flags( const QModelIndex & index ) const
         return Qt::ItemIsEnabled | Qt::ItemIsDropEnabled;
     BookmarkViewItemPtr item = BookmarkViewItemPtr::staticCast( m_viewItems.value( index.internalId() ) );
 
-    if ( typeid( * item ) == typeid( BookmarkGroup ) )
+    if ( BookmarkGroupPtr::dynamicCast( item ) )
     {
         if ( index.column() != Command )
             return Qt::ItemIsEditable | Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDropEnabled | Qt::ItemIsDragEnabled;
@@ -282,7 +279,7 @@ bool BookmarkModel::setData( const QModelIndex & index, const QVariant & value,
     {
         case Name:
             item->rename( value.toString() );
-            emit dataChanged( index, index );
+            Q_EMIT dataChanged( index, index );
             break;
         case Url:
         {
@@ -293,7 +290,7 @@ bool BookmarkModel::setData( const QModelIndex & index, const QVariant & value,
                 url->initFromString( value.toString() );
                 url->saveToDb();
 
-                emit dataChanged( index, index );
+                Q_EMIT dataChanged( index, index );
             }
             break;
         }
@@ -305,7 +302,7 @@ bool BookmarkModel::setData( const QModelIndex & index, const QVariant & value,
             if ( url )
             {
                 url->saveToDb();
-                emit dataChanged( index, index );
+                Q_EMIT dataChanged( index, index );
             }
 
             break;
@@ -338,16 +335,10 @@ BookmarkModel::mimeData( const QModelIndexList &indexes ) const
 
         BookmarkViewItemPtr item = m_viewItems.value( index.internalId() );
 
-        if ( typeid( * item ) == typeid( BookmarkGroup ) ) {
-            BookmarkGroupPtr playlistGroup = BookmarkGroupPtr::staticCast( item );
-            groups << playlistGroup;
-        }
-        else
-        {
-            AmarokUrlPtr bookmark = AmarokUrlPtr::dynamicCast( item );
-            if( bookmark )
-                bookmarks << bookmark;
-        }
+        if ( auto group = BookmarkGroupPtr::dynamicCast( item ) )
+            groups << group;
+        else if( auto bookmark = AmarokUrlPtr::dynamicCast( item ) )
+            bookmarks << bookmark;
     }
 
     debug() << "adding " << groups.count() << " groups and " << bookmarks.count() << " bookmarks";
@@ -424,7 +415,7 @@ void BookmarkModel::createTables()
 {
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     if( !sqlStorage )
         return;
 
@@ -450,12 +441,12 @@ void BookmarkModel::deleteTables()
 
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     if( !sqlStorage )
         return;
 
-    sqlStorage->query( "DROP TABLE IF EXISTS bookmark_groups;" );
-    sqlStorage->query( "DROP TABLE IF EXISTS bookmarks;" );
+    sqlStorage->query( QStringLiteral("DROP TABLE IF EXISTS bookmark_groups;") );
+    sqlStorage->query( QStringLiteral("DROP TABLE IF EXISTS bookmarks;") );
 
 }
 
@@ -464,14 +455,14 @@ void BookmarkModel::checkTables()
 
     DEBUG_BLOCK
 
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     if( !sqlStorage )
         return;
 
-    QStringList values = sqlStorage->query( QString("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
+    QStringList values = sqlStorage->query( QStringLiteral("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
 
     //also check if the db  version is correct but the table is simply missing... can happen due to a bug in 2.2.0 beta1 and beta2
-    QStringList values2 = sqlStorage->query( "show tables like 'bookmarks';");
+    QStringList values2 = sqlStorage->query( QStringLiteral("show tables like 'bookmarks';"));
     
     if( values.isEmpty() || values2.isEmpty() )
     {
@@ -491,8 +482,10 @@ void
 BookmarkModel::reloadFromDb()
 {
     DEBUG_BLOCK;
+
+    beginResetModel();
     m_root->clear();
-    reset();
+    endResetModel();
 
 }
 
@@ -505,7 +498,7 @@ BookmarkModel::editBookmark( int id )
     foreach ( AmarokUrlPtr bookmark, m_root->childBookmarks() ) {
         row++;
         if ( bookmark->id() == id ) {
-            emit editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( bookmark ) ) );
+            Q_EMIT editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( bookmark ) ) );
         }
     }
 }
@@ -527,7 +520,7 @@ BookmarkModel::createNewGroup()
         if ( childGroup->id() == id )
         {
             debug() << "emitting edit for " << childGroup->name() << " id " << childGroup->id() << " in row " << row;
-            emit editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( childGroup ) ) );
+            Q_EMIT editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( childGroup ) ) );
         }
         row++;
     }
@@ -554,7 +547,7 @@ BookmarkModel::createNewBookmark()
         if ( childBookmark->id() == id )
         {
             debug() << "emitting edit for " << childBookmark->name() << " id " << childBookmark->id() << " in row " << row;
-            emit editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( childBookmark ) ) );
+            Q_EMIT editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( childBookmark ) ) );
         }
         row++;
     }
@@ -687,7 +680,7 @@ BookmarkModel::renameBookmarkRecursively( BookmarkGroupPtr group, const QString&
 
 void BookmarkModel::upgradeTables( int from )
 {
-    SqlStorage *sqlStorage = StorageManager::instance()->sqlStorage();
+    auto sqlStorage = StorageManager::instance()->sqlStorage();
     if( !sqlStorage )
         return;
     
@@ -702,4 +695,3 @@ void BookmarkModel::upgradeTables( int from )
 
 
 
-#include "BookmarkModel.moc"
