@@ -24,13 +24,13 @@
 #include "EngineController.h"
 #include "BookmarkModel.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
-PlayUrlGenerator * PlayUrlGenerator::s_instance = 0;
+PlayUrlGenerator * PlayUrlGenerator::s_instance = nullptr;
 
 PlayUrlGenerator * PlayUrlGenerator::instance()
 {
-    if( s_instance == 0)
+    if( s_instance == nullptr)
         s_instance = new PlayUrlGenerator();
 
     return s_instance;
@@ -56,7 +56,7 @@ PlayUrlGenerator::createCurrentTrackBookmark()
 }
 
 AmarokUrl
-PlayUrlGenerator::createTrackBookmark( Meta::TrackPtr track, qint64 miliseconds, QString name )
+PlayUrlGenerator::createTrackBookmark( Meta::TrackPtr track, qint64 miliseconds, const QString &name )
 {
     DEBUG_BLOCK
 
@@ -69,9 +69,9 @@ PlayUrlGenerator::createTrackBookmark( Meta::TrackPtr track, qint64 miliseconds,
         return url;
 
     const QString trackUrl = track->playableUrl().toEncoded().toBase64();
-    url.setCommand( "play" );
+    url.setCommand( QStringLiteral("play") );
     url.setPath( trackUrl );
-    url.setArg( "pos", secondsString );
+    url.setArg( QStringLiteral("pos"), secondsString );
 
     if( name.isEmpty() )
         url.setName( track->prettyName() + " - " + Meta::secToPrettyTime( seconds ) );
@@ -84,7 +84,7 @@ PlayUrlGenerator::createTrackBookmark( Meta::TrackPtr track, qint64 miliseconds,
 }
 
 void
-PlayUrlGenerator::moveTrackBookmark( Meta::TrackPtr track, qint64 newMiliseconds, QString name )
+PlayUrlGenerator::moveTrackBookmark( Meta::TrackPtr track, qint64 newMiliseconds, const QString &name )
 {
     qreal seconds = qreal ( newMiliseconds ) / 1000;
     QString trackPosition;
@@ -93,7 +93,7 @@ PlayUrlGenerator::moveTrackBookmark( Meta::TrackPtr track, qint64 newMiliseconds
     QString trackName = track->prettyName();
     QString newName = ( trackName + " - " + Meta::msToPrettyTime( newMiliseconds ) );
 
-    BookmarkModel::instance()->setBookmarkArg( name, "pos", trackPosition );
+    BookmarkModel::instance()->setBookmarkArg( name, QStringLiteral("pos"), trackPosition );
     BookmarkModel::instance()->renameBookmark( name, newName );
 }
 
@@ -103,9 +103,9 @@ PlayUrlGenerator::description()
     return i18n( "Bookmark Track Position" );
 }
 
-KIcon PlayUrlGenerator::icon()
+QIcon PlayUrlGenerator::icon()
 {
-    return KIcon( "x-media-podcast-amarok" );
+    return QIcon::fromTheme( QStringLiteral("x-media-podcast-amarok") );
 }
 
 AmarokUrl
