@@ -17,29 +17,28 @@
  
 #include "BrowserDock.h"
 
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "core/support/Amarok.h"
 #include "core/support/Components.h"
 #include "core/support/Debug.h"
-#include "core-impl/logger/ProxyLogger.h"
 #include "PaletteHandler.h"
+#include "widgets/BoxWidget.h"
 #include "widgets/HorizontalDivider.h"
 
-#include <KAction>
-#include <KIcon>
-#include <KLocale>
+#include <QAction>
+#include <QIcon>
 
-#include <QWidget>
+#include <KLocalizedString>
 
 BrowserDock::BrowserDock( QWidget *parent )
     : AmarokDockWidget( i18n( "&Media Sources" ), parent )
 {
-    setObjectName( "Media Sources dock" );
+    setObjectName( QStringLiteral("Media Sources dock") );
     setAllowedAreas( Qt::AllDockWidgetAreas );
 
     //we have to create this here as it is used when setting up the
     //categories (unless of course we move that to polish as well...)
-    m_mainWidget = new KVBox( this );
+    m_mainWidget = new BoxWidget( true, this );
     setWidget( m_mainWidget );
     m_mainWidget->setContentsMargins( 0, 0, 0, 0 );
     m_mainWidget->setFrameShape( QFrame::NoFrame );
@@ -49,20 +48,14 @@ BrowserDock::BrowserDock( QWidget *parent )
 
     m_breadcrumbWidget = new BrowserBreadcrumbWidget( m_mainWidget );
     new HorizontalDivider( m_mainWidget );
-    m_categoryList = new BrowserCategoryList( "root list", m_mainWidget );
+    m_categoryList = new BrowserCategoryList( QStringLiteral("root list"), m_mainWidget );
     m_breadcrumbWidget->setRootList( m_categoryList.data() );
 
     m_messageArea = new BrowserMessageArea( m_mainWidget );
     m_messageArea->setAutoFillBackground( true );
+    //TODO: set dynamic height for hidpi displays
     m_messageArea->setFixedHeight( 36 );
 
-    Amarok::Logger *logger = Amarok::Components::logger();
-    ProxyLogger *proxy = dynamic_cast<ProxyLogger *>( logger );
-    if( proxy )
-        proxy->setLogger( m_messageArea );
-    else
-        error() << "Was not able to register BrowserDock as logger";
-
     ensurePolish();
 }
 
@@ -71,22 +64,23 @@ BrowserDock::~BrowserDock()
 
 void BrowserDock::polish()
 {
-    m_categoryList.data()->setIcon( KIcon( "user-home" ) );
+    m_categoryList->setIcon( QIcon::fromTheme( QStringLiteral("user-home") ) );
 
-    m_categoryList.data()->setMinimumSize( 100, 300 );
+    m_categoryList->setMinimumSize( 100, 300 );
 
-    connect( m_breadcrumbWidget, SIGNAL(toHome()), this, SLOT(home()) );
+    connect( m_breadcrumbWidget, &BrowserBreadcrumbWidget::toHome, this, &BrowserDock::home );
 
     // Keyboard shortcut for going back one level
-    KAction *action = new KAction( KIcon( "go-up" ), i18n( "Go Up in Media Sources Pane" ),
+    QAction *action = new QAction( QIcon::fromTheme( QStringLiteral("go-up") ), i18n( "Go Up in Media Sources Pane" ),
                                   m_mainWidget );
-    Amarok::actionCollection()->addAction( "browser_previous", action );
-    connect( action, SIGNAL(triggered(bool)), m_categoryList.data(), SLOT(back()) );
-    action->setShortcut( KShortcut( Qt::Key_Backspace ) );
+    Amarok::actionCollection()->addAction( QStringLiteral("browser_previous"), action );
+    connect( action, &QAction::triggered, m_categoryList.data(), &BrowserCategoryList::back );
+//    action->setShortcut( QKeySequence( Qt::Key_Backspace ) );
+    action->setShortcut( Qt::Key_Backspace );
 
     paletteChanged( palette() );
 
-    connect( The::paletteHandler(), SIGNAL(newPalette(QPalette)), SLOT(paletteChanged(QPalette)) );
+    connect( The::paletteHandler(), &PaletteHandler::newPalette, this, &BrowserDock::paletteChanged );
 }
 
 BrowserCategoryList *BrowserDock::list() const
@@ -97,13 +91,13 @@ BrowserCategoryList *BrowserDock::list() const
 void
 BrowserDock::navigate( const QString &target )
 {
-    m_categoryList.data()->navigate( target );
+    m_categoryList->navigate( target );
 }
 
 void
 BrowserDock::home()
 {
-    m_categoryList.data()->home();
+    m_categoryList->home();
 }
 
 void
@@ -113,10 +107,9 @@ BrowserDock::paletteChanged( const QPalette &palette )
                 QString( "QFrame#BrowserMessageArea { border: 1px ridge %1; " \
                          "background-color: %2; color: %3; border-radius: 3px; }" \
                          "QLabel { color: %3; }" )
-                        .arg( palette.color( QPalette::Active, QPalette::Window ).name() )
-                        .arg( The::paletteHandler()->highlightColor().name() )
-                        .arg( palette.color( QPalette::Active, QPalette::HighlightedText ).name() )
+                        .arg( palette.color( QPalette::Active, QPalette::Window ).name(),
+                              palette.color( QPalette::Active, QPalette::Mid ).name(),
+                              palette.color( QPalette::Active, QPalette::HighlightedText ).name() )
                 );
 }
 
-#include "BrowserDock.moc"
