@@ -1,6 +1,7 @@
 /****************************************************************************************
  * Copyright (c) 2007 Nikolaj Hald Nielsen <nhn@kde.org>                                *
  * Copyright (c) 2008 Seb Ruiz <ruiz@kde.org>                                           *
+ * Copyright (c) 2013 Ralf Engels <ralf-engels@gmx.de>                                  *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -18,36 +19,40 @@
 #ifndef COLLECTIONSORTFILTERPROXYMODEL_H
 #define COLLECTIONSORTFILTERPROXYMODEL_H
 
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 
 #include <QSortFilterProxyModel>
 
+class CollectionTreeItem;
+class QCollator;
+
 /**
-    This is a custom QSortFilterProxyModel that solves some issues with sorting a model that usses lazy loading
+    This is a custom QSortFilterProxyModel that gives special sort orders for
+    our meta objects.
+    e.g. it sorts tracks by disc number and track number.
+
     @author Nikolaj Hald Nielsen <nhn@kde.org>
 */
-
-class CollectionTreeItem;
-
 class CollectionSortFilterProxyModel : public QSortFilterProxyModel
 {
     public:
-        CollectionSortFilterProxyModel( QObject * parent = 0 );
+        explicit CollectionSortFilterProxyModel( QObject *parent = nullptr );
 
-        virtual ~CollectionSortFilterProxyModel();
+        ~CollectionSortFilterProxyModel() override;
 
-        bool hasChildren(const QModelIndex &parent) const;
+        bool hasChildren(const QModelIndex &parent) const override;
 
     protected:
-        virtual bool lessThan( const QModelIndex &left, const QModelIndex &right ) const;
+        bool lessThan( const QModelIndex &left, const QModelIndex &right ) const override;
+        bool filterAcceptsRow( int source_row, const QModelIndex & source_parent ) const override;
 
     private:
-        int albumYear( Meta::AlbumPtr album ) const;
+        QCollator *m_col;
+
         CollectionTreeItem* treeItem( const QModelIndex &index ) const;
         bool lessThanTrack( const QModelIndex &left, const QModelIndex &right ) const;
         bool lessThanAlbum( const QModelIndex &left, const QModelIndex &right ) const;
-        bool lessThanIndex( const QModelIndex &left, const QModelIndex &right ) const;
-        bool lessThanString( const QString &a, const QString &b ) const;
+        bool lessThanItem( const QModelIndex &left, const QModelIndex &right ) const;
 };
 
 #endif
