@@ -264,6 +264,12 @@ CollectionTreeItem::isAlbumItem() const
     return m_type == Data && !Meta::AlbumPtr::dynamicCast( m_data ).isNull();
 }
 
+bool
+CollectionTreeItem::isArtistItem() const
+{
+    return m_type == Data && !Meta::ArtistPtr::dynamicCast( m_data ).isNull();
+}
+
 bool
 CollectionTreeItem::isTrackItem() const
 {
