@@ -55,6 +55,8 @@
 #include <QSortFilterProxyModel>
 #include <QScrollBar>
 
+#include <algorithm>
+
 using namespace Collections;
 
 /**
@@ -180,13 +182,14 @@ class AutoExpander : public QObject
 
 CollectionTreeView::CollectionTreeView( QWidget *parent)
     : Amarok::PrettyTreeView( parent )
-    , m_filterModel( 0 )
-    , m_treeModel( 0 )
-    , m_pd( 0 )
-    , m_appendAction( 0 )
-    , m_loadAction( 0 )
-    , m_editAction( 0 )
-    , m_organizeAction( 0 )
+    , m_filterModel( nullptr )
+    , m_treeModel( nullptr )
+    , m_pd( nullptr )
+    , m_appendAction( nullptr )
+    , m_loadAction( nullptr )
+    , m_editAction( nullptr )
+    , m_organizeAction( nullptr )
+    , m_collapseAction( nullptr )
     , m_ongoingDrag( false )
 {
     setSortingEnabled( true );
@@ -208,7 +211,7 @@ void
 CollectionTreeView::setModel( QAbstractItemModel *model )
 {
     if( m_treeModel )
-        disconnect( m_treeModel, 0, this, 0);
+        disconnect( m_treeModel, nullptr, this, nullptr);
 
     m_treeModel = qobject_cast<CollectionTreeItemModelBase *>( model );
     if( !m_treeModel )
@@ -299,6 +302,17 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
         setCurrentIndex( index );
     }
 
+    // Go through here, as the indices might change in the next phase before menu construction
+    bool expanded = false;
+    for( auto idx : indices )
+    {
+        if(isExpanded(idx) || idx.parent() != QModelIndex() )
+        {
+            expanded = true;
+            break;
+        }
+    }
+
     //TODO: get rid of this, it's a hack.
     // Put remove actions in model so we don't need access to the internal pointer in view
     if( m_filterModel )
@@ -332,6 +346,19 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent *event )
 
     // create basic actions
     QActionList actions = createBasicActions( indices );
+
+    // Adding this action here is maybe less intrusive than in e.g.
+    // createBasicActions, especially as it's not relevant in popupdropper.
+    if( expanded )
+    {
+        if( m_collapseAction == nullptr )
+        {
+            m_collapseAction = new QAction( i18n( "Collapse All" ), this );
+                connect( m_collapseAction, &QAction::triggered,
+                            this, &CollectionTreeView::collapseAll );
+        }
+        actions.append( m_collapseAction );
+    }
     foreach( QAction *action, actions ) {
         menu.addAction( action );
     }
@@ -459,7 +486,7 @@ CollectionTreeView::mouseDoubleClickEvent( QMouseEvent *event )
     // mind bug 279513
     bool isExpandable = model()->hasChildren( index );
     bool wouldExpand = !visualRect( index ).contains( event->pos() ) || // clicked outside item, perhaps on expander icon
-                       ( isExpandable && !style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, 0, this ) ); // we're in doubleClick
+                       ( isExpandable && !style()->styleHint( QStyle::SH_ItemView_ActivateItemOnSingleClick, nullptr, this ) ); // we're in doubleClick
     if( event->button() == Qt::LeftButton &&
         event->modifiers() == Qt::NoModifier &&
         !wouldExpand )
@@ -480,7 +507,7 @@ CollectionTreeView::mouseReleaseEvent( QMouseEvent *event )
     {
         connect( m_pd, &PopupDropper::fadeHideFinished, m_pd, &PopupDropper::deleteLater );
         m_pd->hide();
-        m_pd = 0;
+        m_pd = nullptr;
     }
 
     QModelIndex index = indexAt( event->pos() );
@@ -512,7 +539,7 @@ CollectionTreeView::getItemFromIndex( QModelIndex &index )
 
     if( !filteredIndex.isValid() )
     {
-        return 0;
+        return nullptr;
     }
 
     return static_cast<CollectionTreeItem *>( filteredIndex.internalPointer() );
@@ -567,15 +594,6 @@ CollectionTreeView::keyPressEvent( QKeyEvent *event )
             break;
         case Qt::Key_Down:
             break;
-        // L and R should magically work when we get a patched version of qt
-        case Qt::Key_Right:
-        case Qt::Key_Direction_R:
-            expand( current );
-            return;
-        case Qt::Key_Left:
-        case Qt::Key_Direction_L:
-            collapse( current );
-            return;
         default:
             break;
     }
@@ -681,10 +699,10 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
 
         actions = createExtendedActions( indices );
 
-        PopupDropper *morePud = 0;
+        PopupDropper *morePud = nullptr;
         if( actions.count() > 1 )
         {
-            morePud = The::popupDropperFactory()->createPopupDropper( 0, true );
+            morePud = The::popupDropperFactory()->createPopupDropper( nullptr, true );
 
             foreach( QAction *action, actions )
                 morePud->addItem( The::popupDropperFactory()->createItem( action ) );
@@ -801,7 +819,7 @@ CollectionTreeView::playChildTracks( const QSet<CollectionTreeItem *> &items,
 
     //Store the type of playlist insert to be done and cause a slot to be invoked when the tracklist has been generated.
     AmarokMimeData *mime = dynamic_cast<AmarokMimeData*>(
-                m_treeModel->mimeData( QList<CollectionTreeItem *>::fromSet( parents ) ) );
+                m_treeModel->mimeData( QList<CollectionTreeItem *>( parents.begin(), parents.end() ) ) );
     m_playChildTracksMode.insert( mime, insertMode );
     connect( mime, &AmarokMimeData::trackListSignal,
              this, &CollectionTreeView::playChildTracksSlot );
@@ -815,7 +833,7 @@ CollectionTreeView::playChildTracksSlot( Meta::TrackList list ) //slot
 
     Playlist::AddOptions insertMode = m_playChildTracksMode.take( mime );
 
-    qStableSort( list.begin(), list.end(), Meta::Track::lessThan );
+    std::stable_sort( list.begin(), list.end(), Meta::Track::lessThan );
     The::playlistController()->insertOptioned( list, insertMode );
 
     mime->deleteLater();
@@ -834,7 +852,7 @@ CollectionTreeView::organizeTracks( const QSet<CollectionTreeItem *> &items ) co
     if( !qm )
         return;
 
-    CollectionTreeItem *item = items.toList().first();
+    CollectionTreeItem *item = items.values().first();
     while( item->isDataItem() )
         item = item->parent();
 
@@ -857,7 +875,7 @@ CollectionTreeView::copySelectedToLocalCollection()
     DEBUG_BLOCK
 
     // Get the local collection
-    Collections::Collection *collection = 0;
+    Collections::Collection *collection = nullptr;
     const QList<Collections::Collection*> collections = CollectionManager::instance()->collections().keys();
 
     foreach( collection, collections )
@@ -920,7 +938,7 @@ CollectionTreeView::copyTracks( const QSet<CollectionTreeItem *> &items,
         return;
     }
 
-    CollectionTreeItem *item = items.toList().first();
+    CollectionTreeItem *item = items.values().first();
     while( item->isDataItem() )
     {
         item = item->parent();
@@ -964,7 +982,7 @@ CollectionTreeView::removeTracks( const QSet<CollectionTreeItem *> &items,
     if( !qm )
         return;
 
-    CollectionTreeItem *item = items.toList().first();
+    CollectionTreeItem *item = items.values().first();
     while( item->isDataItem() )
         item = item->parent();
     Collection *coll = item->parentCollection();
@@ -1014,7 +1032,7 @@ CollectionTreeView::slotSetFilter( const QString &filter )
         // ways to determine what item should stay "fixed".
         QModelIndex scrollToIndex = m_filterModel->index( 0, 0 );
         while( isExpanded( scrollToIndex ) && m_filterModel->rowCount( scrollToIndex ) > 0 )
-            scrollToIndex = scrollToIndex.child( 0, 0 );
+            scrollToIndex = m_filterModel->index( 0, 0, scrollToIndex);
         int topOffset = visualRect( scrollToIndex ).top();
 
         QModelIndex bottomIndex = m_filterModel->mapToSource( scrollToIndex );
@@ -1048,7 +1066,7 @@ CollectionTreeView::slotAddFilteredTracksToPlaylist()
         {
             QModelIndex idx = m_treeModel->index( row, 0 );
             CollectionTreeItem *item = idx.isValid()
-                    ? static_cast<CollectionTreeItem *>( idx.internalPointer() ) : 0;
+                    ? static_cast<CollectionTreeItem *>( idx.internalPointer() ) : nullptr;
             if( item )
                 items.insert( item );
         }
@@ -1065,7 +1083,7 @@ CollectionTreeView::createBasicActions( const QModelIndexList &indices )
 
     if( !indices.isEmpty() )
     {
-        if( m_appendAction == 0 )
+        if( m_appendAction == nullptr )
         {
             m_appendAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ),
                                           i18n( "&Add to Playlist" ), this );
@@ -1075,7 +1093,7 @@ CollectionTreeView::createBasicActions( const QModelIndexList &indices )
 
         actions.append( m_appendAction );
 
-        if( m_loadAction == 0 )
+        if( m_loadAction == nullptr )
         {
             m_loadAction = new QAction(
                         i18nc( "Replace the currently loaded tracks with these",
@@ -1125,7 +1143,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
 
                 if( onlyOneCollection )
                 {
-                    if( m_organizeAction == 0 )
+                    if( m_organizeAction == nullptr )
                     {
                         m_organizeAction = new QAction( QIcon::fromTheme(QStringLiteral("folder-open") ),
                                     i18nc( "Organize Files", "Organize Files" ), this );
@@ -1158,7 +1176,7 @@ CollectionTreeView::createExtendedActions( const QModelIndexList &indices )
             }
         }
 
-        if( m_editAction == 0 )
+        if( m_editAction == nullptr )
         {
             m_editAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ),
                                         i18n( "&Edit Track Details" ), this );
@@ -1261,7 +1279,7 @@ CollectionTreeView::getCopyActions( const QModelIndexList &indices )
         {
             foreach( Collection *coll, writableCollections )
             {
-                QAction *action = new QAction( coll->icon(), coll->prettyName(), 0 );
+                QAction *action = new QAction( coll->icon(), coll->prettyName(), nullptr );
                 action->setProperty( "popupdropper_svg_id", "collection" );
                 connect( action, &QAction::triggered, this, &CollectionTreeView::slotCopyTracks );
 
@@ -1298,7 +1316,7 @@ CollectionTreeView::getMoveActions( const QModelIndexList &indices )
             {
                 foreach( Collection *coll, writableCollections )
                 {
-                    QAction *action = new QAction( coll->icon(), coll->prettyName(), 0 );
+                    QAction *action = new QAction( coll->icon(), coll->prettyName(), nullptr );
                     action->setProperty( "popupdropper_svg_id", "collection" );
                     connect( action, &QAction::triggered, this, &CollectionTreeView::slotMoveTracks );
                     currentMoveDestination.insert( action, coll );
@@ -1328,7 +1346,7 @@ bool CollectionTreeView::onlyOneCollection( const QModelIndexList &indices )
 Collection *
 CollectionTreeView::getCollection( const QModelIndex &index )
 {
-    Collection *collection = 0;
+    Collection *collection = nullptr;
     if( index.isValid() )
     {
         CollectionTreeItem *item =
@@ -1434,7 +1452,7 @@ CollectionTreeView::createMetaQueryFromItems( const QSet<CollectionTreeItem *> &
                                               bool cleanItems ) const
 {
     if( !m_treeModel )
-        return 0;
+        return nullptr;
 
     QSet<CollectionTreeItem*> parents = cleanItems ? cleanItemSet( items ) : items;
 
