@@ -178,6 +178,8 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
                     QString(Meta::shortI18nForField( Meta::valCreateDate ) + ":<1w") );
     combo->addItem( icon, i18nc("@item:inlistbox Collection widget filter preset", "Added This Month"),
                     QString(Meta::shortI18nForField( Meta::valCreateDate ) + ":<1m") );
+    combo->addItem( icon, i18nc("@item:inlistbox Collection widget filter preset", "Never Played"),
+                    QString(Meta::shortI18nForField( Meta::valPlaycount ) + ":0") );
     combo->insertSeparator( combo->count() );
 
     QMenu *filterMenu = new QMenu( nullptr );
@@ -254,6 +256,11 @@ CollectionWidget::CollectionWidget( const QString &name , QWidget *parent )
     showTrackNumbers->setChecked( AmarokConfig::showTrackNumbers() );
     connect( showTrackNumbers, &QAction::toggled, this, &CollectionWidget::slotShowTrackNumbers );
 
+    QAction *showArtistForVarious = filterMenu->addAction( i18nc("@action:inmenu", "Show Artist for Various Artists") );
+    showArtistForVarious->setCheckable( true );
+    showArtistForVarious->setChecked( AmarokConfig::showArtistForVarious() );
+    connect( showArtistForVarious, &QAction::toggled, this, &CollectionWidget::slotShowArtistForVarious );
+
     QAction *showCovers = filterMenu->addAction( i18n( "Show Cover Art" ) );
     showCovers->setCheckable( true );
     showCovers->setChecked( AmarokConfig::showAlbumArt() );
@@ -332,6 +339,13 @@ CollectionWidget::slotShowTrackNumbers( bool checked )
     setLevels( levels() );
 }
 
+void
+CollectionWidget::slotShowArtistForVarious( bool checked )
+{
+    AmarokConfig::setShowArtistForVarious( checked );
+    setLevels( levels() );
+}
+
 void
 CollectionWidget::slotShowCovers(bool checked)
 {
