@@ -29,6 +29,8 @@
 
 #include <QAction>
 
+#include <algorithm>
+
 using namespace PlaylistBrowserNS;
 
 // to be used with qSort.
@@ -68,7 +70,7 @@ PlaylistBrowserModel::data( const QModelIndex &index, int role ) const
     QList<QAction *> providerActions;
     QList<Playlists::PlaylistProvider *> providers =
         The::playlistManager()->getProvidersForPlaylist( playlist );
-    Playlists::PlaylistProvider *provider = providers.count() == 1 ? providers.first() : 0;
+    Playlists::PlaylistProvider *provider = providers.count() == 1 ? providers.first() : nullptr;
     Meta::TrackPtr track;
 
     switch( index.column() )
@@ -590,7 +592,7 @@ PlaylistBrowserModel::loadPlaylists()
         subscribeTo( playlist );
     }
 
-    qSort( playlists.begin(), playlists.end(), lessThanPlaylistTitles );
+    std::sort( playlists.begin(), playlists.end(), lessThanPlaylistTitles );
 
     return playlists;
 }
@@ -708,7 +710,7 @@ Playlists::PlaylistProvider *
 PlaylistBrowserModel::providerForIndex( const QModelIndex &idx ) const
 {
     if( !idx.isValid() )
-        return 0;
+        return nullptr;
 
     int playlistRow;
     if( IS_TRACK( idx ) )
@@ -717,7 +719,7 @@ PlaylistBrowserModel::providerForIndex( const QModelIndex &idx ) const
         playlistRow = idx.row();
 
     if( playlistRow >= m_playlists.count() )
-        return 0;
+        return nullptr;
 
     return m_playlists.at( playlistRow )->provider();
 }
@@ -732,5 +734,5 @@ PlaylistBrowserModel::getProviderByName( const QString &name )
         if( provider->prettyName() == name )
             return provider;
     }
-    return 0;
+    return nullptr;
 }
