@@ -41,20 +41,20 @@ class UserModel : public PlaylistBrowserModel
         static UserModel * instance();
         static void destroy();
 
-        ~UserModel();
+        ~UserModel() override;
 
-        virtual bool setData( const QModelIndex &index, const QVariant &value, int role = Qt::EditRole );
-        virtual bool removeRows( int row, int count, const QModelIndex & parent = QModelIndex() );
+        bool setData( const QModelIndex &index, const QVariant &value, int role = Qt::EditRole ) override;
+        bool removeRows( int row, int count, const QModelIndex & parent = QModelIndex() ) override;
 
-        virtual Qt::DropActions supportedDropActions() const {
+        Qt::DropActions supportedDropActions() const override {
             return Qt::CopyAction | Qt::MoveAction;
         }
 
-        virtual Qt::DropActions supportedDragActions() const {
+        Qt::DropActions supportedDragActions() const override {
             return Qt::MoveAction | Qt::CopyAction;
         }
 
-        bool dropMimeData ( const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent );
+        bool dropMimeData ( const QMimeData * data, Qt::DropAction action, int row, int column, const QModelIndex & parent ) override;
 
     private:
         UserModel();
