@@ -18,6 +18,7 @@
 
 #include "PluginsConfig.h"
 
+#include "configdialog/ConfigDialog.h"
 #include "core/support/Debug.h"
 #include "services/ServiceBase.h"
 #include "PluginManager.h"
@@ -27,7 +28,7 @@
 
 #include <QVBoxLayout>
 
-PluginsConfig::PluginsConfig( QWidget *parent )
+PluginsConfig::PluginsConfig( Amarok2ConfigDialog *parent )
     : ConfigDialogBase( parent )
     , m_configChanged( false )
 {
@@ -40,16 +41,16 @@ PluginsConfig::PluginsConfig( QWidget *parent )
     layout->addWidget( m_selector );
 
     m_selector->addPlugins( The::pluginManager()->plugins( Plugins::PluginManager::Collection ),
-                            KPluginSelector::ReadConfigFile, i18n("Collections"), "Collection" );
+                            KPluginSelector::ReadConfigFile, i18n("Collections"), QStringLiteral("Collection") );
 
     m_selector->addPlugins( The::pluginManager()->plugins( Plugins::PluginManager::Service ),
-                            KPluginSelector::ReadConfigFile, i18n("Internet Services"), "Service" );
+                            KPluginSelector::ReadConfigFile, i18n("Internet Services"), QStringLiteral("Service") );
 
     m_selector->addPlugins( The::pluginManager()->plugins( Plugins::PluginManager::Importer ),
-                            KPluginSelector::ReadConfigFile, i18n("Statistics importers"), "Importer" );
+                            KPluginSelector::ReadConfigFile, i18n("Statistics importers"), QStringLiteral("Importer") );
 
-    connect( m_selector, SIGNAL(changed(bool)), SLOT(slotConfigChanged(bool)) );
-    connect( m_selector, SIGNAL(changed(bool)), parent, SLOT(updateButtons()) );
+    connect( m_selector, &KPluginSelector::changed, this, &PluginsConfig::slotConfigChanged );
+    connect( m_selector, &KPluginSelector::changed, parent, &Amarok2ConfigDialog::updateButtons );
 }
 
 PluginsConfig::~PluginsConfig()
@@ -86,4 +87,3 @@ void PluginsConfig::slotConfigChanged( bool changed )
         debug() << "config changed";
 }
 
-#include "PluginsConfig.moc"
