@@ -28,16 +28,13 @@
 #include "ui_upcomingEventsVenueSettings.h"
 
 class KConfigDialog;
-class QGraphicsLinearLayout;
 class QListWidgetItem;
-class QXmlStreamReader;
 class UpcomingEventsMapWidget;
 class UpcomingEventsStackItem;
 class UpcomingEventsStack;
 
 namespace Plasma
 {
-    class WebView;
 }
 
  /**
@@ -68,7 +65,7 @@ public:
      *
      * This method is called when the interface should be painted
      *
-     * \param painter : the QPainter to use to do the paintiner
+     * \param painter : the QPainter to use to do the paint
      * \param option : the style options object
      * \param contentsRect : the rect to paint within; automatically adjusted for
      *                     the background, if any
@@ -88,7 +85,7 @@ public:
      */
     void constraintsEvent( Plasma::Constraints constraints = Plasma::AllConstraints );
 
-signals:
+Q_SIGNALS:
     void listWidgetAdded( UpcomingEventsListWidget *widget );
     void listWidgetRemoved( UpcomingEventsListWidget *widget );
 
@@ -103,7 +100,7 @@ protected:
      */
     void createConfigurationInterface(KConfigDialog *parent);
 
-public slots:
+public Q_SLOTS:
     /**
      * \brief Initialization
      *
@@ -140,7 +137,7 @@ private:
      */
     UpcomingEventsListWidget *m_artistEventsList;
 
-private slots:
+private Q_SLOTS:
     /**
      * Connects the source to the Upcoming Events engine
      * and calls the dataUpdated function
@@ -205,10 +202,10 @@ private:
     UpcomingEventsStack *m_stack;
     UpcomingEventsMapWidget *mapView();
 
-private slots:
+private Q_SLOTS:
     void searchVenue( const QString &text );
-    void venueResults( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
-    void venuePhotoResult( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
+    void venueResults( const QUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
+    void venuePhotoResult( const QUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e );
     void showVenueInfo( QListWidgetItem *item );
     void venueResultDoubleClicked( QListWidgetItem *item );
     void selectedVenueDoubleClicked( QListWidgetItem *item );
