@@ -32,7 +32,7 @@ namespace Meta
 {
 
 #define FORWARD( call ) { foreach( TrackEditorPtr e, m_editors ) { e->call; } \
-                            if( !m_batchMode ) QTimer::singleShot( 0, m_collection, SLOT(slotUpdated()) ); }
+                            if( !m_batchMode ) QTimer::singleShot( 0, m_collection, &Collections::AggregateCollection::slotUpdated ); }
 
 class AggregateTrackEditor : public TrackEditor
 {
@@ -44,28 +44,28 @@ public:
         , m_editors( editors )
     {}
 
-    void beginUpdate()
+    void beginUpdate() override
     {
         m_batchMode = true;
         foreach( TrackEditorPtr ec, m_editors ) ec->beginUpdate();
     }
-    void endUpdate()
+    void endUpdate() override
     {
         foreach( TrackEditorPtr ec, m_editors ) ec->endUpdate();
         m_batchMode = false;
-        QTimer::singleShot( 0, m_collection, SLOT(slotUpdated()) );
+        QTimer::singleShot( 0, m_collection, &Collections::AggregateCollection::slotUpdated );
     }
-    void setComment( const QString &newComment ) { FORWARD( setComment( newComment ) ) }
-    void setTrackNumber( int newTrackNumber ) { FORWARD( setTrackNumber( newTrackNumber ) ) }
-    void setDiscNumber( int newDiscNumber ) { FORWARD( setDiscNumber( newDiscNumber ) ) }
-    void setBpm( const qreal newBpm ) { FORWARD( setBpm( newBpm ) ) }
-    void setTitle( const QString &newTitle ) { FORWARD( setTitle( newTitle ) ) }
-    void setArtist( const QString &newArtist ) { FORWARD( setArtist( newArtist ) ) }
-    void setAlbum( const QString &newAlbum ) { FORWARD( setAlbum( newAlbum ) ) }
-    void setAlbumArtist( const QString &newAlbumArtist ) { FORWARD( setAlbumArtist ( newAlbumArtist ) ) }
-    void setGenre( const QString &newGenre ) { FORWARD( setGenre( newGenre ) ) }
-    void setComposer( const QString &newComposer ) { FORWARD( setComposer( newComposer ) ) }
-    void setYear( int newYear ) { FORWARD( setYear( newYear ) ) }
+    void setComment( const QString &newComment ) override { FORWARD( setComment( newComment ) ) }
+    void setTrackNumber( int newTrackNumber ) override { FORWARD( setTrackNumber( newTrackNumber ) ) }
+    void setDiscNumber( int newDiscNumber ) override { FORWARD( setDiscNumber( newDiscNumber ) ) }
+    void setBpm( const qreal newBpm ) override { FORWARD( setBpm( newBpm ) ) }
+    void setTitle( const QString &newTitle ) override { FORWARD( setTitle( newTitle ) ) }
+    void setArtist( const QString &newArtist ) override { FORWARD( setArtist( newArtist ) ) }
+    void setAlbum( const QString &newAlbum ) override { FORWARD( setAlbum( newAlbum ) ) }
+    void setAlbumArtist( const QString &newAlbumArtist ) override { FORWARD( setAlbumArtist ( newAlbumArtist ) ) }
+    void setGenre( const QString &newGenre ) override { FORWARD( setGenre( newGenre ) ) }
+    void setComposer( const QString &newComposer ) override { FORWARD( setComposer( newComposer ) ) }
+    void setYear( int newYear ) override { FORWARD( setYear( newYear ) ) }
 private:
     bool m_batchMode;
     Collections::AggregateCollection *m_collection;
@@ -79,11 +79,11 @@ AggregateTrack::AggregateTrack( Collections::AggregateCollection *coll, const Tr
         , Observer()
         , m_collection( coll )
         , m_name( track->name() )
-        , m_album( 0 )
-        , m_artist( 0 )
-        , m_genre( 0 )
-        , m_composer( 0 )
-        , m_year( 0 )
+        , m_album( nullptr )
+        , m_artist( nullptr )
+        , m_genre( nullptr )
+        , m_composer( nullptr )
+        , m_year( nullptr )
 {
     subscribeTo( track );
     m_tracks.append( track );
@@ -125,7 +125,7 @@ AggregateTrack::sortableName() const
     return m_name;
 }
 
-KUrl
+QUrl
 AggregateTrack::playableUrl() const
 {
     Meta::TrackPtr bestPlayableTrack;
@@ -150,7 +150,7 @@ AggregateTrack::playableUrl() const
     if( bestPlayableTrack )
         return bestPlayableTrack->playableUrl();
 
-    return KUrl();
+    return QUrl();
 }
 
 QString
@@ -187,7 +187,7 @@ AggregateTrack::notPlayableReason() const
         else
             return QString(); // no reason if at least one playable
     }
-    return reasons.join( QString( ", " ) );
+    return reasons.join( QStringLiteral( ", " ) );
 }
 
 Meta::AlbumPtr
@@ -553,7 +553,7 @@ AggregateTrack::createCapabilityInterface( Capabilities::Capability::Type type )
     if( m_tracks.count() == 1 )
         return m_tracks.first()->createCapabilityInterface( type );
     else
-        return 0;
+        return nullptr;
 }
 
 TrackEditorPtr
@@ -639,7 +639,7 @@ AggregateTrack::add( const Meta::TrackPtr &track )
 }
 
 void
-AggregateTrack::metadataChanged( Meta::TrackPtr track )
+AggregateTrack::metadataChanged(const TrackPtr &track )
 {
     if( !track )
         return;
@@ -797,12 +797,12 @@ AggregateAlbum::createCapabilityInterface( Capabilities::Capability::Type type )
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
 void
-AggregateAlbum::add( Meta::AlbumPtr album )
+AggregateAlbum::add( const Meta::AlbumPtr &album )
 {
     if( !album || m_albums.contains( album ) )
         return;
@@ -837,21 +837,21 @@ AggregateAlbum::image( int size ) const
     return Meta::Album::image( size );
 }
 
-KUrl
+QUrl
 AggregateAlbum::imageLocation( int size )
 {
     foreach( Meta::AlbumPtr album, m_albums )
     {
         if( album->hasImage( size ) )
         {
-            KUrl url = album->imageLocation( size );
+            QUrl url = album->imageLocation( size );
             if( url.isValid() )
             {
                 return url;
             }
         }
     }
-    return KUrl();
+    return QUrl();
 }
 
 QPixmap
@@ -870,12 +870,12 @@ AggregateAlbum::imageWithBorder( int size, int borderWidth )
 bool
 AggregateAlbum::canUpdateImage() const
 {
-    if( m_albums.count() == 0 )
+    if( m_albums.isEmpty() )
         return false;
 
     foreach( const Meta::AlbumPtr &album, m_albums )
     {
-        //we can only update the image for all albusm at the same time
+        //we can only update the image for all albums at the same time
         if( !album->canUpdateImage() )
             return false;
     }
@@ -921,7 +921,7 @@ AggregateAlbum::suppressImageAutoFetch() const
 }
 
 void
-AggregateAlbum::metadataChanged( Meta::AlbumPtr album )
+AggregateAlbum::metadataChanged(const AlbumPtr &album )
 {
     if( !album || !m_albums.contains( album ) )
         return;
@@ -953,7 +953,7 @@ AggregateAlbum::metadataChanged( Meta::AlbumPtr album )
     notifyObservers();
 }
 
-AggregateArtist::AggregateArtist( Collections::AggregateCollection *coll, Meta::ArtistPtr artist )
+AggregateArtist::AggregateArtist( Collections::AggregateCollection *coll, const Meta::ArtistPtr &artist )
         : Meta::Artist()
         , Meta::Observer()
         , m_collection( coll )
@@ -1032,12 +1032,12 @@ AggregateArtist::createCapabilityInterface( Capabilities::Capability::Type type
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
 void
-AggregateArtist::add( Meta::ArtistPtr artist )
+AggregateArtist::add( const Meta::ArtistPtr &artist )
 {
     if( !artist || m_artists.contains( artist ) )
         return;
@@ -1049,7 +1049,7 @@ AggregateArtist::add( Meta::ArtistPtr artist )
 }
 
 void
-AggregateArtist::metadataChanged( Meta::ArtistPtr artist )
+AggregateArtist::metadataChanged(const ArtistPtr &artist )
 {
     if( !artist || !m_artists.contains( artist ) )
         return;
@@ -1079,7 +1079,7 @@ AggregateArtist::metadataChanged( Meta::ArtistPtr artist )
     notifyObservers();
 }
 
-AggregateGenre::AggregateGenre( Collections::AggregateCollection *coll, Meta::GenrePtr genre )
+AggregateGenre::AggregateGenre( Collections::AggregateCollection *coll, const Meta::GenrePtr &genre )
         : Meta::Genre()
         , Meta::Observer()
         , m_collection( coll )
@@ -1158,12 +1158,12 @@ AggregateGenre::createCapabilityInterface( Capabilities::Capability::Type type )
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
 void
-AggregateGenre::add( Meta::GenrePtr genre )
+AggregateGenre::add( const Meta::GenrePtr &genre )
 {
     if( !genre || m_genres.contains( genre ) )
         return;
@@ -1175,7 +1175,7 @@ AggregateGenre::add( Meta::GenrePtr genre )
 }
 
 void
-AggregateGenre::metadataChanged( Meta::GenrePtr genre )
+AggregateGenre::metadataChanged( const Meta::GenrePtr &genre )
 {
     if( !genre || !m_genres.contains( genre ) )
         return;
@@ -1199,7 +1199,7 @@ AggregateGenre::metadataChanged( Meta::GenrePtr genre )
     notifyObservers();
 }
 
-AggregateComposer::AggregateComposer( Collections::AggregateCollection *coll, Meta::ComposerPtr composer )
+AggregateComposer::AggregateComposer( Collections::AggregateCollection *coll, const Meta::ComposerPtr &composer )
         : Meta::Composer()
         , Meta::Observer()
         , m_collection( coll )
@@ -1278,12 +1278,12 @@ AggregateComposer::createCapabilityInterface( Capabilities::Capability::Type typ
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
 void
-AggregateComposer::add( Meta::ComposerPtr composer )
+AggregateComposer::add( const Meta::ComposerPtr &composer )
 {
     if( !composer || m_composers.contains( composer ) )
         return;
@@ -1295,7 +1295,7 @@ AggregateComposer::add( Meta::ComposerPtr composer )
 }
 
 void
-AggregateComposer::metadataChanged( Meta::ComposerPtr composer )
+AggregateComposer::metadataChanged(const ComposerPtr &composer )
 {
     if( !composer || !m_composers.contains( composer ) )
         return;
@@ -1319,7 +1319,7 @@ AggregateComposer::metadataChanged( Meta::ComposerPtr composer )
     notifyObservers();
 }
 
-AggreagateYear::AggreagateYear( Collections::AggregateCollection *coll, Meta::YearPtr year )
+AggreagateYear::AggreagateYear( Collections::AggregateCollection *coll, const Meta::YearPtr &year )
         : Meta::Year()
         , Meta::Observer()
         , m_collection( coll )
@@ -1399,12 +1399,12 @@ AggreagateYear::createCapabilityInterface( Capabilities::Capability::Type type )
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
 void
-AggreagateYear::add( Meta::YearPtr year )
+AggreagateYear::add( const Meta::YearPtr &year )
 {
     if( !year || m_years.contains( year ) )
         return;
@@ -1416,7 +1416,7 @@ AggreagateYear::add( Meta::YearPtr year )
 }
 
 void
-AggreagateYear::metadataChanged( Meta::YearPtr year )
+AggreagateYear::metadataChanged( const Meta::YearPtr &year )
 {
     if( !year || !m_years.contains( year ) )
         return;
@@ -1442,7 +1442,7 @@ AggreagateYear::metadataChanged( Meta::YearPtr year )
             else
             {
                 // be careful with the ordering of instructions here
-                // AggregateCollection uses KSharedPtr internally
+                // AggregateCollection uses AmarokSharedPointer internally
                 // so we have to make sure that there is more than one pointer
                 // to this instance by registering this instance under the new name
                 // before removing the old one. Otherwise kSharedPtr might delete this
@@ -1516,7 +1516,7 @@ AggregateLabel::createCapabilityInterface( Capabilities::Capability::Type type )
     }
     else
     {
-        return 0;
+        return nullptr;
     }
 }
 
