@@ -85,9 +85,7 @@ AudioCdCollection::~AudioCdCollection()
 QUrl
 AudioCdCollection::audiocdUrl( const QString &path ) const
 {
-    QUrl url("audiocd:/");
-    url = url.adjusted(QUrl::StripTrailingSlash);
-    url.setPath(url.path() + QLatin1Char('/') + ( path ));
+    QUrl url("audiocd:/" + path);
 
     if( !m_device.isEmpty() )
     {
@@ -371,7 +369,7 @@ qint64
 AudioCdCollection::trackLength( int i ) const
 {
     QUrl kioUrl = audiocdUrl( trackWavFileName( i ) );
-    KIO::StatJob *statJob = KIO::stat( kioUrl );
+    KIO::StatJob *statJob = KIO::statDetails( kioUrl, KIO::StatJob::SourceSide );
     if ( statJob->exec() )
     {
         KIO::UDSEntry uds = statJob->statResult();
@@ -506,7 +504,7 @@ AudioCdCollection::noInfoAvailable()
 
     // This will find also data tracks on mixed CDs:
     // a better way to discover the available audio tracks should be found
-    while( KIO::stat( audiocdUrl( trackWav ), KIO::StatJob::SourceSide, 0 )->exec() )
+    while( KIO::statDetails( audiocdUrl( trackWav ), KIO::StatJob::SourceSide )->exec() )
     {
         debug() << "got track url: " << audiocdUrl( trackWav );
 
