@@ -112,7 +112,15 @@ void FormatSelectionDialog::showAdvancedSettings()
 {
     KCMultiDialog KCM;
     KCM.setWindowTitle( i18n( "Audio CD settings - Amarok" ) );
-    KCM.addModule( "audiocd" );
+    QString searchPath = QStringLiteral( "plasma/kcms/systemsettings_qwidgets/kcm_audiocd.so" );
+    KPluginMetaData plugin = KPluginMetaData( searchPath );
+    while( !plugin.isValid() && searchPath.indexOf( '/' ) >= 0 )
+    {
+        searchPath = searchPath.mid( searchPath.indexOf( '/' ) + 1 );
+        qDebug() << "didn't find kcm_audiocd with first attempt, trying"<< searchPath;
+        plugin = KPluginMetaData( searchPath );
+    }
+    KCM.addModule( plugin );
 
     KCM.exec();
 }
