@@ -17,6 +17,7 @@
 #include "DatabaseUpdater.h"
 
 #include "amarokconfig.h"
+#include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 #include <core/storage/SqlStorage.h>
 #include "SqlCollection.h"
@@ -27,7 +28,6 @@
 #include <QMultiMap>
 #include <QTextStream>
 
-#include <KGlobal>
 #include <KMessageBox>
 
 static const int DB_VERSION = 15;
@@ -42,7 +42,7 @@ DatabaseUpdater::DatabaseUpdater( Collections::SqlCollection *collection )
     : m_collection( collection )
     , m_debugDatabaseContent( false )
 {
-    m_debugDatabaseContent = KGlobal::config()->group( "SqlCollection" ).readEntry( "DebugDatabaseContent", false );
+    m_debugDatabaseContent = Amarok::config( "SqlCollection" ).readEntry( "DebugDatabaseContent", false );
 }
 
 DatabaseUpdater::~DatabaseUpdater()
@@ -85,45 +85,45 @@ DatabaseUpdater::update()
         {
             case 1:
                 upgradeVersion1to2();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 2:
                 upgradeVersion2to3();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 3:
                 upgradeVersion3to4();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 4:
                 upgradeVersion4to5();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 5:
                 upgradeVersion5to6();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 6:
                 upgradeVersion6to7();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 7:
                 upgradeVersion7to8();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 8:
                 //removes stray rows from albums that were caused by the initial full scan
                 upgradeVersion8to9();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 9:
                 //removes stray rows from albums that were caused by the initial full scan
                 upgradeVersion9to10();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 10:
                 upgradeVersion10to11();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 11:
                 upgradeVersion11to12();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 12:
                 upgradeVersion12to13();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 13:
                 upgradeVersion13to14();
-                /* Falls through. */
+                Q_FALLTHROUGH();
             case 14:
                 upgradeVersion14to15();
                 dbVersion = 15; // be sure to update this manually when introducing new version!
@@ -139,7 +139,7 @@ DatabaseUpdater::update()
 
     if( dbVersion > DB_VERSION )
     {
-        KMessageBox::error(0,
+        KMessageBox::error(nullptr,
                 "<p>The Amarok collection database was created by a newer version of Amarok, "
                 "and this version of Amarok cannot use it.</p>",
                 "Database Type Unknown");
@@ -168,7 +168,7 @@ DatabaseUpdater::upgradeVersion2to3()
 {
     DEBUG_BLOCK;
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
     storage->query( "DROP TABLE devices;" );
 
     QString create = "CREATE TABLE devices "
@@ -189,7 +189,7 @@ DatabaseUpdater::upgradeVersion2to3()
 void
 DatabaseUpdater::upgradeVersion3to4()
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     storage->query( "CREATE TABLE statistics_permanent "
                          "(url " + storage->exactTextColumnType() +
@@ -217,7 +217,7 @@ DatabaseUpdater::upgradeVersion3to4()
 void
 DatabaseUpdater::upgradeVersion4to5()
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     //first the database
     storage->query( "ALTER DATABASE amarok DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_unicode_ci" );
@@ -341,7 +341,7 @@ DatabaseUpdater::upgradeVersion5to6()
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     //first, drop tables that can easily be recreated by doing an update
     QStringList dropTables;
@@ -397,7 +397,7 @@ DatabaseUpdater::upgradeVersion6to7()
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     typedef QPair<QString, int> vcpair;
     QMultiMap<QString, vcpair> columns;
@@ -423,7 +423,7 @@ DatabaseUpdater::upgradeVersion7to8()
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QHash< int, int > trackLengthHash;
 
@@ -456,7 +456,7 @@ DatabaseUpdater::upgradeVersion9to10()
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     //first the database
     storage->query( "ALTER DATABASE amarok DEFAULT CHARACTER SET utf8 DEFAULT COLLATE utf8_bin" );
@@ -611,7 +611,7 @@ void
 DatabaseUpdater::upgradeVersion13to14()
 {
     DEBUG_BLOCK
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     /* Following commands transition lyrics table from text-based urls (in fact just rpath
      * parts) to references to urls table. */
@@ -624,7 +624,7 @@ DatabaseUpdater::upgradeVersion13to14()
     storage->query( "UPDATE lyrics l SET l.url = (SELECT u.id FROM urls u WHERE u.rpath = l.rpath LIMIT 1)" );
     // delete entries with no matches in urls table; these should be just stale ones
     storage->query( "DELETE FROM lyrics WHERE url IS NULL" );
-    // make the url columnt non-null
+    // make the url column non-null
     storage->query( "ALTER TABLE lyrics MODIFY url INT NOT NULL" );
     // select duplicate ids into temporary table
     storage->query( "CREATE TEMPORARY TABLE duplicate_lyrics_ids ( id INT NOT NULL ) "
@@ -651,7 +651,7 @@ DatabaseUpdater::upgradeVersion14to15()
      * Amarok 2.6-git.
      */
     DEBUG_BLOCK
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     // zero length = TEXT datatype
     typedef QPair<QString, int> vcpair;
@@ -739,7 +739,7 @@ DatabaseUpdater::checkTables( bool full )
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QStringList res = storage->query( "SHOW TABLES" );
     if( res.count() > 0 )
@@ -755,7 +755,7 @@ DatabaseUpdater::createTables() const
 {
     DEBUG_BLOCK
 
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     // see docs/database/amarokTables.svg for documentation about database layout
     {
@@ -967,7 +967,7 @@ DatabaseUpdater::createTables() const
 int
 DatabaseUpdater::adminValue( const QString &key ) const
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QStringList columns = storage->query(
             QString( "SELECT column_name FROM INFORMATION_SCHEMA.columns "
@@ -987,7 +987,7 @@ DatabaseUpdater::adminValue( const QString &key ) const
 void
 DatabaseUpdater::deleteAllRedundant( const QString &type )
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     const QString tablename = type + 's';
     if( type == "artist" )
@@ -1003,7 +1003,7 @@ DatabaseUpdater::deleteAllRedundant( const QString &type )
 void
 DatabaseUpdater::deleteOrphanedByDirectory( const QString &table )
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
     QString query( "DELETE FROM %1 WHERE directory NOT IN ( SELECT id FROM directories )" );
     storage->query( query.arg( table ) );
 }
@@ -1011,7 +1011,7 @@ DatabaseUpdater::deleteOrphanedByDirectory( const QString &table )
 void
 DatabaseUpdater::deleteOrphanedByUrl( const QString &table )
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
     QString query( "DELETE FROM %1 WHERE url NOT IN ( SELECT id FROM urls )" );
     storage->query( query.arg( table ) );
 }
@@ -1019,7 +1019,7 @@ DatabaseUpdater::deleteOrphanedByUrl( const QString &table )
 void
 DatabaseUpdater::removeFilesInDir( int deviceid, const QString &rdir )
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     QString select = QString( "SELECT urls.id FROM urls LEFT JOIN directories ON urls.directory = directories.id "
                               "WHERE directories.deviceid = %1 AND directories.dir = '%2';" )
@@ -1045,7 +1045,7 @@ DatabaseUpdater::removeFilesInDir( int deviceid, const QString &rdir )
 void
 DatabaseUpdater::writeCSVFile( const QString &table, const QString &filename, bool forceDebug )
 {
-    SqlStorage *storage = m_collection->sqlStorage();
+    auto storage = m_collection->sqlStorage();
 
     if( !forceDebug && !m_debugDatabaseContent )
         return;
@@ -1062,7 +1062,7 @@ DatabaseUpdater::writeCSVFile( const QString &table, const QString &filename, bo
     // that clashes with INFORMATION_SCHEMA.statistics, a build in table.
     if( table == "statistics" && columns.count() > 15 )
     {
-        // delete all columns with full upper case name. Those are the buildins.
+        // delete all columns with full upper case name. Those are the builtins.
         for( int i = columns.count()-1; i>= 0; --i )
         {
             if( columns[i].toUpper() == columns[i] )
@@ -1087,7 +1087,6 @@ DatabaseUpdater::writeCSVFile( const QString &table, const QString &filename, bo
     {
         QTextStream stream( &file );
         int i = 0;
-        QString line;
         //write header
         foreach( const QString &column, columns )
         {
@@ -1101,7 +1100,7 @@ DatabaseUpdater::writeCSVFile( const QString &table, const QString &filename, bo
             stream << data;
             stream << ';';
             ++i;
-            if( i % columns.count() == 0 )
+            if( i % columns.isEmpty() )
                 stream << '\n';
         }
         file.close();
