@@ -22,7 +22,8 @@
 #include "core/support/Debug.h"
 #include <core/storage/SqlStorage.h>
 
-#include <KUrl>
+#include <QUrl>
+#include <QDir>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 #include <Solid/NetworkShare>
@@ -75,14 +76,15 @@ const QString &NfsDeviceHandler::getDevicePath() const
     return m_mountPoint;
 }
 
-void NfsDeviceHandler::getURL( KUrl &absolutePath, const KUrl &relativePath )
+void NfsDeviceHandler::getURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     absolutePath.setPath( m_mountPoint );
-    absolutePath.addPath( relativePath.path() );
-    absolutePath.cleanPath();
+    absolutePath = absolutePath.adjusted(QUrl::StripTrailingSlash);
+    absolutePath.setPath(absolutePath.path() + QLatin1Char('/') + ( relativePath.path() ));
+    absolutePath.setPath( QDir::cleanPath(absolutePath.path()) );
 }
 
-void NfsDeviceHandler::getPlayableURL( KUrl &absolutePath, const KUrl &relativePath )
+void NfsDeviceHandler::getPlayableURL( QUrl &absolutePath, const QUrl &relativePath )
 {
     getURL( absolutePath, relativePath );
 }
@@ -145,22 +147,22 @@ NfsDeviceHandlerFactory::~NfsDeviceHandlerFactory( )
 }
 
 DeviceHandler *
-NfsDeviceHandlerFactory::createHandler( KSharedConfigPtr, SqlStorage* ) const
+NfsDeviceHandlerFactory::createHandler( const KSharedConfigPtr&, QSharedPointer<SqlStorage> ) const
 {
-    return 0;
+    return nullptr;
 }
 
 DeviceHandler *
-NfsDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, SqlStorage *s ) const
+NfsDeviceHandlerFactory::createHandler( const Solid::Device &device, const QString &udi, QSharedPointer<SqlStorage> s ) const
 {
     DEBUG_BLOCK
     if( !s )
     {
         debug() << "!s, returning 0";
-        return 0;
+        return nullptr;
     }
     if( !canHandle( device ) )
-        return 0;
+        return nullptr;
 
     const Solid::StorageAccess *access = device.as<Solid::StorageAccess>();
     Q_ASSERT( access );  // canHandle() checks it
@@ -175,15 +177,15 @@ NfsDeviceHandlerFactory::createHandler( const Solid::Device &device, const QStri
     QStringList ids = s->query( QString( "SELECT id, label, lastmountpoint "
                                          "FROM devices WHERE type = 'nfs' "
                                          "AND servername = '%1' AND sharename = '%2';" )
-                                         .arg( s->escape( server ) )
-                                         .arg( s->escape( share ) ) );
+                                         .arg( s->escape( server ),
+                                               s->escape( share ) ) );
     if ( ids.size() == 3 )
     {
         debug() << "Found existing NFS config for ID " << ids[0] << " , server " << server << " ,share " << share;
         s->query( QString( "UPDATE devices SET lastmountpoint = '%2' WHERE "
                            "id = %1;" )
-                           .arg( ids[0] )
-                           .arg( s->escape( mountPoint ) ) );
+                           .arg( ids[0],
+                                 s->escape( mountPoint ) ) );
         return new NfsDeviceHandler( ids[0].toInt(), server, share, mountPoint, udi );
     }
     else
@@ -191,14 +193,14 @@ NfsDeviceHandlerFactory::createHandler( const Solid::Device &device, const QStri
         int id = s->insert( QString( "INSERT INTO devices"
                                      "( type, servername, sharename, lastmountpoint ) "
                                      "VALUES ( 'nfs', '%1', '%2', '%3' );" )
-                                     .arg( s->escape( server ) )
-                                     .arg( s->escape( share ) )
-                                     .arg( s->escape( mountPoint ) ),
+                                     .arg( s->escape( server ),
+                                           s->escape( share ),
+                                           s->escape( mountPoint ) ),
                                      "devices" );
         if ( id == 0 )
         {
             warning() << "Inserting into devices failed for type=nfs, server=" << server << ", share=" << share;
-            return 0;
+            return nullptr;
         }
         debug() << "Created new NFS device with ID " << id << " , server " << server << " ,share " << share;
         return new NfsDeviceHandler( id, server, share, mountPoint, udi );
