@@ -44,14 +44,14 @@ using namespace IpodMeta;
 gpointer AmarokItdbUserDataDuplicateFunc( gpointer userdata )
 {
     Q_UNUSED( userdata )
-    return 0; // we never copy our userdata
+    return nullptr; // we never copy our userdata
 }
 
 Track::Track( Itdb_Track *ipodTrack )
     : m_track( ipodTrack )
     , m_batch( 0 )
 {
-    Q_ASSERT( m_track != 0 );
+    Q_ASSERT( m_track != nullptr );
     m_track->usertype = m_gpodTrackUserTypeAmarokTrackPtr;
     m_track->userdata = this;
     m_track->userdata_duplicate = AmarokItdbUserDataDuplicateFunc;
@@ -61,7 +61,7 @@ Track::Track( const Meta::TrackPtr &origTrack )
     : m_track( itdb_track_new() )
     , m_batch( 0 )
 {
-    Q_ASSERT( m_track != 0 );
+    Q_ASSERT( m_track != nullptr );
     m_track->usertype = m_gpodTrackUserTypeAmarokTrackPtr;
     m_track->userdata = this;
     m_track->userdata_duplicate = AmarokItdbUserDataDuplicateFunc;
@@ -444,14 +444,14 @@ Track::createDate() const
     time_t time = m_track->time_added;
     if( time == 0 )
         return QDateTime();  // 0 means "no reasonable time", so return invalid QDateTime
-    return QDateTime::fromTime_t( time );
+    return QDateTime::fromSecsSinceEpoch( time );
 }
 
 void
 Track::setCreateDate( const QDateTime &newDate )
 {
     QWriteLocker locker( &m_trackLock );
-    m_track->time_added = newDate.isValid() ? newDate.toTime_t() : 0;
+    m_track->time_added = newDate.isValid() ? newDate.toSecsSinceEpoch() : 0;
     commitIfInNonBatchUpdate( Meta::valCreateDate, newDate );
 }
 
@@ -461,14 +461,14 @@ Track::modifyDate() const
     time_t time = m_track->time_modified;
     if( time == 0 )
         return QDateTime();  // 0 means "no reasonable time", so return invalid QDateTime
-    return QDateTime::fromTime_t( time );
+    return QDateTime::fromSecsSinceEpoch( time );
 }
 
 void
 Track::setModifyDate( const QDateTime &newDate )
 {
     // this method _cannot_ lock m_trackLock or deadlock will occur in commitChanges()
-    m_track->time_modified = newDate.isValid() ? newDate.toTime_t() : 0;
+    m_track->time_modified = newDate.isValid() ? newDate.toSecsSinceEpoch() : 0;
 }
 
 int
@@ -504,14 +504,14 @@ Track::setDiscNumber( int newDiscNumber )
 QDateTime
 Track::lastPlayed() const
 {
-    return m_track->time_played ? QDateTime::fromTime_t( m_track->time_played ) : QDateTime();
+    return m_track->time_played ? QDateTime::fromSecsSinceEpoch( m_track->time_played ) : QDateTime();
 }
 
 void
 Track::setLastPlayed( const QDateTime &time )
 {
     QWriteLocker locker( &m_trackLock );
-    m_track->time_played = time.isValid() ? time.toTime_t() : 0;
+    m_track->time_played = time.isValid() ? time.toSecsSinceEpoch() : 0;
     commitIfInNonBatchUpdate( Meta::valLastPlayed, time );
 }
 
@@ -520,14 +520,14 @@ Track::firstPlayed() const
 {
     // we abuse time_released for this, which should be okay for non-podcast tracks
     // TODO: return QDateTime for podcast tracks
-    return m_track->time_released ? QDateTime::fromTime_t( m_track->time_released ) : QDateTime();
+    return m_track->time_released ? QDateTime::fromSecsSinceEpoch( m_track->time_released ) : QDateTime();
 }
 
 void
 Track::setFirstPlayed( const QDateTime &time )
 {
     QWriteLocker locker( &m_trackLock );
-    m_track->time_released = time.isValid() ? time.toTime_t() : 0;
+    m_track->time_released = time.isValid() ? time.toSecsSinceEpoch() : 0;
     commitIfInNonBatchUpdate( Meta::valFirstPlayed, time );
 }
 
@@ -630,7 +630,7 @@ Track::collection() const
 Meta::TrackEditorPtr
 Track::editor()
 {
-    return Meta::TrackEditorPtr( isEditable() ? this : 0 );
+    return Meta::TrackEditorPtr( isEditable() ? this : nullptr );
 }
 
 Meta::StatisticsPtr
@@ -660,14 +660,14 @@ Track::itdbTrack() const
 bool
 Track::finalizeCopying( const gchar *mountPoint, const gchar *filePath )
 {
-    GError *error = 0;
+    GError *error = nullptr;
     // we cannot use m_mountPoint, we are not yet in collection
     Itdb_Track *res = itdb_cp_finalize( m_track, mountPoint, filePath, &error );
     if( error )
     {
         warning() << "Failed to finalize copying of iPod track:" << error->message;
         g_error_free( error );
-        error = 0;
+        error = nullptr;
     }
     return res == m_track;
 }
@@ -733,9 +733,9 @@ Track::commitIfInNonBatchUpdate()
     // it would only be confusing to the user as the changes would get discarded.
     if( !m_coll || !m_coll->isWritable() )
         return;
-
+    const QList<long long int> changedfieldkeys=m_changedFields.keys();
     if( AmarokConfig::writeBackStatistics() ||
-        !(QSet<qint64>::fromList( m_changedFields.keys() ) - statFields).isEmpty() )
+        !(QSet<qint64>( changedfieldkeys.begin(), changedfieldkeys.end() ) - statFields).isEmpty() )
     {
         setModifyDate( QDateTime::currentDateTime() );
     }
