@@ -24,8 +24,6 @@
 #include "core-impl/collections/mediadevicecollection/support/MediaDeviceInfo.h"
 #include "core-impl/collections/support/MemoryQueryMaker.h"
 
-#include <KDiskFreeSpaceInfo>
-
 using namespace Collections;
 
 MediaDeviceCollectionFactoryBase::MediaDeviceCollectionFactoryBase( ConnectionAssistant* assistant )
@@ -57,7 +55,7 @@ MediaDeviceCollectionFactoryBase::init()
 
 void MediaDeviceCollectionFactoryBase::slotDeviceDetected(MediaDeviceInfo* info)
 {
-    MediaDeviceCollection* coll = 0;
+    MediaDeviceCollection* coll = nullptr;
     // If device not already connected to
     if( !m_collectionMap.contains( info->udi() ) )
     {
@@ -105,7 +103,7 @@ MediaDeviceCollectionFactoryBase::slotDeviceDisconnected( const QString &udi )
 
 MediaDeviceCollection::MediaDeviceCollection()
     : Collection()
-    , m_ejectAction( 0 )
+    , m_ejectAction( nullptr )
     , m_mc( new MemoryCollection() )
 {
     connect( this, &MediaDeviceCollection::attemptConnectionDone,
@@ -205,7 +203,7 @@ MediaDeviceCollection::createCapabilityInterface( Capabilities::Capability::Type
                 return new Capabilities::ActionsCapability( actions );
             }
         default:
-            return 0;
+            return nullptr;
     }
 }
 
