@@ -89,8 +89,7 @@ QThreadStorage< ThreadInitializer* > ThreadInitializer::storage;
 
 MySqlStorage::MySqlStorage()
     : SqlStorage()
-    , m_db( 0 )
-    , m_mutex( QMutex::Recursive )
+    , m_db( nullptr )
     , m_debugIdent( "MySQL-none" )
 {
     //Relevant code must be implemented in subclasses
