@@ -121,10 +121,16 @@ PodcastImageFetcher::run()
 
     foreach( Podcasts::PodcastChannelPtr channel, m_channels )
     {
+        QUrl channelImageUrl = channel->imageUrl();
+        // KIO::file_copy in KF5 needs scheme
+        if (channelImageUrl.isRelative() && channelImageUrl.host().isEmpty()) {
+            channelImageUrl.setScheme("file");
+        }
+
         QUrl cachedPath = cachedImagePath( channel );
         KIO::mkdir( cachedPath.adjusted(QUrl::RemoveFilename|QUrl::StripTrailingSlash) );
-        KIO::FileCopyJob *job = KIO::file_copy( channel->imageUrl(), cachedPath,
-                                -1, KIO::HideProgressInfo | KIO::Overwrite );
+        KIO::FileCopyJob *job = KIO::file_copy(channelImageUrl, cachedPath,
+                                               -1, KIO::HideProgressInfo | KIO::Overwrite );
         //remove channel from the todo list
         m_channels.removeAll( channel );
         m_jobChannelMap.insert( job, channel );
