@@ -24,7 +24,7 @@
 #include <KConfigCore/KConfigGroup>
 
 #include <QApplication>
-#include <QMutex>
+#include <QRecursiveMutex>
 #include <QObject>
 
 #include <iostream>
@@ -37,7 +37,7 @@
 
 #define DEBUG_INDENT_OBJECTNAME QLatin1String("Debug_Indent_object")
 
-AMAROKCORE_EXPORT QMutex Debug::mutex( QMutex::Recursive );
+AMAROKCORE_EXPORT QRecursiveMutex Debug::mutex;
 
 using namespace Debug;
 
@@ -60,7 +60,7 @@ IndentPrivate::IndentPrivate(QObject* parent)
 IndentPrivate* IndentPrivate::instance()
 {
     QObject* qOApp = reinterpret_cast<QObject*>(qApp);
-    QObject* obj = qOApp ? qOApp->findChild<QObject*>( DEBUG_INDENT_OBJECTNAME ) : 0;
+    QObject* obj = qOApp ? qOApp->findChild<QObject*>( DEBUG_INDENT_OBJECTNAME ) : nullptr;
     return (obj ? static_cast<IndentPrivate*>( obj ) : new IndentPrivate( qApp ));
 }
 
@@ -221,5 +221,5 @@ Block::~Block()
 void Debug::stamp()
 {
     static int n = 0;
-    debug() << "| Stamp: " << ++n << endl;
+    debug() << "| Stamp: " << ++n << Qt::endl;
 }
