@@ -16,7 +16,7 @@
 
 #include "TranscodingAacFormat.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QVariant>
 
@@ -25,7 +25,7 @@ using namespace Transcoding;
 AacFormat::AacFormat()
 {
     m_encoder = AAC;
-    m_fileExtension = "m4a";
+    m_fileExtension = QStringLiteral("m4a");
     QString description1 =
         i18n( "The bitrate is a measure of the quantity of data used to represent a "
               "second of the audio track.<br>"
@@ -67,17 +67,17 @@ AacFormat::description() const
                   "It is a reasonable choice for the iPod and some other portable music players." );
 }
 
-KIcon
+QIcon
 AacFormat::icon() const
 {
-    return KIcon( "audio-x-mpeg" ); //TODO: get a *real* icon!
+    return QIcon::fromTheme( QStringLiteral("audio-ac3") ); //TODO: get a *real* icon!
 }
 
 QStringList
 AacFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
-    parameters << "-acodec" << "aac" << "-strict" << "-2";
+    parameters << QStringLiteral("-acodec") << QStringLiteral("aac") << QStringLiteral("-strict") << QStringLiteral("-2");
     foreach( const Property &property, m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
@@ -85,12 +85,12 @@ AacFormat::ffmpegParameters( const Configuration &configuration ) const
         {
             if( property.name() == "bitrate" )
             {
-                parameters << "-b:a"
+                parameters << QStringLiteral("-b:a")
                            << QString::number( ( configuration.property( "bitrate" ).toInt() + 1 ) * 32000);
             }
         }
     }
-    parameters << "-vn"; // no album art, writing it to m4a is not supported by ffmpeg
+    parameters << QStringLiteral("-vn"); // no album art, writing it to m4a is not supported by ffmpeg
     return parameters;
 }
 
