@@ -16,7 +16,7 @@
 
 #include "TranscodingFlacFormat.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QVariant>
 
@@ -25,8 +25,8 @@ using namespace Transcoding;
 FlacFormat::FlacFormat()
 {
     m_encoder = FLAC;
-    m_fileExtension = "flac";
-    QString description1 =
+    m_fileExtension = QStringLiteral("flac");
+    const QString description1 =
             i18n( "The <a href=http://flac.sourceforge.net/documentation_tools_flac.html>"
             "compression level</a> is an integer value between 0 and 8 that represents "
             "the tradeoff between file size and compression speed while encoding with <b>FLAC</b>.<br/> "
@@ -60,17 +60,17 @@ FlacFormat::description() const
                   "without compromising on audio quality, FLAC is an excellent choice." );
 }
 
-KIcon
+QIcon
 FlacFormat::icon() const
 {
-    return KIcon( "audio-x-flac" ); //TODO: get a *real* icon!
+    return QIcon::fromTheme( QStringLiteral("audio-x-flac") ); //TODO: get a *real* icon!
 }
 
 QStringList
 FlacFormat::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
-    parameters << "-acodec" << "flac";
+    parameters << QStringLiteral("-acodec") << QStringLiteral("flac");
     foreach( const Property &property, m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
@@ -78,17 +78,17 @@ FlacFormat::ffmpegParameters( const Configuration &configuration ) const
         {
             if( property.name() == "level" )
             {
-                parameters << "-compression_level"
+                parameters << QStringLiteral("-compression_level")
                            << QString::number( configuration.property( "level" ).toInt() );
             }
         }
     }
-    parameters << "-vn"; // no album art, writing it to flac is not supported by ffmpeg
+    parameters << QStringLiteral("-vn"); // no album art, writing it to flac is not supported by ffmpeg
     return parameters;
 }
 
 bool
 FlacFormat::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( "^ .EA... flac +" ) );
+    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... flac +") ) );
 }
