@@ -16,15 +16,15 @@
 
 #include "TranscodingMp3Format.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace Transcoding;
 
 Mp3Format::Mp3Format()
 {
     m_encoder = MP3;
-    m_fileExtension = "mp3";
-    QString description1 =
+    m_fileExtension = QStringLiteral("mp3");
+    const QString description1 =
         i18n( "The bitrate is a measure of the quantity of data used to represent a "
         "second of the audio track.<br>The <b>MP3</b> encoder used by Amarok supports "
         "a <a href=http://en.wikipedia.org/wiki/MP3#VBR>variable bitrate (VBR)</a> "
@@ -74,17 +74,17 @@ Mp3Format::description() const
                   "audio storage, and is widely supported on portable music players." );
 }
 
-KIcon
+QIcon
 Mp3Format::icon() const
 {
-    return KIcon( "audio-x-mpeg" );  //TODO: get a *real* icon!
+    return QIcon::fromTheme( QStringLiteral("audio-x-generic") );  //TODO: get a *real* icon!
 }
 
 QStringList
 Mp3Format::ffmpegParameters( const Configuration &configuration ) const
 {
     QStringList parameters;
-    parameters << "-acodec" << "libmp3lame";
+    parameters << QStringLiteral("-acodec") << QStringLiteral("libmp3lame");
     foreach( const Property &property, m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
@@ -93,16 +93,16 @@ Mp3Format::ffmpegParameters( const Configuration &configuration ) const
             if( property.name() == "quality" )
             {
                 int ffmpegQuality = qAbs( configuration.property( "quality" ).toInt() - 9 );
-                parameters << "-aq" << QString::number( ffmpegQuality );
+                parameters << QStringLiteral("-aq") << QString::number( ffmpegQuality );
             }
         }
     }
-    parameters << "-vcodec" << "copy"; // keep album art unchanged
+    parameters << QStringLiteral("-vcodec") << QStringLiteral("copy"); // keep album art unchanged
     return parameters;
 }
 
 bool
 Mp3Format::verifyAvailability( const QString &ffmpegOutput ) const
 {
-    return ffmpegOutput.contains( QRegExp( "^ .EA... mp3 +.*libmp3lame" ) );
+    return ffmpegOutput.contains( QRegExp( QStringLiteral("^ .EA... mp3 +.*libmp3lame") ) );
 }
