@@ -39,11 +39,11 @@
 
 #include <QAction>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QMenu>    //showCoverMenu()
 #include <QProgressBar>
 #include <QPushButton>
+#include <QScreen>
 #include <QSplitter>
 #include <QStatusBar>
 #include <QStringList>
@@ -74,7 +74,7 @@ class ArtistItem : public QTreeWidgetItem
 
         ArtistItem( const QString &text, QTreeWidget *parent = nullptr )
             : QTreeWidgetItem( parent )
-            , m_artist( 0 )
+            , m_artist( nullptr )
         {
             setText( 0, text );
         }
@@ -130,9 +130,9 @@ CoverManager::CoverManager( QWidget *parent )
     m_artistView->setUniformRowHeights( true );
     m_artistView->setSelectionMode( QAbstractItemView::ExtendedSelection );
 
-    ArtistItem *item = 0;
+    ArtistItem *item = nullptr;
     item = new ArtistItem( i18n( "All Artists" ) );
-    item->setIcon(0, SmallIcon( "media-optical-audio-amarok" ) );
+    item->setIcon(0, QIcon::fromTheme( "media-optical-audio-amarok" ) );
     m_items.append( item );
 
     Collections::Collection *coll = CollectionManager::instance()->primaryCollection();
@@ -165,7 +165,7 @@ CoverManager::slotContinueConstruction() //SLOT
     foreach( Meta::ArtistPtr artist, m_artistList )
     {
         ArtistItem* item = new ArtistItem( m_artistView, artist );
-        item->setIcon( 0, SmallIcon( "view-media-artist-amarok" ) );
+        item->setIcon( 0, QIcon::fromTheme( "view-media-artist-amarok" ) );
         m_items.append( item );
     }
     m_artistView->insertTopLevelItems( 0, m_items );
@@ -228,7 +228,7 @@ CoverManager::slotContinueConstruction() //SLOT
 
     connect( m_progress, &CompoundProgressBar::allDone, this, &CoverManager::progressAllDone );
 
-    QSize size = QApplication::desktop()->screenGeometry( this ).size() / 1.5;
+    QSize size = this->screen()->size() / 1.5;
     QSize sz = Amarok::config( "Cover Manager" ).readEntry( "Window Size", size );
     resize( sz.width(), sz.height() );
 
@@ -237,7 +237,7 @@ CoverManager::slotContinueConstruction() //SLOT
 
     m_fetcher = The::coverFetcher();
 
-    QTreeWidgetItem *item = 0;
+    QTreeWidgetItem *item = nullptr;
     int i = 0;
     if ( !artistToSelectInInitFunction.isEmpty() )
     {
@@ -260,7 +260,7 @@ CoverManager::slotContinueConstruction() //SLOT
     connect( m_searchEdit, &Amarok::LineEdit::textChanged,
              this, &CoverManager::slotSetFilterTimeout );
 
-    if( item == 0 )
+    if( item == nullptr )
         item = m_artistView->invisibleRootItem()->child( 0 );
 
     item->setSelected( true );
@@ -272,7 +272,7 @@ CoverManager::~CoverManager()
     Amarok::config( "Cover Manager" ).writeEntry( "Window Size", size() );
     qDeleteAll( m_coverItems );
     delete m_coverView;
-    m_coverView = 0;
+    m_coverView = nullptr;
     s_instance = nullptr;
 }
 
