@@ -25,9 +25,9 @@
 
 #include "DBusAbstractAdaptor.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QMetaClassInfo>
-#include <QtDBus/QDBusMessage>
+#include <QDebug>
+#include <QMetaClassInfo>
+#include <QDBusMessage>
 
 #include "core/support/Debug.h"
 
@@ -93,8 +93,8 @@ void DBusAbstractAdaptor::_m_emitPropertiesChanged()
         warning() << "MPRIS2: No D-Bus interface given (missing Q_CLASSINFO)";
     } else {
         QDBusMessage signal = QDBusMessage::createSignal( m_path,
-             "org.freedesktop.DBus.Properties",
-             "PropertiesChanged" );
+             QStringLiteral("org.freedesktop.DBus.Properties"),
+             QStringLiteral("PropertiesChanged") );
         signal << metaObject()->classInfo( ifaceIndex ).value();
         signal << m_updatedProperties;
         signal << m_invalidatedProperties;
