@@ -28,7 +28,7 @@
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 QString
 Dynamic::IfElseBiasFactory::i18nName() const
@@ -57,7 +57,7 @@ Dynamic::IfElseBias::IfElseBias()
 QString
 Dynamic::IfElseBias::sName()
 {
-    return QLatin1String( "ifElseBias" );
+    return QStringLiteral( "ifElseBias" );
 }
 
 QString
@@ -84,7 +84,7 @@ Dynamic::IfElseBias::paintOperator( QPainter* painter, const QRect& rect, Dynami
 Dynamic::TrackSet
 Dynamic::IfElseBias::matchingTracks( const Meta::TrackList& playlist,
                                      int contextCount, int finalCount,
-                                     Dynamic::TrackCollectionPtr universe ) const
+                                     const Dynamic::TrackCollectionPtr &universe ) const
 {
     // store the parameters in case we need to request additional matching tracks later
     m_playlist = playlist;
@@ -125,7 +125,7 @@ Dynamic::IfElseBias::resultReceived( const Dynamic::TrackSet &tracks )
     removeDuplicate();
     if( !m_tracks.isEmpty() )
     {
-        emit resultReady( m_tracks );
+        Q_EMIT resultReady( m_tracks );
         return;
     }
 
@@ -155,12 +155,12 @@ Dynamic::IfElseBias::resultReceived( const Dynamic::TrackSet &tracks )
         {
             removeDuplicate();
             if( !m_tracks.isEmpty() ) {
-                emit resultReady( m_tracks );
+                Q_EMIT resultReady( m_tracks );
                 return;
             }
         }
     }
-    emit resultReady( m_tracks );
+    Q_EMIT resultReady( m_tracks );
 }
 
 // we need to eliminate duplicates now to have a proper check for an empty result
@@ -175,5 +175,4 @@ Dynamic::IfElseBias::removeDuplicate() const
             m_tracks.subtract( m_playlist[i] );
 }
 
-#include "IfElseBias.moc"
 
