@@ -25,7 +25,7 @@
 #include "widgets/SliderWidget.h"
 
 #include <KLocalizedString>
-#include <KRandom>
+#include <QRandomGenerator>
 
 #include <QtGlobal> // for qRound
 #include <QApplication>
@@ -249,7 +249,7 @@ Dynamic::PartBiasWidget::biasAppended( Dynamic::BiasPtr bias )
 {
     int index = m_bias->biases().indexOf( bias );
 
-    Amarok::Slider* slider = 0;
+    Amarok::Slider* slider = nullptr;
     slider = new Amarok::Slider( Qt::Horizontal, 100 );
     slider->setValue( m_bias->weights()[ m_bias->biases().indexOf( bias ) ] * 100.0 );
     slider->setToolTip( i18n( "This controls what portion of the playlist should match the criteria" ) );
@@ -481,7 +481,7 @@ Dynamic::PartBias::updateResults() const
     // if we have some biases under-represented
     if( missingCapacity > 0 )
     {
-        int random = KRandom::random() % missingCapacity;
+        int random = QRandomGenerator::global()->generate() % missingCapacity;
         for( int source = 0; source < state.m_sourceCount; source++ )
         {
             // debug() << "PartBias::matchingTracks: biase"<<m_biases[source]->toString()<<"matches"<<state.m_sourceFlow[source]<<"out of"<<state.m_sourceCapacity[source]<<"tracks.";
