@@ -27,7 +27,7 @@
 #include "core-impl/collections/support/TextualQueryFilter.h"
 #include "dynamic/TrackSet.h"
 
-#include <KLineEdit>
+#include <QLineEdit>
 
 #include <QLabel>
 #include <QCheckBox>
@@ -58,7 +58,7 @@ Dynamic::SearchQueryBiasFactory::createBias()
 
 // ----- SearchQueryBias --------
 
-Dynamic::SearchQueryBias::SearchQueryBias( QString filter )
+Dynamic::SearchQueryBias::SearchQueryBias( const QString &filter )
     : SimpleMatchBias()
     , m_filter( filter )
 { }
@@ -92,13 +92,13 @@ Dynamic::SearchQueryBias::fromXml( QXmlStreamReader *reader )
 void
 Dynamic::SearchQueryBias::toXml( QXmlStreamWriter *writer ) const
 {
-    writer->writeTextElement( "filter", m_filter );
+    writer->writeTextElement( QStringLiteral("filter"), m_filter );
 }
 
 QString
 Dynamic::SearchQueryBias::sName()
 {
-    return QLatin1String( "searchQueryBias" );
+    return QStringLiteral( "searchQueryBias" );
 }
 
 QString
@@ -124,11 +124,11 @@ Dynamic::SearchQueryBias::widget( QWidget* parent )
     QWidget *widget = new QWidget( parent );
     QVBoxLayout *layout = new QVBoxLayout( widget );
 
-    KLineEdit *edit = new KLineEdit( m_filter );
+    QLineEdit *edit = new QLineEdit( m_filter );
     layout->addWidget( edit );
 
-    connect( edit, SIGNAL(textChanged(QString)),
-             this, SLOT(setFilter(QString)) );
+    connect( edit, &QLineEdit::textChanged,
+             this, &SearchQueryBias::setFilter );
 
     return widget;
 }
@@ -148,7 +148,7 @@ Dynamic::SearchQueryBias::setFilter( const QString &filter )
 
     m_filter = filter;
     invalidate();
-    emit changed( BiasPtr(this) );
+    Q_EMIT changed( BiasPtr(this) );
 }
 
 void
@@ -162,12 +162,11 @@ Dynamic::SearchQueryBias::newQuery()
     m_qm->setQueryType( Collections::QueryMaker::Custom );
     m_qm->addReturnValue( Meta::valUniqueId );
 
-    connect( m_qm.data(), SIGNAL(newResultReady(QStringList)),
-             this, SLOT(updateReady(QStringList)), Qt::QueuedConnection );
-    connect( m_qm.data(), SIGNAL(queryDone()),
-             this, SLOT(updateFinished()), Qt::QueuedConnection );
+    connect( m_qm.data(), &Collections::QueryMaker::newResultReady,
+             this, &SearchQueryBias::updateReady, Qt::QueuedConnection );
+    connect( m_qm.data(), &Collections::QueryMaker::queryDone,
+             this, &SearchQueryBias::updateFinished, Qt::QueuedConnection );
     m_qm.data()->run();
 }
 
-#include "SearchQueryBias.moc"
 
