@@ -351,25 +351,38 @@ Dynamic::TagMatchBias::newQuery()
             m_qm->addNumberFilter( m_filter.field(), QDateTime::currentDateTimeUtc().toSecsSinceEpoch() - m_filter.numValue,
                                 Collections::QueryMaker::LessThan );
             break;
+        case MetaQueryWidget::NewerThan:
+            m_qm->addNumberFilter( m_filter.field(), QDateTime::currentDateTimeUtc().toSecsSinceEpoch() - m_filter.numValue,
+                                Collections::QueryMaker::GreaterThan );
+            break;
         default:
             ;
         }
     }
     else if( m_filter.isNumeric() )
     {
+        qint64 nval1 = m_filter.numValue;
+        qint64 nval2 = m_filter.numValue2;
+        if( m_filter.field() == Meta::valLength )
+        {
+            // Length is msecs in database, corresponding conversion done in TextualQueryFilter.cpp:157
+            // BUG 375565
+            nval1 = nval1 * 1000;
+            nval2 = nval2 * 1000;
+        }
         switch( m_filter.condition )
         {
         case MetaQueryWidget::LessThan:
         case MetaQueryWidget::Equals:
         case MetaQueryWidget::GreaterThan:
-            m_qm->addNumberFilter( m_filter.field(), m_filter.numValue,
+            m_qm->addNumberFilter( m_filter.field(), nval1,
                                 (Collections::QueryMaker::NumberComparison)m_filter.condition );
             break;
         case MetaQueryWidget::Between:
             m_qm->beginAnd();
-            m_qm->addNumberFilter( m_filter.field(), qMin(m_filter.numValue, m_filter.numValue2)-1,
+            m_qm->addNumberFilter( m_filter.field(), qMin(nval1, nval2)-1,
                                 Collections::QueryMaker::GreaterThan );
-            m_qm->addNumberFilter( m_filter.field(), qMax(m_filter.numValue, m_filter.numValue2)+1,
+            m_qm->addNumberFilter( m_filter.field(), qMax(nval1, nval2)+1,
                                 Collections::QueryMaker::LessThan );
             m_qm->endAndOr();
             break;
@@ -429,6 +442,7 @@ Dynamic::TagMatchBias::nameForCondition( MetaQueryWidget::FilterCondition cond )
     case MetaQueryWidget::LessThan:    return QStringLiteral("less");
     case MetaQueryWidget::Between:     return QStringLiteral("between");
     case MetaQueryWidget::OlderThan:   return QStringLiteral("older");
+    case MetaQueryWidget::NewerThan:   return QStringLiteral("newer");
     case MetaQueryWidget::Contains:    return QStringLiteral("contains");
     default:
         ;// the other conditions are only for the advanced playlist generator
@@ -444,6 +458,7 @@ Dynamic::TagMatchBias::conditionForName( const QString &name )
     else if( name == QLatin1String("less") )     return MetaQueryWidget::LessThan;
     else if( name == QLatin1String("between") )  return MetaQueryWidget::Between;
     else if( name == QLatin1String("older") )    return MetaQueryWidget::OlderThan;
+    else if( name == QLatin1String("newer") )    return MetaQueryWidget::NewerThan;
     else if( name == QLatin1String("contains") ) return MetaQueryWidget::Contains;
     else return MetaQueryWidget::Equals;
 }
@@ -474,6 +489,9 @@ Dynamic::TagMatchBias::matches( const Meta::TrackPtr &track ) const
         case MetaQueryWidget::OlderThan:
             result = value.toLongLong() < m_filter.numValue + QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
             break;
+        case MetaQueryWidget::NewerThan:
+            result = value.toLongLong() > m_filter.numValue + QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+            break;
         default:
             ;
         }
