@@ -20,7 +20,7 @@
 #include "amarokconfig.h"
 #include "core/support/Debug.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #define NUM_EQ_VALUES 11
 
@@ -122,12 +122,12 @@ EqualizerPresets::eqGlobalList()
 QStringList
 EqualizerPresets::eqUserList()
 {
-    QStringList defaultList = eqDefaultPresetsList();
+    const QStringList defaultList = eqDefaultPresetsList();
 
     QStringList userList;
     foreach( const QString &mUsrName, AmarokConfig::equalizerPresetsNames() )
     {
-        if( defaultList.indexOf( mUsrName ) < 0 )
+        if( !defaultList.contains( mUsrName ) )
             userList.append( mUsrName );
     }
     return userList;
@@ -227,7 +227,7 @@ QList<int>
 EqualizerPresets::eqCfgGetPresetVal( const QString &presetName )
 {
       // Idea is to return user preset with request name first
-      // if not look into into default preset names
+      // if not look into the default preset names
       const int idUsr = AmarokConfig::equalizerPresetsNames().indexOf( presetName );
       const int idDef = eqDefaultPresetsList().indexOf( presetName );
 
