@@ -35,10 +35,6 @@
 #include <QtWebEngine>
 #endif
 
-#ifdef Q_WS_X11
-#include <X11/Xlib.h>
-#endif
-
 #include <csignal>
 
 #ifdef Q_OS_WIN
@@ -383,11 +379,6 @@ int main( int argc, char *argv[] )
     signal( SIGINT, &QCoreApplication::exit );
     signal( SIGTERM, &QCoreApplication::exit );
 
-    // This call is needed to prevent a crash on exit with Phonon-VLC and LibPulse
-#ifdef Q_WS_X11
-    XInitThreads();
-#endif
-
     app.continueInit();
     return app.exec();
 }
