@@ -30,7 +30,7 @@ class MusicBrainzFinder : public QObject
     Q_OBJECT
 
     public:
-        explicit MusicBrainzFinder( QObject *parent = 0,
+        explicit MusicBrainzFinder( QObject *parent = nullptr,
                                     const QString &host = "musicbrainz.org",
                                     const int port = 80,
                                     const QString &pathPrefix = "/ws/2",
@@ -39,23 +39,23 @@ class MusicBrainzFinder : public QObject
 
         bool isRunning() const;
 
-    signals:
+    Q_SIGNALS:
         void progressStep();
         void trackFound( const Meta::TrackPtr track, const QVariantMap tags );
         void done();
 
-    public slots:
+    public Q_SLOTS:
         void run( const Meta::TrackList &tracks );
 
         void lookUpByPUID( const Meta::TrackPtr &track, const QString &puid );
 
-    private slots:
+    private Q_SLOTS:
         void sendNewRequest();
         void gotAuthenticationRequest( const QNetworkReply *reply, QAuthenticator *authenticator );
         void gotReplyError( QNetworkReply::NetworkError code );
         void gotReply( QNetworkReply *reply );
 
-        void parsingDone( ThreadWeaver::Job *_parser );
+        void parsingDone( ThreadWeaver::JobPointer _parser );
 
     private:
         QVariantMap guessMetadata( const Meta::TrackPtr &track ) const;
