@@ -34,18 +34,23 @@ PlaylistQueueEditor::PlaylistQueueEditor()
 {
     m_ui.setupUi( this );
     updateView();
-    connect( qobject_cast<Playlist::Model*>(The::playlist()->qaim()), &Playlist::Model::queueChanged, this, &PlaylistQueueEditor::queueChanged );
+    connect( qobject_cast<Playlist::ProxyBase*>(The::playlist()->qaim()), &Playlist::ProxyBase::queueChanged, this, &PlaylistQueueEditor::queueChanged );
     m_ui.upButton->setIcon( QIcon::fromTheme( QStringLiteral("go-up") ) );
     m_ui.downButton->setIcon( QIcon::fromTheme( QStringLiteral("go-down") ) );
     m_ui.dequeueTrackButton->setIcon( QIcon::fromTheme( QStringLiteral("list-remove") ) );
     m_ui.clearButton->setIcon( QIcon::fromTheme( QStringLiteral("edit-clear-list") ) );
+    m_ui.listWidget->setDragEnabled( true );
+    m_ui.listWidget->setDragDropMode( QAbstractItemView::InternalMove );
     connect( m_ui.upButton, &QAbstractButton::clicked, this, &PlaylistQueueEditor::moveUp );
     connect( m_ui.downButton, &QAbstractButton::clicked, this, &PlaylistQueueEditor::moveDown );
     connect( m_ui.clearButton, &QAbstractButton::clicked, this, &PlaylistQueueEditor::clear );
     connect( m_ui.dequeueTrackButton, &QAbstractButton::clicked, this, &PlaylistQueueEditor::dequeueTrack );
     connect( m_ui.buttonBox->buttons().first(), &QAbstractButton::clicked, this, &PlaylistQueueEditor::accept );
+    connect( m_ui.listWidget->model(), &QAbstractItemModel::rowsMoved, this, &PlaylistQueueEditor::updateQueueFromList );
 }
 
+
+
 void
 PlaylistQueueEditor::updateView()
 {
@@ -143,3 +148,18 @@ PlaylistQueueEditor::clear()
     m_blockViewUpdates = false;
     updateView();
 }
+
+void
+PlaylistQueueEditor::updateQueueFromList()
+{
+    m_blockViewUpdates = true;
+    for( int i = 0; i < m_ui.listWidget->count(); i++ )
+    {
+        bool ok;
+        quint64 id = m_ui.listWidget->item(i)->data( s_idRole ).toULongLong( &ok );
+        if( ok )
+            The::playlistActions()->queueMoveTo( id, i );
+    }
+    m_blockViewUpdates = false;
+    updateView();
+}
