@@ -22,7 +22,7 @@
 #include "proxymodels/SortScheme.h"
 
 #include <KConfigGroup>
-#include <KStandardDirs>
+#include <QStandardPaths>
 
 namespace Playlist
 {
@@ -39,11 +39,11 @@ SortWidget::SortWidget( QWidget *parent )
     m_layout->setContentsMargins( 0, 0, 0, 0 );
 
     BreadcrumbItemButton *rootItem = new BreadcrumbItemButton(
-            KIcon( QPixmap( KStandardDirs::locate( "data", "amarok/images/playlist-sorting-16.png" ) ) ),
+            QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/playlist-sorting-16.png" ) ) ),
             QString(), this );
     rootItem->setToolTip( i18n( "Clear the playlist sorting configuration." ) );
     m_layout->addWidget( rootItem );
-    connect( rootItem, SIGNAL(clicked()), this, SLOT(trimToLevel()) );
+    connect( rootItem, &BreadcrumbItemButton::clicked, this, &SortWidget::trimToLevel );
 
     m_ribbon = new QHBoxLayout();
     m_layout->addLayout( m_ribbon );
@@ -55,13 +55,15 @@ SortWidget::SortWidget( QWidget *parent )
     m_layout->addWidget( m_addButton );
     m_layout->addStretch( 10 );
 
-    m_urlButton = new BreadcrumbUrlMenuButton( "playlist", this );
+    m_urlButton = new BreadcrumbUrlMenuButton( QStringLiteral("playlist"), this );
     m_layout->addWidget( m_urlButton );
 
-    connect( m_addButton->menu(), SIGNAL(actionClicked(QString)), this, SLOT(addLevel(QString)) );
-    connect( m_addButton->menu(), SIGNAL(shuffleActionClicked()), The::playlistActions(), SLOT(shuffle()) );
+    connect( m_addButton->menu(), &BreadcrumbItemMenu::actionClicked,
+             this, &SortWidget::addLevelAscending );
+    connect( m_addButton->menu(), &BreadcrumbItemMenu::shuffleActionClicked,
+             The::playlistActions(), &Actions::shuffle );
 
-    QString sortPath = Amarok::config( "Playlist Sorting" ).readEntry( "SortPath", QString() );
+    QString sortPath = Amarok::config( QStringLiteral("Playlist Sorting") ).readEntry( "SortPath", QString() );
     readSortPath( sortPath );
 }
 
@@ -69,21 +71,27 @@ SortWidget::~SortWidget()
 {}
 
 void
-SortWidget::addLevel( QString internalColumnName, Qt::SortOrder sortOrder )  //private slot
+SortWidget::addLevel( const QString &internalColumnName, Qt::SortOrder sortOrder )  //private slot
 {
     BreadcrumbLevel *bLevel = new BreadcrumbLevel( internalColumnName );
     BreadcrumbItem *item = new BreadcrumbItem( bLevel, this );
     m_ribbon->addWidget( item );
-    connect( item, SIGNAL(clicked()), this, SLOT(onItemClicked()) );
-    connect( item->menu(), SIGNAL(actionClicked(QString)), this, SLOT(onItemSiblingClicked(QString)) );
-    connect( item->menu(), SIGNAL(shuffleActionClicked()), this, SLOT(onShuffleSiblingClicked()) );
-    connect( item, SIGNAL(orderInverted()), this, SLOT(updateSortScheme()) );
+    connect( item, &BreadcrumbItem::clicked, this, &SortWidget::onItemClicked );
+    connect( item->menu(), &BreadcrumbItemMenu::actionClicked, this, &SortWidget::onItemSiblingClicked );
+    connect( item->menu(), &BreadcrumbItemMenu::shuffleActionClicked, this, &SortWidget::onShuffleSiblingClicked );
+    connect( item, &BreadcrumbItem::orderInverted, this, &SortWidget::updateSortScheme );
     if( sortOrder != item->sortOrder() )
         item->invertOrder();
     m_addButton->updateMenu( levels() );
     updateSortScheme();
 }
 
+void
+SortWidget::addLevelAscending ( const QString &internalColumnName )
+{
+    addLevel(internalColumnName, Qt::AscendingOrder);
+}
+
 void
 SortWidget::trimToLevel( const int level )
 {
@@ -114,7 +122,7 @@ SortWidget::onItemClicked()
 }
 
 void
-SortWidget::onItemSiblingClicked( QString internalColumnName )
+SortWidget::onItemSiblingClicked( const QString &internalColumnName )
 {
     const int level = m_ribbon->indexOf( qobject_cast< QWidget * >( sender()->parent() ) );
     trimToLevel( level - 1 );
@@ -142,7 +150,7 @@ SortWidget::updateSortScheme()
     }
     ModelStack::instance()->sortProxy()->updateSortMap( scheme );
 
-    KConfigGroup config = Amarok::config( "Playlist Sorting" );
+    KConfigGroup config = Amarok::config( QStringLiteral("Playlist Sorting") );
     config.writeEntry( "SortPath", sortPath() );
 }
 
@@ -165,7 +173,7 @@ SortWidget::readSortPath( const QString &sortPath )
 {
     trimToLevel();
 
-    QStringList levels = sortPath.split( '-' );
+    QStringList levels = sortPath.split( QLatin1Char('-') );
     foreach( const QString &level, levels )
     {
         QStringList levelParts = level.split( '_' );
@@ -180,9 +188,9 @@ SortWidget::readSortPath( const QString &sortPath )
         || ( Playlist::PlaylistColumnInfos::internalNames().
                            indexOf( levelParts.value(0) ) == -1) )
             warning() << "Playlist sorting load error: Invalid sort level " << level;
-        else if( levelParts.value( 1 ) == QString( "asc" ) )
+        else if( levelParts.value( 1 ) == QStringLiteral( "asc" ) )
             addLevel( levelParts.value( 0 ), Qt::AscendingOrder );
-        else if( levelParts.value( 1 ) == QString( "des" ) )
+        else if( levelParts.value( 1 ) == QStringLiteral( "des" ) )
             addLevel( levelParts.value( 0 ), Qt::DescendingOrder );
         else
             warning() << "Playlist sorting load error: Invalid sort order for level " << level;
@@ -195,7 +203,6 @@ SortWidget::prettySortPath() const
     QString prettyPath;
     for( int i = 0; i < m_ribbon->count(); ++i )    //could be faster if done with iterator
     {
-        QString name( qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->name() );
         QString prettyName( qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->prettyName() );
         Qt::SortOrder sortOrder = qobject_cast< BreadcrumbItem * >( m_ribbon->itemAt( i )->widget() )->sortOrder();
         QString prettyLevel = prettyName + ( sortOrder ? "↓" : "↑" );
