@@ -37,12 +37,12 @@ public:
     /**
      * Constructor.
      */
-    SortWidget( QWidget *parent );
+    explicit SortWidget( QWidget *parent );
 
     /**
      * Destructor.
      */
-    ~SortWidget();
+    ~SortWidget() override;
 
     /**
      * Returns the list of levels that are currently defined in the breadcrumb path.
@@ -56,7 +56,7 @@ public:
     QString sortPath() const;
 
     /**
-     * Generate current sort scheme from a sorth path stored in a QString.
+     * Generate current sort scheme from a sort path stored in a QString.
      */
     void readSortPath( const QString &sortPath );
 
@@ -65,7 +65,7 @@ public:
      */
     QString prettySortPath() const;
 
-public slots:
+public Q_SLOTS:
     /**
      * Generates a new sort scheme and forwards it to Playlist::SortProxy to apply it to
      * the playlist.
@@ -85,13 +85,20 @@ private:
     QHBoxLayout * m_layout;
     BreadcrumbUrlMenuButton *m_urlButton;
 
-private slots:
+private Q_SLOTS:
     /**
      * Adds a level to the breadcrumb path.
      * @param internalColumnName the name of the level.
      * @param sortOrder the Qt::SortOrder of the level.
      */
-    void addLevel( QString internalColumnName, Qt::SortOrder sortOrder = Qt::AscendingOrder );
+    void addLevel( const QString &internalColumnName, Qt::SortOrder sortOrder = Qt::AscendingOrder );
+
+    /**
+     * Adds a level to the breadcrumb path.
+     * Orders the level in ascending order.
+     * @param internalColumnName the name of the level.
+     */
+    void addLevelAscending( const QString &internalColumnName );
 
     /**
      * Handles the (possible) deletion of further levels when an item is clicked.
@@ -102,7 +109,7 @@ private slots:
      * Handles the rearrangement of the breadcrumb path when a sibling of an item is clicked.
      * @param action the action in the menu.
      */
-    void onItemSiblingClicked( QString internalColumnName );
+    void onItemSiblingClicked( const QString &internalColumnName );
 
     /**
      * Handles the rearrangement of the breadcrumb path when a Shuffle action is clicked.
