@@ -23,17 +23,17 @@
 #include "PlaylistSortWidget.h"
 #include "ProgressiveSearchWidget.h"
 
-#include <KLocale>
-#include <KStandardDirs>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 namespace Playlist
 {
 
-ViewUrlGenerator * ViewUrlGenerator::s_instance = 0;
+ViewUrlGenerator * ViewUrlGenerator::s_instance = nullptr;
 
 ViewUrlGenerator * ViewUrlGenerator::instance()
 {
-    if( s_instance == 0)
+    if( s_instance == nullptr)
         s_instance = new ViewUrlGenerator();
 
     return s_instance;
@@ -51,8 +51,8 @@ ViewUrlGenerator::createUrl()
 {
     DEBUG_BLOCK
     AmarokUrl url;
-    url.setCommand( "playlist" );
-    url.setPath( "view" );
+    url.setCommand( QStringLiteral("playlist") );
+    url.setPath( QStringLiteral("view") );
     Dock * playlistDock = The::mainWindow()->playlistDock();
 
     QString filterExpr = playlistDock->searchWidget()->currentFilter();
@@ -69,23 +69,23 @@ ViewUrlGenerator::createUrl()
 
     if( !sortPath.isEmpty() )
     {
-        url.setArg( "sort", sortPath );
+        url.setArg( QStringLiteral("sort"), sortPath );
         prettyUrlName.append( prettySortPath );
     }
     if( !filterExpr.isEmpty() )
     {
-        url.setArg( "filter", filterExpr );
-        url.setArg( "matches", onlyMatches );
+        url.setArg( QStringLiteral("filter"), filterExpr );
+        url.setArg( QStringLiteral("matches"), onlyMatches );
         if( !prettyUrlName.isEmpty() )
             prettyUrlName.append( "  |  " );
         QString prettyFilterExpr = "\"" + filterExpr + "\"";
-        prettyUrlName.append( ( onlyMatches == QString( "true" ) )
+        prettyUrlName.append( ( onlyMatches == QStringLiteral( "true" ) )
                               ? i18n( "Filter %1", prettyFilterExpr )
                               : i18n( "Search %1", prettyFilterExpr ) );
     }
     if( !layout.isEmpty() )
     {
-        url.setArg( "layout", layout );
+        url.setArg( QStringLiteral("layout"), layout );
         if( !prettyUrlName.isEmpty() )
             prettyUrlName.append( "  |  " );
         prettyUrlName.append( i18n( "%1 layout", layout ) );
@@ -102,9 +102,9 @@ ViewUrlGenerator::description()
     return i18n( "Bookmark Playlist Setup" );
 }
 
-KIcon ViewUrlGenerator::icon()
+QIcon ViewUrlGenerator::icon()
 {
-    return KIcon( QPixmap( KStandardDirs::locate( "data", "amarok/images/playlist-bookmark-16.png" ) ) );
+    return QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, "amarok/images/playlist-bookmark-16.png" ) ) );
 }
 
 } //namespace Playlist
