@@ -61,10 +61,10 @@ SqlPlaylist::~SqlPlaylist()
 {
 }
 
-KUrl
+QUrl
 SqlPlaylist::uidUrl() const
 {
-    return KUrl( QString( "amarok-sqlplaylistuid://%1").arg( m_dbId ) );
+    return QUrl( QStringLiteral( "amarok-sqlplaylistuid://%1").arg( m_dbId ) );
 }
 
 QStringList
@@ -102,7 +102,7 @@ SqlPlaylist::saveToDb( bool tracks )
     if( m_parent )
         parentId = m_parent->id();
 
-    SqlStorage *sql = StorageManager::instance()->sqlStorage();
+    auto sql = StorageManager::instance()->sqlStorage();
 
     //figure out if we have a urlId and if this id is already in the db, if so, update it instead of creating a new one.
     if( !m_urlId.isEmpty() )
@@ -110,7 +110,7 @@ SqlPlaylist::saveToDb( bool tracks )
         debug() << "Checking " << m_urlId << " against db";
 
         //check if urlId exists
-        QString query = "SELECT id from playlists WHERE urlid='%1'";
+        QString query = QStringLiteral("SELECT id from playlists WHERE urlid='%1'");
         query = query.arg( sql->escape( m_urlId ) );
         QStringList result = sql->query( query );
 
@@ -125,16 +125,16 @@ SqlPlaylist::saveToDb( bool tracks )
     if( m_dbId != -1 )
     {
         //update existing
-        QString query = "UPDATE playlists SET parent_id=%1, name='%2' WHERE id=%3;";
-        query = query.arg( QString::number( parentId ) )
-                .arg( sql->escape( m_name ) )
-                .arg( QString::number( m_dbId ) );
+        QString query = QStringLiteral("UPDATE playlists SET parent_id=%1, name='%2' WHERE id=%3;");
+        query = query.arg( QString::number( parentId ),
+                      sql->escape( m_name ),
+                      QString::number( m_dbId ) );
         StorageManager::instance()->sqlStorage()->query( query );
 
         if( tracks )
         {
             //delete existing tracks and insert all
-            query = "DELETE FROM playlist_tracks where playlist_id=%1;";
+            query = QStringLiteral("DELETE FROM playlist_tracks where playlist_id=%1;");
             query = query.arg( QString::number( m_dbId ) );
             StorageManager::instance()->sqlStorage()->query( query );
             saveTracks();
@@ -145,10 +145,10 @@ SqlPlaylist::saveToDb( bool tracks )
         //insert new
         QString query = "INSERT INTO playlists ( parent_id, name, urlid ) "
                         "VALUES ( %1, '%2', '%3' );";
-        query = query.arg( QString::number( parentId ) )
-                .arg( sql->escape( m_name ) )
-                .arg( sql->escape( m_urlId ) );
-        m_dbId = StorageManager::instance()->sqlStorage()->insert( query, "playlists" );
+        query = query.arg( QString::number( parentId ),
+                      sql->escape( m_name ),
+                      sql->escape( m_urlId ) );
+        m_dbId = StorageManager::instance()->sqlStorage()->insert( query, QStringLiteral("playlists") );
         if( tracks )
             saveTracks();
     }
@@ -173,7 +173,7 @@ void
 SqlPlaylist::saveTracks()
 {
     int trackNum = 1;
-    SqlStorage *sql = StorageManager::instance()->sqlStorage();
+    auto sql = StorageManager::instance()->sqlStorage();
 
     foreach( Meta::TrackPtr trackPtr, m_tracks )
     {
@@ -187,11 +187,11 @@ SqlPlaylist::saveTracks()
             query = query.arg( QString::number( m_dbId ), QString::number( trackNum ),
                         sql->escape( trackPtr->uidUrl() ),
                         sql->escape( trackPtr->prettyName() ),
-                        trackPtr->album() ? sql->escape( trackPtr->album()->prettyName() ) : "",
-                        trackPtr->artist()? sql->escape( trackPtr->artist()->prettyName() ) : "",
+                        trackPtr->album() ? sql->escape( trackPtr->album()->prettyName() ) : QLatin1String(""),
+                        trackPtr->artist()? sql->escape( trackPtr->artist()->prettyName() ) : QLatin1String(""),
                         QString::number( trackPtr->length() ),
                         sql->escape( trackPtr->uidUrl() ) );
-            sql->insert( query, "playlist_tracks" );
+            sql->insert( query, QStringLiteral("playlist_tracks") );
 
             trackNum++;
         }
@@ -222,7 +222,7 @@ SqlPlaylist::triggerTrackLoad()
 }
 
 void
-SqlPlaylist::addTrack( Meta::TrackPtr track, int position )
+SqlPlaylist::addTrack(const Meta::TrackPtr &track, int position )
 {
     if( !m_tracksLoaded )
         loadTracks();
@@ -263,7 +263,7 @@ SqlPlaylist::loadTracks()
     for( int i = 0; i < resultRows; i++ )
     {
         QStringList row = result.mid( i*7, 7 );
-        KUrl url = KUrl( row[2] );
+        QUrl url = QUrl( row[2] );
 
         MetaProxy::TrackPtr proxyTrack( new MetaProxy::Track( url ) );
 
@@ -286,11 +286,11 @@ SqlPlaylist::setName( const QString &name )
 void
 SqlPlaylist::removeFromDb()
 {
-    QString query = "DELETE FROM playlist_tracks WHERE playlist_id=%1";
+    QString query = QStringLiteral("DELETE FROM playlist_tracks WHERE playlist_id=%1");
     query = query.arg( QString::number( m_dbId ) );
     StorageManager::instance()->sqlStorage()->query( query );
 
-    query = "DELETE FROM playlists WHERE id=%1";
+    query = QStringLiteral("DELETE FROM playlists WHERE id=%1");
     query = query.arg( QString::number( m_dbId ) );
     StorageManager::instance()->sqlStorage()->query( query );
 }
