@@ -129,9 +129,9 @@ ServiceTrack::ServiceTrack( const QString & name )
     , ActionsProvider()
     , SourceInfoProvider()
     , BookmarkThisProvider()
-    , m_genre( 0 )
-    , m_composer( 0 )
-    , m_year( 0 )
+    , m_genre( nullptr )
+    , m_composer( nullptr )
+    , m_year( nullptr )
     , m_id( 0 )
     , m_trackNumber( 0 )
     , m_length( 0 )
@@ -148,9 +148,9 @@ ServiceTrack::ServiceTrack( const QStringList & resultRow )
     , ActionsProvider()
     , SourceInfoProvider()
     , BookmarkThisProvider()
-    , m_genre( 0 )
-    , m_composer( 0 )
-    , m_year( 0 )
+    , m_genre( nullptr )
+    , m_composer( nullptr )
+    , m_year( nullptr )
 {
     m_id = resultRow[0].toInt();
     m_name = resultRow[1];
@@ -589,7 +589,7 @@ ServiceAlbum::ServiceAlbum( const QString & name )
     , m_name( name )
     , m_tracks()
     , m_isCompilation( false )
-    , m_albumArtist( 0 )
+    , m_albumArtist( nullptr )
     , m_artistId( 0 )
 {
     //nothing to do
@@ -604,7 +604,7 @@ ServiceAlbum::ServiceAlbum(const QStringList & resultRow)
     , m_id( resultRow[0].toInt() )
     , m_name( resultRow[1] )
     , m_isCompilation( false )
-    , m_albumArtist( 0 )
+    , m_albumArtist( nullptr )
     , m_description( resultRow[2] )
     , m_artistId( resultRow[3].toInt() )
     , m_artistName()
