@@ -28,9 +28,10 @@
 #include "core/meta/support/MetaConstants.h"
 #include "core-impl/collections/support/MemoryMatcher.h"
 
-#include <QSet>
 #include <QAtomicInt>
 #include <QDomDocument>
+#include <QSet>
+#include <QUrlQuery>
 
 using namespace Collections;
 
@@ -43,7 +44,7 @@ struct AmpacheServiceQueryMaker::Private
 
     QAtomicInt expectedReplies;
 
-    QString server;
+    QUrl server;
     QString sessionId;
     QList<int> parentTrackIds;
     QList<int> parentAlbumIds;
@@ -62,7 +63,7 @@ struct AmpacheServiceQueryMaker::Private
     Meta::TrackList trackResults;
 };
 
-AmpacheServiceQueryMaker::AmpacheServiceQueryMaker( AmpacheServiceCollection * collection, const QString &server, const QString &sessionId  )
+AmpacheServiceQueryMaker::AmpacheServiceQueryMaker( AmpacheServiceCollection * collection, const QUrl &server, const QString &sessionId  )
     : DynamicServiceQueryMaker()
     , d( new Private )
 {
@@ -206,26 +207,29 @@ AmpacheServiceQueryMaker::fetchArtists()
     // first try the cache
     if( !d->parentArtistIds.isEmpty() )
     {
-        foreach( int artistId, d->parentArtistIds )
+        for( int artistId : qAsConst(d->parentArtistIds) )
             artists << d->collection->artistById( artistId );
     }
 
     if( !artists.isEmpty() )
     {
         debug() << "got" << artists.count() << "artists from the memory collection";
-        emit newResultReady( artists );
-        emit queryDone();
+        Q_EMIT newArtistsReady( artists );
+        Q_EMIT queryDone();
         return;
     }
 
-    KUrl request = getRequestUrl( "artists" );
+    QUrl request = getRequestUrl( "artists" );
+    QUrlQuery query( request );
 
     if ( !d->artistFilter.isEmpty() )
-        request.addQueryItem( "filter", d->artistFilter );
+    {
+        query.addQueryItem( "filter", d->artistFilter );
+        request.setQuery( query );
+    }
 
     d->expectedReplies.ref();
-    The::networkAccessManager()->getData( request, this,
-                                          SLOT(artistDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+    The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::artistDownloadComplete );
 }
 
 void
@@ -244,8 +248,8 @@ AmpacheServiceQueryMaker::fetchAlbums()
     if( !albums.isEmpty() )
     {
         debug() << "got" << albums.count() << "albums from the memory collection";
-        emit newResultReady( albums );
-        emit queryDone();
+        Q_EMIT newAlbumsReady( albums );
+        Q_EMIT queryDone();
         return;
     }
 
@@ -253,24 +257,28 @@ AmpacheServiceQueryMaker::fetchAlbums()
     {
         foreach( int id, d->parentArtistIds )
         {
-            KUrl request = getRequestUrl( "artist_albums" );
-            request.addQueryItem( "filter", QString::number( id ) );
+            QUrl request = getRequestUrl( "artist_albums" );
+            QUrlQuery query( request );
+            query.addQueryItem( "filter", QString::number( id ) );
+            request.setQuery( query );
 
             d->expectedReplies.ref();
-            The::networkAccessManager()->getData( request, this,
-                                                  SLOT(albumDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+            The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::albumDownloadComplete );
         }
     }
     else
     {
-        KUrl request = getRequestUrl( "albums" );
+        QUrl request = getRequestUrl( "albums" );
+        QUrlQuery query( request );
 
         if ( !d->albumFilter.isEmpty() )
-            request.addQueryItem( "filter", d->albumFilter );
+        {
+            query.addQueryItem( "filter", d->albumFilter );
+            request.setQuery( query );
+        }
 
         d->expectedReplies.ref();
-        The::networkAccessManager()->getData( request, this,
-                                              SLOT(albumDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+        The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::albumDownloadComplete );
     }
 }
 
@@ -314,50 +322,51 @@ AmpacheServiceQueryMaker::fetchTracks()
     if( !tracks.isEmpty() )
     {
         debug() << "got" << tracks.count() << "tracks from the memory collection";
-        emit newResultReady( tracks );
-        emit queryDone();
+        Q_EMIT newTracksReady( tracks );
+        Q_EMIT queryDone();
         return;
     }
 
-    KUrl request = getRequestUrl();
+    QUrl request = getRequestUrl();
 
 
     if( !d->parentAlbumIds.isEmpty() )
     {
         foreach( int id, d->parentAlbumIds )
         {
-            KUrl request = getRequestUrl( "album_songs" );
-            request.addQueryItem( "filter", QString::number( id ) );
+            QUrl request = getRequestUrl( "album_songs" );
+            QUrlQuery query( request );
+            query.addQueryItem( "filter", QString::number( id ) );
+            request.setQuery( query );
 
             d->expectedReplies.ref();
-            The::networkAccessManager()->getData( request, this,
-                                                  SLOT(trackDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+            The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::trackDownloadComplete );
         }
     }
     else if( !d->parentArtistIds.isEmpty() )
     {
         foreach( int id, d->parentArtistIds )
         {
-            KUrl request = getRequestUrl( "artist_songs" );
-            request.addQueryItem( "filter", QString::number( id ) );
+            QUrl request = getRequestUrl( "artist_songs" );
+            QUrlQuery query( request );
+            query.addQueryItem( "filter", QString::number( id ) );
+            request.setQuery( query );
 
             d->expectedReplies.ref();
-            The::networkAccessManager()->getData( request, this,
-                                                  SLOT(trackDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+            The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::trackDownloadComplete );
         }
     }
     else
     {
-        KUrl request = getRequestUrl( "songs" );
+        QUrl request = getRequestUrl( "songs" );
 
         d->expectedReplies.ref();
-        The::networkAccessManager()->getData( request, this,
-                                              SLOT(trackDownloadComplete(KUrl,QByteArray,NetworkAccessManagerProxy::Error)) );
+        The::networkAccessManager()->getData( request, this, &AmpacheServiceQueryMaker::trackDownloadComplete );
     }
 }
 
 void
-AmpacheServiceQueryMaker::artistDownloadComplete( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e )
+AmpacheServiceQueryMaker::artistDownloadComplete( const QUrl &url, const QByteArray &data, const NetworkAccessManagerProxy::Error &e )
 {
     Q_UNUSED( url );
 
@@ -365,7 +374,7 @@ AmpacheServiceQueryMaker::artistDownloadComplete( const KUrl &url, QByteArray da
     {
         warning() << "Artist download error:" << e.description;
         if( !d->expectedReplies.deref() )
-            emit queryDone();
+            Q_EMIT queryDone();
         return;
     }
 
@@ -376,14 +385,14 @@ AmpacheServiceQueryMaker::artistDownloadComplete( const KUrl &url, QByteArray da
     doc.setContent( data );
     QDomElement root = doc.firstChildElement( "root" );
 
-    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before contiuning
+    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before continuing
     QDomElement domError = root.firstChildElement( "error" );
 
     if ( !domError.isNull() )
     {
-        warning() << "Error getting Artist List" << domError.text();
+        warning() << "Error getting Artist List" << domError.text() << "Code:" << domError.attribute("code");
         AmpacheService *parentService = dynamic_cast< AmpacheService * >( d->collection->service() );
-        if( parentService == 0 )
+        if( !parentService )
             return;
         else
             parentService->reauthenticate();
@@ -420,14 +429,14 @@ AmpacheServiceQueryMaker::artistDownloadComplete( const KUrl &url, QByteArray da
 
     if( !d->expectedReplies.deref() )
     {
-        emit newResultReady( d->artistResults );
-        emit queryDone();
+        Q_EMIT newArtistsReady( d->artistResults );
+        Q_EMIT queryDone();
         d->artistResults.clear();
     }
 }
 
 void
-AmpacheServiceQueryMaker::albumDownloadComplete( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e )
+AmpacheServiceQueryMaker::albumDownloadComplete( const QUrl &url, const QByteArray &data, const NetworkAccessManagerProxy::Error &e )
 {
     Q_UNUSED( url );
 
@@ -435,7 +444,7 @@ AmpacheServiceQueryMaker::albumDownloadComplete( const KUrl &url, QByteArray dat
     {
         warning() << "Album download error:" << e.description;
         if( !d->expectedReplies.deref() )
-            emit queryDone();
+            Q_EMIT queryDone();
         return;
     }
 
@@ -446,14 +455,14 @@ AmpacheServiceQueryMaker::albumDownloadComplete( const KUrl &url, QByteArray dat
     doc.setContent( data );
     QDomElement root = doc.firstChildElement( "root" );
 
-    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before contiuning
+    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before continuing
     QDomElement domError = root.firstChildElement( "error" );
 
     if( !domError.isNull() )
     {
-        warning() << "Error getting Album List" << domError.text();
+        warning() << "Error getting Album List" << domError.text() << "Code:" << domError.attribute("code");
         AmpacheService *parentService = dynamic_cast< AmpacheService * >(d->collection->service());
-        if( parentService == 0 )
+        if( parentService == nullptr )
             return;
         else
             parentService->reauthenticate();
@@ -538,14 +547,14 @@ AmpacheServiceQueryMaker::albumDownloadComplete( const KUrl &url, QByteArray dat
 
     if( !d->expectedReplies.deref() )
     {
-        emit newResultReady( d->albumResults );
-        emit queryDone();
+        Q_EMIT newAlbumsReady( d->albumResults );
+        Q_EMIT queryDone();
         d->albumResults.clear();
     }
 }
 
 void
-AmpacheServiceQueryMaker::trackDownloadComplete( const KUrl &url, QByteArray data, NetworkAccessManagerProxy::Error e )
+AmpacheServiceQueryMaker::trackDownloadComplete( const QUrl &url, const QByteArray &data, const NetworkAccessManagerProxy::Error &e )
 {
     Q_UNUSED( url );
 
@@ -553,7 +562,7 @@ AmpacheServiceQueryMaker::trackDownloadComplete( const KUrl &url, QByteArray dat
     {
         warning() << "Track download error:" << e.description;
         if( !d->expectedReplies.deref() )
-            emit queryDone();
+            Q_EMIT queryDone();
         return;
     }
 
@@ -564,14 +573,14 @@ AmpacheServiceQueryMaker::trackDownloadComplete( const KUrl &url, QByteArray dat
     doc.setContent( data );
     QDomElement root = doc.firstChildElement( "root" );
 
-    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before contiuning
+    // Is this an error, if so we need to 'un-ready' the service and re-authenticate before continuing
     QDomElement domError = root.firstChildElement( "error" );
 
     if( !domError.isNull() )
     {
-        warning() << "Error getting Track Download " << domError.text();
+        warning() << "Error getting Track Download " << domError.text() << "Code:" << domError.attribute("code");
         AmpacheService *parentService = dynamic_cast< AmpacheService * >( d->collection->service() );
-        if( parentService == 0 )
+        if( parentService == nullptr )
             return;
         else
             parentService->reauthenticate();
@@ -649,8 +658,8 @@ AmpacheServiceQueryMaker::trackDownloadComplete( const KUrl &url, QByteArray dat
 
     if( !d->expectedReplies.deref() )
     {
-        emit newResultReady( d->trackResults );
-        emit queryDone();
+        Q_EMIT newTracksReady( d->trackResults );
+        Q_EMIT queryDone();
         d->trackResults.clear();
     }
 }
@@ -697,7 +706,7 @@ AmpacheServiceQueryMaker::addNumberFilter( qint64 value, qint64 filter, QueryMak
 int
 AmpacheServiceQueryMaker::validFilterMask()
 {
-    //we only supprt artist and album filters for now...
+    //we only support artist and album filters for now...
     return ArtistFilter | AlbumFilter;
 }
 
@@ -708,32 +717,35 @@ AmpacheServiceQueryMaker::limitMaxResultSize( int size )
     return this;
 }
 
-KUrl
+QUrl
 AmpacheServiceQueryMaker::getRequestUrl( const QString &action ) const
 {
-    QString path = d->server;
+    QUrl url = d->server;
+    QString scheme = url.scheme();
 
-    if( !path.startsWith("http://") && !path.startsWith("https://") )
-        path = "http://" + path;
+    if( scheme != "http" && scheme != "https" )
+        url.setScheme( "http" );
 
-    KUrl url( path );
+    QUrlQuery query( url );
 
-    url.addPath( "/server/xml.server.php" );
-    url.addQueryItem( "auth", d->sessionId );
+    url = url.adjusted( QUrl::StripTrailingSlash );
+    url.setPath( url.path() + "/server/xml.server.php" );
+
+    query.addQueryItem( "auth", d->sessionId );
 
     if( !action.isEmpty() )
-        url.addQueryItem( "action", action );
+        query.addQueryItem( "action", action );
 
     if( d->dateFilter > 0 )
     {
         QDateTime from;
-        from.setTime_t( d->dateFilter );
-        url.addQueryItem( "add", from.toString( Qt::ISODate ) );
+        from.setSecsSinceEpoch( d->dateFilter );
+        query.addQueryItem( "add", from.toString( Qt::ISODate ) );
     }
-    url.addQueryItem( "limit", QString::number( d->maxsize ) );
+    query.addQueryItem( "limit", QString::number( d->maxsize ) );
+    url.setQuery( query );
 
     return url;
 }
 
-#include "AmpacheServiceQueryMaker.moc"
 
