@@ -26,12 +26,13 @@
 #include "AmarokMimeData.h"
 
 #include <QIcon>
-
 #include <QPainter>
 
 #include <Tag.h>
 #include <XmlQuery.h>
 
+#include <algorithm>
+
 using namespace LastFm;
 
 LastFmTreeModel::LastFmTreeModel( QObject *parent )
@@ -390,7 +391,7 @@ Qt::ItemFlags
 LastFmTreeModel::flags( const QModelIndex &index ) const
 {
     if( !index.isValid() )
-        return 0;
+        return {};
 
     Qt::ItemFlags flags = Qt::ItemIsEnabled | Qt::ItemIsDropEnabled;
     LastFmTreeItem *i = static_cast<LastFmTreeItem*>( index.internalPointer() );
@@ -615,7 +616,7 @@ LastFmTreeModel::mimeData( const QModelIndexList &indices ) const
         if( track )
             list << track;
     }
-    qStableSort( list.begin(), list.end(), Meta::Track::lessThan );
+    std::stable_sort( list.begin(), list.end(), Meta::Track::lessThan );
 
     AmarokMimeData *mimeData = new AmarokMimeData();
     mimeData->setTracks( list );
