@@ -21,14 +21,13 @@
 
 #include "core/meta/forward_declarations.h"
 
-#include <KUrl>
+#include <QUrl>
 
 #include <QAbstractItemModel>
 #include <QPixmap>
 
 #include <User.h>
 
-class QNetworkReply;
 
 namespace LastFm
 {
@@ -38,31 +37,18 @@ enum Type
     MyRecommendations,
     PersonalRadio,
     MixRadio,
-    NeighborhoodRadio,
-    //         RecentlyPlayed,
-    //         RecentlyLoved,
-    //         RecentlyBanned,
     TopArtists,
     MyTags,
     Friends,
-    Neighbors,
-
-    //         History,
-
     RowCount,
-
     MyTagsChild,
     FriendsChild,
-    NeighborsChild,
     ArtistsChild,
     RecentlyBannedTrack,
     RecentlyPlayedTrack,
     RecentlyLovedTrack,
     HistoryStation,
-
     UserChildPersonal,
-    UserChildNeighborhood,
-
     TypeUnknown
 };
 
@@ -85,8 +71,7 @@ enum SortOrder
 }
 
 class LastFmTreeItem;
-class KUrl;
-class WsReply;
+class QUrl;
 
 
 class LastFmTreeModel : public QAbstractItemModel
@@ -94,24 +79,23 @@ class LastFmTreeModel : public QAbstractItemModel
     Q_OBJECT
 
 public:
-    explicit LastFmTreeModel( QObject *parent = 0 );
-    ~LastFmTreeModel();
+    explicit LastFmTreeModel( QObject *parent = nullptr );
+    ~LastFmTreeModel() override;
 
-    QVariant data( const QModelIndex &index, int role ) const;
-    Qt::ItemFlags flags( const QModelIndex &index ) const;
+    QVariant data( const QModelIndex &index, int role ) const override;
+    Qt::ItemFlags flags( const QModelIndex &index ) const override;
     QModelIndex index( int row, int column,
-                        const QModelIndex &parent = QModelIndex() ) const;
-    QModelIndex parent( const QModelIndex &index ) const;
-    int rowCount( const QModelIndex &parent = QModelIndex() ) const;
-    int columnCount( const QModelIndex &parent = QModelIndex() ) const;
+                        const QModelIndex &parent = QModelIndex() ) const override;
+    QModelIndex parent( const QModelIndex &index ) const override;
+    int rowCount( const QModelIndex &parent = QModelIndex() ) const override;
+    int columnCount( const QModelIndex &parent = QModelIndex() ) const override;
     static int avatarSize();
     void prepareAvatar( QPixmap& avatar, int size );
 
-    virtual QMimeData *mimeData( const QModelIndexList &indices ) const;
+    QMimeData *mimeData( const QModelIndexList &indices ) const override;
 
-private slots:
+private Q_SLOTS:
     void onAvatarDownloaded( const QString& username, QPixmap );
-    void slotAddNeighbors();
     void slotAddFriends();
     void slotAddTags();
     void slotAddTopArtists();
@@ -119,7 +103,7 @@ private slots:
 private:
     void setupModelData( LastFmTreeItem *parent );
 
-    QIcon avatar( const QString &username, const KUrl &avatarUrl ) const;
+    QIcon avatar( const QString &username, const QUrl &avatarUrl ) const;
     QString mapTypeToUrl( LastFm::Type type, const QString &key = "" );
 
     void appendUserStations( LastFmTreeItem* item, const QString& user );
@@ -129,7 +113,6 @@ private:
     LastFmTreeItem *m_rootItem;
     LastFmTreeItem *m_myTags;
     LastFmTreeItem *m_myFriends;
-    LastFmTreeItem *m_myNeighbors;
     LastFmTreeItem *m_myTopArtists;
     QHash<QString, QIcon> m_avatars;
 };
@@ -137,10 +120,10 @@ private:
 class LastFmTreeItem
 {
 public:
-    LastFmTreeItem ( const LastFm::Type &type, const QVariant &data, LastFmTreeItem *parent = 0 );
-    LastFmTreeItem ( const QString &url, const LastFm::Type &type, const QVariant &data, LastFmTreeItem *parent = 0 );
-    explicit LastFmTreeItem ( const LastFm::Type &type, LastFmTreeItem *parent = 0 );
-    LastFmTreeItem ( const QString &url, const LastFm::Type &type, LastFmTreeItem *parent = 0 );
+    LastFmTreeItem ( const LastFm::Type &type, const QVariant &data, LastFmTreeItem *parent = nullptr );
+    LastFmTreeItem ( const QString &url, const LastFm::Type &type, const QVariant &data, LastFmTreeItem *parent = nullptr );
+    explicit LastFmTreeItem ( const LastFm::Type &type, LastFmTreeItem *parent = nullptr );
+    LastFmTreeItem ( const QString &url, const LastFm::Type &type, LastFmTreeItem *parent = nullptr );
     ~LastFmTreeItem();
 
     void appendChild ( LastFmTreeItem *child );
@@ -156,11 +139,11 @@ public:
         return mType;
     }
 
-    KUrl avatarUrl() const
+    QUrl avatarUrl() const
     {
         return avatar;
     }
-    void setAvatarUrl( const KUrl &url )
+    void setAvatarUrl( const QUrl &url )
     {
         avatar = url;
     }
@@ -171,7 +154,7 @@ private:
     LastFmTreeItem *parentItem;
     QVariant itemData;
     QString mUrl;
-    KUrl avatar;
+    QUrl avatar;
 };
 
 #endif
