@@ -17,34 +17,34 @@
 #include "MagnatuneInfoParser.h"
 
 #include "core/support/Components.h"
-#include "core/interfaces/Logger.h"
+#include "core/logger/Logger.h"
 #include "MagnatuneConfig.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 
 using namespace Meta;
 
-void MagnatuneInfoParser::getInfo(ArtistPtr artist)
+void MagnatuneInfoParser::getInfo(const ArtistPtr &artist)
 {
 
     showLoading( i18n( "Loading artist info..." ) );
 
     MagnatuneArtist * magnatuneArtist = dynamic_cast<MagnatuneArtist *>( artist.data() );
-    if ( magnatuneArtist == 0) return;
+    if ( !magnatuneArtist ) return;
 
     // first get the entire artist html page
    /* QString tempFile;
     QString orgHtml;*/
 
     m_infoDownloadJob = KIO::storedGet( magnatuneArtist->magnatuneUrl(), KIO::Reload, KIO::HideProgressInfo );
-    Amarok::Components::logger()->newProgressOperation( m_infoDownloadJob, i18n( "Fetching %1 Artist Info", magnatuneArtist->prettyName() ) );
-    connect( m_infoDownloadJob, SIGNAL(result(KJob*)), SLOT(artistInfoDownloadComplete(KJob*)) );
+    Amarok::Logger::newProgressOperation( m_infoDownloadJob, i18n( "Fetching %1 Artist Info", magnatuneArtist->prettyName() ) );
+    connect( m_infoDownloadJob, &KJob::result, this, &MagnatuneInfoParser::artistInfoDownloadComplete );
 
 }
 
 
-void MagnatuneInfoParser::getInfo(AlbumPtr album)
+void MagnatuneInfoParser::getInfo(const AlbumPtr &album)
 {
 
     showLoading( i18n( "Loading album info..." ) );
@@ -81,10 +81,10 @@ void MagnatuneInfoParser::getInfo(AlbumPtr album)
     infoHtml += "</p><br><br>" + i18n( "From Magnatune.com" ) + "</div>";
     infoHtml += "</BODY></HTML>";
 
-    emit ( info( infoHtml ) );
+    Q_EMIT ( info( infoHtml ) );
 }
 
-void MagnatuneInfoParser::getInfo(TrackPtr track)
+void MagnatuneInfoParser::getInfo(const TrackPtr &track)
 {
     Q_UNUSED( track );
     return;
@@ -97,7 +97,7 @@ void
 MagnatuneInfoParser::artistInfoDownloadComplete( KJob *downLoadJob )
 {
 
-    if ( !downLoadJob->error() == 0 )
+    if ( downLoadJob->error() != 0 )
     {
         //TODO: error handling here
         return ;
@@ -113,7 +113,7 @@ MagnatuneInfoParser::artistInfoDownloadComplete( KJob *downLoadJob )
 
     //debug() << "html: " << trimmedInfo;
 
-    emit ( info( infoString ) );
+    Q_EMIT ( info( infoString ) );
 
 }
 
@@ -156,15 +156,15 @@ void MagnatuneInfoParser::getFrontPage()
 
     if( !m_cachedFrontpage.isEmpty() )
     {
-        emit ( info( m_cachedFrontpage ) );
+        Q_EMIT ( info( m_cachedFrontpage ) );
         return;
     }
 
     showLoading( i18n( "Loading Magnatune.com frontpage..." ) );
     
-    m_pageDownloadJob = KIO::storedGet( KUrl( "http://magnatune.com/amarok_frontpage.html" ), KIO::Reload, KIO::HideProgressInfo );
-    Amarok::Components::logger()->newProgressOperation( m_pageDownloadJob, i18n( "Fetching Magnatune.com front page" ) );
-    connect( m_pageDownloadJob, SIGNAL(result(KJob*)), SLOT(frontpageDownloadComplete(KJob*)) );
+    m_pageDownloadJob = KIO::storedGet( QUrl("http://magnatune.com/amarok_frontpage.html"), KIO::Reload, KIO::HideProgressInfo );
+    Amarok::Logger::newProgressOperation( m_pageDownloadJob, i18n( "Fetching Magnatune.com front page" ) );
+    connect( m_pageDownloadJob, &KJob::result, this, &MagnatuneInfoParser::frontpageDownloadComplete );
 }
 
 void MagnatuneInfoParser::getFavoritesPage()
@@ -185,11 +185,11 @@ void MagnatuneInfoParser::getFavoritesPage()
     QString user = config.username();
     QString password = config.password();
 
-    QString url = "http://" + user + ":" + password + "@" + type.toLower() + ".magnatune.com/member/amarok_favorites.php";
+    QUrl url = QUrl::fromUserInput( "http://" + user + ":" + password + "@" + type.toLower() + ".magnatune.com/member/amarok_favorites.php" );
 
-    m_pageDownloadJob = KIO::storedGet( KUrl( url ), KIO::Reload, KIO::HideProgressInfo );
-    Amarok::Components::logger()->newProgressOperation( m_pageDownloadJob, i18n( "Loading your Magnatune.com favorites page..." ) );
-    connect( m_pageDownloadJob, SIGNAL(result(KJob*)), SLOT(userPageDownloadComplete(KJob*)) );
+    m_pageDownloadJob = KIO::storedGet( url, KIO::Reload, KIO::HideProgressInfo );
+    Amarok::Logger::newProgressOperation( m_pageDownloadJob, i18n( "Loading your Magnatune.com favorites page..." ) );
+    connect( m_pageDownloadJob, &KJob::result, this, &MagnatuneInfoParser::userPageDownloadComplete );
 }
 
 void MagnatuneInfoParser::getRecommendationsPage()
@@ -210,16 +210,16 @@ void MagnatuneInfoParser::getRecommendationsPage()
     QString user = config.username();
     QString password = config.password();
 
-    QString url = "http://" + user + ":" + password + "@" + type.toLower() + ".magnatune.com/member/amarok_recommendations.php";
+    QUrl url = QUrl::fromUserInput( "http://" + user + ":" + password + "@" + type.toLower() + ".magnatune.com/member/amarok_recommendations.php" );
 
-    m_pageDownloadJob = KIO::storedGet( KUrl( url ), KIO::Reload, KIO::HideProgressInfo );
-    Amarok::Components::logger()->newProgressOperation( m_pageDownloadJob, i18n( "Loading your personal Magnatune.com recommendations page..." ) );
-    connect( m_pageDownloadJob, SIGNAL(result(KJob*)), SLOT(userPageDownloadComplete(KJob*)) );
+    m_pageDownloadJob = KIO::storedGet( url, KIO::Reload, KIO::HideProgressInfo );
+    Amarok::Logger::newProgressOperation( m_pageDownloadJob, i18n( "Loading your personal Magnatune.com recommendations page..." ) );
+    connect( m_pageDownloadJob, &KJob::result, this, &MagnatuneInfoParser::userPageDownloadComplete );
 }
 
 void MagnatuneInfoParser::frontpageDownloadComplete( KJob * downLoadJob )
 {
-    if ( !downLoadJob->error() == 0 )
+    if ( downLoadJob->error() != 0 )
     {
         //TODO: error handling here
         return ;
@@ -240,12 +240,12 @@ void MagnatuneInfoParser::frontpageDownloadComplete( KJob * downLoadJob )
     if( m_cachedFrontpage.isEmpty() )
         m_cachedFrontpage = infoString;
 
-    emit ( info( infoString ) );
+    Q_EMIT ( info( infoString ) );
 }
 
 void MagnatuneInfoParser::userPageDownloadComplete( KJob * downLoadJob )
 {
-    if ( !downLoadJob->error() == 0 )
+    if ( downLoadJob->error() )
     {
         //TODO: error handling here
         return ;
@@ -265,7 +265,7 @@ void MagnatuneInfoParser::userPageDownloadComplete( KJob * downLoadJob )
     //make sure that any pages that use the old command name "service_magnatune" replaces it with "service-magnatune"
     infoString.replace( "service_magnatune", "service-magnatune" );
 
-    emit ( info( infoString ) );
+    Q_EMIT ( info( infoString ) );
 }
 
 
@@ -302,7 +302,7 @@ MagnatuneInfoParser::createArtistLinks( const QString &page )
 
     QString returnPage = page;
 
-    int startTokenLength = QString( "<!--ARTIST_TOKEN-->" ).length();
+    int startTokenLength = QStringLiteral( "<!--ARTIST_TOKEN-->" ).length();
 
     int offset = 0;
     int startTokenIndex = page.indexOf( "<!--ARTIST_TOKEN-->", offset );
@@ -335,5 +335,4 @@ MagnatuneInfoParser::createArtistLinks( const QString &page )
 }
 
 
-#include "MagnatuneInfoParser.moc"
 
