@@ -26,7 +26,6 @@
 #include <QString>
 #include <QStringList>
 
-class MagnatuneAlbumCoverDownloader;
 class MagnatuneStore;
 
 namespace Meta
@@ -36,31 +35,31 @@ class MagnatuneTrack  : public ServiceTrack
 {
     Q_OBJECT
 public:
-    MagnatuneTrack( const QString &name );
-    MagnatuneTrack( const QStringList &resultRow );
+    explicit MagnatuneTrack( const QString &name );
+    explicit  MagnatuneTrack( const QStringList &resultRow );
 
     QString lofiUrl();
     void setLofiUrl( const QString &url );
 
-    QList<QString> moods();
-    void setMoods(  QList<QString> moods );
+    QList<QString> moods() const;
+    void setMoods(  const QList<QString> &moods );
 
     void setDownloadMembership();
 
-    virtual QString sourceName();
-    virtual QString sourceDescription();
-    virtual QPixmap emblem();
+    QString sourceName() override;
+    QString sourceDescription() override;
+    QPixmap emblem() override;
 
-    virtual bool isBookmarkable() const { return true; }
-    virtual QString collectionName() const { return "Magnatune.com"; }
-    virtual bool simpleFiltering() const { return false; }
+    bool isBookmarkable() const override { return true; }
+    QString collectionName() const override { return QStringLiteral("Magnatune.com"); }
+    bool simpleFiltering() const override { return false; }
 
     void setOggUrl( const QString& url );
     QString oggUrl() const;
 
-    void setAlbumPtr( Meta::AlbumPtr album );
+    void setAlbumPtr( const Meta::AlbumPtr &album ) override;
 
-public slots:
+public Q_SLOTS:
     void download();
 
 private:
@@ -75,22 +74,22 @@ class MagnatuneArtist : public ServiceArtist
 {
 private:
 
-    QString m_photoUrl;
-    QString m_magnatuneUrl;
+    QUrl m_photoUrl;
+    QUrl m_magnatuneUrl;
 
 public:
-    MagnatuneArtist( const QString &name );
-    MagnatuneArtist( const QStringList &resultRow );
+    explicit MagnatuneArtist( const QString &name );
+    explicit MagnatuneArtist( const QStringList &resultRow );
 
-    void setPhotoUrl( const QString &photoUrl );
-    QString photoUrl() const;
+    void setPhotoUrl( const QUrl &photoUrl );
+    QUrl photoUrl() const;
 
-    void setMagnatuneUrl( const QString &url );
-    QString magnatuneUrl() const;
+    void setMagnatuneUrl( const QUrl &url );
+    QUrl magnatuneUrl() const;
 
-    virtual bool isBookmarkable() const { return true; }
-    virtual QString collectionName() const { return "Magnatune.com"; }
-    virtual bool simpleFiltering() const { return false; }
+    bool isBookmarkable() const override { return true; }
+    QString collectionName() const override { return QStringLiteral("Magnatune.com"); }
+    bool simpleFiltering() const override { return false; }
 };
 
 class MagnatuneAlbum : public ServiceAlbumWithCover
@@ -105,20 +104,20 @@ private:
 
 
 public:
-    MagnatuneAlbum( const QString &name );
-    MagnatuneAlbum( const QStringList &resultRow );
+    explicit MagnatuneAlbum( const QString &name );
+    explicit MagnatuneAlbum( const QStringList &resultRow );
 
-    ~MagnatuneAlbum();
+    ~MagnatuneAlbum() override;
     
-    virtual QString downloadPrefix() const { return "magnatune"; }
+    QString downloadPrefix() const override { return QStringLiteral("magnatune"); }
 
     void setLaunchYear( int launchYear );
     int launchYear() const;
 
-    virtual void setCoverUrl( const QString &coverUrl );
-    virtual QString coverUrl() const;
+    void setCoverUrl( const QString &coverUrl ) override;
+    QString coverUrl() const override;
 
-    virtual KUrl imageLocation( int size = 1 ) { Q_UNUSED( size ); return KUrl( coverUrl() ); }
+    QUrl imageLocation( int size = 1 ) override { Q_UNUSED( size ); return QUrl( coverUrl() ); }
     
     void setAlbumCode(  const QString &albumCode );
     QString albumCode();
@@ -128,11 +127,11 @@ public:
 
     void setDownloadMembership();
 
-    virtual bool isBookmarkable() const { return true; }
-    virtual QString collectionName() const { return "Magnatune.com"; }
-    virtual bool simpleFiltering() const { return false; }
+    bool isBookmarkable() const override { return true; }
+    QString collectionName() const override { return QStringLiteral("Magnatune.com"); }
+    bool simpleFiltering() const override { return false; }
 
-public slots:
+public Q_SLOTS:
     void download();
     void addToFavorites();
 };
@@ -141,12 +140,12 @@ class MagnatuneGenre  : public ServiceGenre
 {
 
 public:
-    MagnatuneGenre( const QString &name );
-    MagnatuneGenre( const QStringList &resultRow );
+    explicit MagnatuneGenre( const QString &name );
+    explicit MagnatuneGenre( const QStringList &resultRow );
 
-    virtual bool isBookmarkable() const { return true; }
-    virtual QString collectionName() const { return "Magnatune.com"; }
-    virtual bool simpleFiltering() const { return false; }
+    bool isBookmarkable() const override { return true; }
+    QString collectionName() const override { return QStringLiteral("Magnatune.com"); }
+    bool simpleFiltering() const override { return false; }
 };
 
 }
@@ -158,23 +157,23 @@ class MagnatuneMetaFactory : public ServiceMetaFactory
         enum { OGG = 0, MP3 = 1, LOFI = 2 };
         
         MagnatuneMetaFactory( const QString &dbPrefix, MagnatuneStore * store );
-        virtual ~MagnatuneMetaFactory() {}
+        ~MagnatuneMetaFactory() override {}
 
-        virtual int getTrackSqlRowCount();
-        virtual QString getTrackSqlRows();
-        virtual Meta::TrackPtr createTrack( const QStringList &rows );
+        int getTrackSqlRowCount() override;
+        QString getTrackSqlRows() override;
+        Meta::TrackPtr createTrack( const QStringList &rows ) override;
 
-        virtual int getAlbumSqlRowCount();
-        virtual QString getAlbumSqlRows();
-        virtual Meta::AlbumPtr createAlbum( const QStringList &rows );
+        int getAlbumSqlRowCount() override;
+        QString getAlbumSqlRows() override;
+        Meta::AlbumPtr createAlbum( const QStringList &rows ) override;
 
-        virtual int getArtistSqlRowCount();
-        virtual QString getArtistSqlRows();
-        virtual Meta::ArtistPtr createArtist( const QStringList &rows );
+        int getArtistSqlRowCount() override;
+        QString getArtistSqlRows() override;
+        Meta::ArtistPtr createArtist( const QStringList &rows ) override;
 
     //virtual int getGenreSqlRowCount();
     //virtual QString getGenreSqlRows();
-        virtual Meta::GenrePtr createGenre( const QStringList &rows );
+        Meta::GenrePtr createGenre( const QStringList &rows ) override;
 
         //stuff for supporting the new membership services at Magnatune.com
 
