@@ -27,14 +27,11 @@
 
 #include "../ServiceBase.h"
 
-#include <kio/job.h>
-#include <kio/jobclasses.h>
+#include <KJob>
 
 #include <QCheckBox>
 #include <QComboBox>
-#include <khbox.h>
 #include <QPushButton>
-#include <kvbox.h>
 
 
 class MagnatuneInfoParser;
@@ -42,17 +39,19 @@ class MagnatuneNeedUpdateWidget;
 
 class MagnatuneServiceFactory : public ServiceFactory
 {
+    Q_PLUGIN_METADATA(IID AmarokPluginFactory_iid FILE "amarok_service_magnatunestore.json")
+    Q_INTERFACES(Plugins::PluginFactory)
     Q_OBJECT
 
     public:
-        MagnatuneServiceFactory( QObject *parent, const QVariantList &args );
-        virtual ~MagnatuneServiceFactory() {}
+        MagnatuneServiceFactory();
+        ~MagnatuneServiceFactory() override {}
 
-        virtual void init();
-        virtual QString name();
-        virtual KConfigGroup config();
+        void init() override;
+        QString name() override;
+        KConfigGroup config() override;
 
-        virtual bool possiblyContainsTrack( const KUrl &url ) const { return url.url().contains( "magnatune.com", Qt::CaseInsensitive ); }
+        bool possiblyContainsTrack( const QUrl &url ) const override { return url.url().contains( "magnatune.com", Qt::CaseInsensitive ); }
 };
 
 
@@ -70,11 +69,11 @@ public:
      /**
      * Constructor
      */
-    MagnatuneStore( MagnatuneServiceFactory* parent, const char *name );
+    explicit MagnatuneStore( MagnatuneServiceFactory* parent, const char *name );
     /**
      * Destructor
      */
-    ~MagnatuneStore();
+    ~MagnatuneStore() override;
 
     void setMembership( int type, const QString &username,  const QString &password );
 
@@ -86,23 +85,23 @@ public:
      /**
      * Do not do expensive initializations before we are actually shown
      */
-    void polish();
+    void polish() override;
    // bool updateContextView();
 
-    virtual Collections::Collection * collection() { return m_collection; }
+    Collections::Collection * collection() override { return m_collection; }
 
-    virtual QString messages();
-    virtual QString sendMessage( const QString &message );
+    QString messages() override;
+    QString sendMessage( const QString &message ) override;
 
-public slots:
+public Q_SLOTS:
     /**
     * Slot for catching cancelled list downloads
     */
     void listDownloadCancelled();
 
-    void download( Meta::MagnatuneTrack * track );
+    void downloadTrack( Meta::MagnatuneTrack * track );
 
-    void download( Meta::MagnatuneAlbum * album );
+    void downloadAlbum( Meta::MagnatuneAlbum * album );
 
     void showFavoritesPage();
     void showHomePage();
@@ -111,30 +110,30 @@ public slots:
     void addToFavorites( const QString &sku );
     void removeFromFavorites( const QString &sku );
     
-private slots:
+private Q_SLOTS:
     /**
      * Slot called when the download album button is clicked. Starts a download
      */
     void download();
 
-    void download( const QString &sku );
+    void downloadSku( const QString &sku );
 
     /**
-     * Slot for recieving notification that the update button has been clicked.
+     * Slot for receiving notification that the update button has been clicked.
      */
     void updateButtonClicked();
 
 
     /**
-     * Slot for recieving notification when the Magnatune xml file has been downloaded.
-     * Triggers a parse of the file to get the info added to the databse
+     * Slot for receiving notification when the Magnatune xml file has been downloaded.
+     * Triggers a parse of the file to get the info added to the database
      * @param downLoadJob The calling download Job
      */
     void listDownloadComplete( KJob* downLoadJob );
 
 
     /**
-     * Slot called when the parsing of the Magnatuin xml file is completed.
+     * Slot called when the parsing of the Magnatune xml file is completed.
      * Triggers an update of the list view and the genre combo box
      */
     void doneParsing();
@@ -145,7 +144,7 @@ private slots:
     void processRedownload();
 
     /**
-     * Slot for recieving notifications of completed download operations
+     * Slot for receiving notifications of completed download operations
      * @param success Was the operation a success?
      */
     void downloadCompleted( bool success );
@@ -160,14 +159,13 @@ private slots:
 
      /**
      * Checks if download button should be enabled
-     * @param selection the new selection
-     * @param deseleted items that were previously selected but have been deselected
+     * @param selectedItem the new selected item
      */
     void itemSelected( CollectionTreeItem * selectedItem );
 
 
-    void moodMapReady( QMap<QString, int> map );
-    void moodyTracksReady( Meta::TrackList tracks );
+    void moodMapReady(const QMap<QString, int> &map );
+    void moodyTracksReady( const Meta::TrackList &tracks );
 
     void timestampDownloadComplete( KJob * job );
     void favoritesResult( KJob* addToFavoritesJob );
@@ -211,7 +209,7 @@ private:
 
     QAction * m_updateAction;
 
-    bool         m_downloadInProgress;
+    bool m_downloadInProgress;
 
     Meta::MagnatuneAlbum * m_currentAlbum;
 
