@@ -16,11 +16,14 @@
 
 #include "Mp3tunesLocker.h"
 
-#include "Debug.h"
+#include "core/support/Debug.h"
 
 #include <QByteArray>
+#include <QStringList>
+
 #include <memory>
 
+
 Mp3tunesLocker::Mp3tunesLocker ( const QString & partnerToken )
 {
     DEBUG_BLOCK
@@ -335,7 +338,7 @@ Mp3tunesLocker::tracksWithArtistId ( int artistId ) const
 }
 
 QList<Mp3tunesLockerTrack>
-Mp3tunesLocker::tracksWithFileKeys( QStringList filekeys ) const
+Mp3tunesLocker::tracksWithFileKeys( const QStringList &filekeys ) const
 {
     QString keys;
     foreach( const QString &key, filekeys )
