@@ -41,7 +41,7 @@ struct ScriptableServiceQueryMaker::Private {
     QString lastFilter;
 };
 
-ScriptableServiceQueryMaker::ScriptableServiceQueryMaker( ScriptableServiceCollection * collection, QString name )
+ScriptableServiceQueryMaker::ScriptableServiceQueryMaker( ScriptableServiceCollection * collection, const QString &name )
     : DynamicServiceQueryMaker()
     , d( new Private )
     , m_convertToMultiTracks( false )
@@ -50,7 +50,8 @@ ScriptableServiceQueryMaker::ScriptableServiceQueryMaker( ScriptableServiceColle
     m_collection = collection;
     m_name = name;
 
-    connect( collection, SIGNAL(updateComplete()), this, SLOT(slotScriptComplete()) );
+    connect( collection, &Collections::ScriptableServiceCollection::updateComplete,
+             this, &ScriptableServiceQueryMaker::slotScriptComplete );
 
     d->type = Private::NONE;
     d->closestParent = Private::NONE;
@@ -75,7 +76,7 @@ void ScriptableServiceQueryMaker::run()
         return;
 
     if ( d->callbackString.isEmpty() )
-        d->callbackString = "none";
+        d->callbackString = QStringLiteral("none");
 
 
     if ( d->type == Private::GENRE ) {
@@ -83,7 +84,7 @@ void ScriptableServiceQueryMaker::run()
         {
             m_collection->clear();
         }
-        QTimer::singleShot( 0, this, SLOT(fetchGenre()) );
+        QTimer::singleShot( 0, this, &ScriptableServiceQueryMaker::fetchGenre );
     }
     else if ( d->type == Private::ARTIST )
     {
@@ -91,7 +92,7 @@ void ScriptableServiceQueryMaker::run()
         {
             m_collection->clear();
         }
-        QTimer::singleShot( 0, this, SLOT(fetchArtists()) );
+        QTimer::singleShot( 0, this, &ScriptableServiceQueryMaker::fetchArtists );
     }
     else if ( d->type == Private::ALBUM )
     {
@@ -99,7 +100,7 @@ void ScriptableServiceQueryMaker::run()
         {
             m_collection->clear();
         }
-        QTimer::singleShot( 0, this, SLOT(fetchAlbums()) );
+        QTimer::singleShot( 0, this, &ScriptableServiceQueryMaker::fetchAlbums );
     }
     else if ( d->type == Private::TRACK )
     {
@@ -107,7 +108,7 @@ void ScriptableServiceQueryMaker::run()
         {
             m_collection->clear();
         }
-        QTimer::singleShot( 0, this, SLOT(fetchTracks()) );
+        QTimer::singleShot( 0, this, &ScriptableServiceQueryMaker::fetchTracks );
     }
 
 }
@@ -195,25 +196,25 @@ ScriptableServiceQueryMaker::setConvertToMultiTracks( bool convert )
 void ScriptableServiceQueryMaker::handleResult( const Meta::GenreList & genres )
 {
     if ( d->maxsize >= 0 && genres.count() > d->maxsize )
-        emit newResultReady( genres.mid( 0, d->maxsize ) );
+        Q_EMIT newGenresReady( genres.mid( 0, d->maxsize ) );
     else
-        emit newResultReady( genres );
+        Q_EMIT newGenresReady( genres );
 }
 
 void ScriptableServiceQueryMaker::handleResult( const Meta::AlbumList & albums )
 {
     if ( d->maxsize >= 0 && albums.count() > d->maxsize )
-        emit newResultReady( albums.mid( 0, d->maxsize ) );
+        Q_EMIT newAlbumsReady( albums.mid( 0, d->maxsize ) );
     else
-        emit newResultReady( albums );
+        Q_EMIT newAlbumsReady( albums );
 }
 
 void ScriptableServiceQueryMaker::handleResult( const Meta::ArtistList & artists )
 {
     if ( d->maxsize >= 0 && artists.count() > d->maxsize )
-        emit newResultReady( artists.mid( 0, d->maxsize ) );
+        Q_EMIT newArtistsReady( artists.mid( 0, d->maxsize ) );
     else
-        emit newResultReady( artists );
+        Q_EMIT newArtistsReady( artists );
 }
 
 void ScriptableServiceQueryMaker::handleResult( const Meta::TrackList &tracks )
@@ -238,9 +239,9 @@ void ScriptableServiceQueryMaker::handleResult( const Meta::TrackList &tracks )
         ret = tracks;
 
     if ( d->maxsize >= 0 && ret.count() > d->maxsize )
-        emit newResultReady( ret.mid( 0, d->maxsize ) );
+        Q_EMIT newTracksReady( ret.mid( 0, d->maxsize ) );
     else
-        emit newResultReady( ret );
+        Q_EMIT newTracksReady( ret );
 }
 
 void ScriptableServiceQueryMaker::fetchGenre()
@@ -251,7 +252,7 @@ void ScriptableServiceQueryMaker::fetchGenre()
     if ( genre.count() > 0 )
     {
         handleResult( genre );
-        emit( queryDone() );
+        Q_EMIT( queryDone() );
     }
     else
         //this is where we call the script to get it to add more stuff!
@@ -283,7 +284,7 @@ void ScriptableServiceQueryMaker::fetchArtists()
     if ( artists.count() > 0 )
     {
         handleResult( artists );
-        emit( queryDone() );
+        Q_EMIT( queryDone() );
     }
     else
         //this is where we call the script to get it to add more stuff!
@@ -309,7 +310,7 @@ void ScriptableServiceQueryMaker::fetchAlbums()
     if ( albums.count() > 0 )
     {
         handleResult( albums );
-        emit( queryDone() );
+        Q_EMIT( queryDone() );
     }
     else
         //this is where we call the script to get it to add more stuff!
@@ -335,7 +336,7 @@ void ScriptableServiceQueryMaker::fetchTracks()
 
     if ( tracks.count() > 0 ) {
         handleResult( tracks );
-        emit( queryDone() );
+        Q_EMIT( queryDone() );
     }
     else
         //this is where we call the script to get it to add more stuff!
@@ -409,7 +410,7 @@ void ScriptableServiceQueryMaker::slotScriptComplete()
         debug() << "there are " << tracks.count() << " tracks";
         handleResult( tracks );
     }
-    emit( queryDone() );
+    Q_EMIT( queryDone() );
 }
 
 QueryMaker * ScriptableServiceQueryMaker::setAlbumQueryMode( AlbumQueryMode mode )
@@ -429,7 +430,7 @@ QueryMaker * ScriptableServiceQueryMaker::addFilter( qint64 value, const QString
     {
         //I am sure there is a really good reason to add this space, as nothing works if it is removed, but WHY?!?
         d->filter += filter + ' ';
-        d->filter = d->filter.replace( ' ', "%20" );
+        d->filter = d->filter.replace( ' ', QLatin1String("%20") );
     }
 
     int level = 0;
@@ -459,4 +460,3 @@ QueryMaker * ScriptableServiceQueryMaker::addFilter( qint64 value, const QString
 
 }
 
-#include "ScriptableServiceQueryMaker.moc"
