@@ -21,6 +21,8 @@
 #include "MetaValues.h"
 #include "core/meta/Meta.h"
 
+#include <algorithm>
+
 using namespace StatSyncing;
 
 #undef VERBOSE_DEBUG
@@ -187,7 +189,7 @@ MatchTracksJob::matchTracksFromArtist( const QMultiMap<ProviderPtr, QString> &pr
         if( trackList.isEmpty() )
             continue;  // don't add empty lists to providerTracks
         // the sorting is important and makes our matching algorithm work
-        qSort( trackList.begin(), trackList.end(), trackDelegatePtrLessThan<MatchTracksJob> );
+        std::sort( trackList.begin(), trackList.end(), trackDelegatePtrLessThan<MatchTracksJob> );
 
         scanForScrobblableTracks( trackList );
         providerTracks[ provider ] = trackList;
