@@ -29,14 +29,14 @@ class EditDeleteComboBoxView : public QListView
     Q_OBJECT
 
     public:
-        EditDeleteComboBoxView( QWidget* parent = 0 );
+        explicit EditDeleteComboBoxView( QWidget* parent = nullptr );
 
-    signals:
+    Q_SIGNALS:
         void editItem( const QString &itemName );
         void deleteItem( const QString &itemName );
 
     protected:
-        virtual void mousePressEvent( QMouseEvent* );
+        void mousePressEvent( QMouseEvent* ) override;
 };
 
 #endif
