@@ -24,8 +24,6 @@
 #include <QSlider>
 #include <QVector>
 
-class QPalette;
-class QTimer;
 class BookmarkTriangle;
 
 
@@ -36,24 +34,24 @@ namespace Amarok
         Q_OBJECT
 
         public:
-            explicit Slider( Qt::Orientation, uint max = 0, QWidget* parent = 0 );
+            explicit Slider( Qt::Orientation, uint max = 0, QWidget* parent = nullptr );
 
             virtual void setValue( int );
 
-        signals:
-            //we emit this when the user has specifically changed the slider
+        Q_SIGNALS:
+            //we Q_EMIT this when the user has specifically changed the slider
             //so connect to it if valueChanged() is too generic
             //Qt also emits valueChanged( int )
             void sliderReleased( int );
 
         protected:
-            virtual void wheelEvent( QWheelEvent* );
-            virtual void mouseMoveEvent( QMouseEvent* );
-            virtual void mouseReleaseEvent( QMouseEvent* );
-            virtual void mousePressEvent( QMouseEvent* );
+            void wheelEvent( QWheelEvent* ) override;
+            void mouseMoveEvent( QMouseEvent* ) override;
+            void mouseReleaseEvent( QMouseEvent* ) override;
+            void mousePressEvent( QMouseEvent* ) override;
             virtual void slideEvent( QMouseEvent* );
             QRect sliderHandleRect( const QRect &slider, qreal percent ) const;
-            virtual void resizeEvent( QResizeEvent * ) { m_needsResize = true; }
+            void resizeEvent( QResizeEvent * ) override { m_needsResize = true; }
 
             void paintCustomSlider( QPainter *p, bool paintMoodbar = false );
 
@@ -92,12 +90,12 @@ namespace Amarok
             explicit VolumeSlider( uint max, QWidget *parent, bool customStyle = true );
 
             // VolumePopupButton needs to access this
-            virtual void wheelEvent( QWheelEvent *e );
+            void wheelEvent( QWheelEvent *e ) override;
 
         protected:
-            virtual void paintEvent( QPaintEvent* );
-            virtual void mousePressEvent( QMouseEvent* );
-            virtual void contextMenuEvent( QContextMenuEvent* );
+            void paintEvent( QPaintEvent* ) override;
+            void mousePressEvent( QMouseEvent* ) override;
+            void contextMenuEvent( QContextMenuEvent* ) override;
 
         private:
             Q_DISABLE_COPY( VolumeSlider )
@@ -108,20 +106,20 @@ namespace Amarok
         Q_OBJECT
 
         public:
-            TimeSlider( QWidget *parent );
+            explicit TimeSlider( QWidget *parent );
 
             void setSliderValue( int value );
             void drawTriangle( const QString &name, int milliSeconds, bool showPopup = false);
             void clearTriangles();
 
         protected:
-            virtual void paintEvent( QPaintEvent* );
-            virtual void mousePressEvent( QMouseEvent* );
-            virtual void resizeEvent( QResizeEvent * event );
-            virtual void sliderChange( SliderChange change );
-            virtual bool event( QEvent * event );
+            void paintEvent( QPaintEvent* ) override;
+            void mousePressEvent( QMouseEvent* ) override;
+            void resizeEvent( QResizeEvent * event ) override;
+            void sliderChange( SliderChange change ) override;
+            bool event( QEvent * event ) override;
 
-        private slots:
+        private Q_SLOTS:
             void slotTriangleClicked( int );
             void slotTriangleFocused( int );
 
