@@ -22,6 +22,8 @@
 #include "config-amarok-test.h"
 #include "amarokconfig.h"
 
+#include <KLocalizedString>
+
 #include <QTemporaryDir>
 
 #include <QTest>
@@ -34,8 +36,10 @@
 QTEST_GUILESS_MAIN( TestMetaFileTrack )
 
 TestMetaFileTrack::TestMetaFileTrack()
-    : m_tmpDir( 0 )
-{}
+    : m_tmpDir( nullptr )
+{
+    KLocalizedString::setApplicationDomain("amarok-test");
+}
 
 void TestMetaFileTrack::initTestCase()
 {
@@ -152,7 +156,7 @@ void TestMetaFileTrack::testIsEditable()
 
     QFile testFile( m_tmpFileName );
 
-    QVERIFY( testFile.setPermissions( 0x0000 ) );
+    QVERIFY( testFile.setPermissions( {} ) );
     /* When the tests are run as root under Linux, the file is accessible even when it
      * has no permission bits set. Just skip one verify in this case in order not to
      * break whole test. */
@@ -374,7 +378,7 @@ void TestMetaFileTrack::testSetGetDiscNumber()
 
 void TestMetaFileTrack::testLength()
 {
-    QCOMPARE( m_track->length(), 12000LL );
+    QCOMPARE( m_track->length(), 12095LL );
 }
 
 void TestMetaFileTrack::testFilesize()
@@ -449,7 +453,7 @@ void TestMetaFileTrack::testType()
 void TestMetaFileTrack::testCreateDate()
 {
     QFileInfo fi( m_tmpFileName );
-    QDateTime created = fi.created();
+    QDateTime created = fi.birthTime();
     // m_track->createDate() is rounded to full second because it is created from full seconds
     // created therefore also needs to be rounded
     QCOMPARE( m_track->createDate().toSecsSinceEpoch(), created.toSecsSinceEpoch() );
