@@ -24,6 +24,8 @@
 #include "core/support/Amarok.h"
 #include "core/support/Debug.h"
 
+#include <KLocalizedString>
+
 #include <QByteArray>
 #include <QDataStream>
 #include <QMimeData>
@@ -33,7 +35,7 @@
 
 Q_DECLARE_METATYPE(QModelIndex);
 
-QTemporaryDir *s_tmpDir = 0;   // Memory leak here now, but if it's deleted, we have a segfault
+QTemporaryDir *s_tmpDir = nullptr;   // Memory leak here now, but if it's deleted, we have a segfault
 
 // We return a special saveLocation.
 QString Amarok::saveLocation( const QString &directory )
@@ -51,6 +53,7 @@ TestDynamicModel::TestDynamicModel()
 void
 TestDynamicModel::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     AmarokConfig::instance("amarokrc");
 
     s_tmpDir = new QTemporaryDir();
@@ -352,6 +355,6 @@ TestDynamicModel::testRemoveActive()
     model->removeAt( model->index( model->activePlaylist() ) );
 
     QCOMPARE( model->rowCount(), 0 );
-    QCOMPARE( model->activePlaylist(), static_cast<Dynamic::DynamicPlaylist*>(0) );
+    QCOMPARE( model->activePlaylist(), static_cast<Dynamic::DynamicPlaylist*>(nullptr) );
 }
 
