@@ -22,6 +22,7 @@
 
 #include <QTest>
 
+#include <KLocalizedString>
 
 QTEST_MAIN( TestBansheeImporter )
 
@@ -32,9 +33,9 @@ TestBansheeImporter::getProvider()
 {
     QVariantMap cfg = BansheeConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", QApplication::applicationDirPath()
-                          + "/importers_files/banshee.db" );
+                          + "/../tests/importers_files/banshee.db" );
 
-    return ProviderPtr( new BansheeProvider( cfg, 0 ) );
+    return ProviderPtr( new BansheeProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
@@ -45,12 +46,12 @@ TestBansheeImporter::getWritableProvider()
 
     const QString dst = base.filePath( "importers_tmp/banshee.db" );
     QFile( dst ).remove();
-    QFile( base.filePath( "importers_files/banshee.db" ) ).copy( dst );
+    QFile( base.filePath( "../tests/importers_files/banshee.db" ) ).copy( dst );
 
     QVariantMap cfg = BansheeConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", dst );
 
-    return ProviderPtr( new BansheeProvider( cfg, 0 ) );
+    return ProviderPtr( new BansheeProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -68,6 +69,7 @@ TestBansheeImporter::hasOddRatings() const
 void
 TestBansheeImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = BansheeConfigWidget( QVariantMap() ).config();
 }
 
@@ -76,7 +78,7 @@ TestBansheeImporter::providerShouldHandleNonexistentDbFile()
 {
     m_cfg.insert( "dbPath", "/wdawd\\wdadwgd/das4hutyf" );
 
-    BansheeProvider provider( m_cfg, 0 );
+    BansheeProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -85,7 +87,7 @@ TestBansheeImporter::providerShouldHandleInvalidDbFile()
 {
     m_cfg.insert( "dbPath", QApplication::applicationFilePath() );
 
-    BansheeProvider provider( m_cfg, 0 );
+    BansheeProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -95,7 +97,7 @@ TestBansheeImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbPath", "\\wd%aw@d/sdsd2'vodk0-=$$" );
     m_cfg.insert( "name", QColor( Qt::white ) );
 
-    BansheeProvider provider( m_cfg, 0 );
+    BansheeProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
