@@ -20,6 +20,8 @@
 #include "importers/clementine/ClementineConfigWidget.h"
 #include "importers/clementine/ClementineProvider.h"
 
+#include <KLocalizedString>
+
 #include <QTest>
 
 
@@ -32,9 +34,9 @@ TestClementineImporter::getProvider()
 {
     QVariantMap cfg = ClementineConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", QApplication::applicationDirPath()
-                          + "/importers_files/clementine.db" );
+                          + "/../tests/importers_files/clementine.db" );
 
-    return ProviderPtr( new ClementineProvider( cfg, 0 ) );
+    return ProviderPtr( new ClementineProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
@@ -45,12 +47,12 @@ TestClementineImporter::getWritableProvider()
 
     const QString dst = base.filePath( "importers_tmp/clementine.db" );
     QFile( dst ).remove();
-    QFile( base.filePath( "importers_files/clementine.db" ) ).copy( dst );
+    QFile( base.filePath( "../tests/importers_files/clementine.db" ) ).copy( dst );
 
     QVariantMap cfg = ClementineConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", dst );
 
-    return ProviderPtr( new ClementineProvider( cfg, 0 ) );
+    return ProviderPtr( new ClementineProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -62,6 +64,7 @@ TestClementineImporter::reliableStatistics() const
 void
 TestClementineImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = ClementineConfigWidget( QVariantMap() ).config();
 }
 
@@ -70,7 +73,7 @@ TestClementineImporter::providerShouldHandleNonexistentDbFile()
 {
     m_cfg.insert( "dbPath", "/wdawd\\wdadwgd/das4hutyf" );
 
-    ClementineProvider provider( m_cfg, 0 );
+    ClementineProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -79,7 +82,7 @@ TestClementineImporter::providerShouldHandleInvalidDbFile()
 {
     m_cfg.insert( "dbPath", QApplication::applicationFilePath() );
 
-    ClementineProvider provider( m_cfg, 0 );
+    ClementineProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -89,6 +92,6 @@ TestClementineImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbPath", "\\wd%aw@d/sdsd2'vodk0-=$$" );
     m_cfg.insert( "name", QColor( Qt::white ) );
 
-    ClementineProvider provider( m_cfg, 0 );
+    ClementineProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
