@@ -20,6 +20,8 @@
 #include "importers/itunes/ITunesConfigWidget.h"
 #include "importers/itunes/ITunesProvider.h"
 
+#include <KLocalizedString>
+
 #include <QTest>
 
 
@@ -32,9 +34,9 @@ TestITunesImporter::getProvider()
 {
     QVariantMap cfg = ITunesConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", QApplication::applicationDirPath()
-                          + "/importers_files/iTunes_Music_Library.xml" );
+                          + "/../tests/importers_files/iTunes_Music_Library.xml" );
 
-    return ProviderPtr( new ITunesProvider( cfg, 0 ) );
+    return ProviderPtr( new ITunesProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
@@ -45,12 +47,12 @@ TestITunesImporter::getWritableProvider()
 
     const QString dst = base.filePath( "importers_tmp/iTunes_Music_Library.xml" );
     QFile( dst ).remove();
-    QFile( base.filePath( "importers_files/iTunes_Music_Library.xml" ) ).copy( dst );
+    QFile( base.filePath( "../tests/importers_files/iTunes_Music_Library.xml" ) ).copy( dst );
 
     QVariantMap cfg = ITunesConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", dst);
 
-    return ProviderPtr( new ITunesProvider( cfg, 0 ) );
+    return ProviderPtr( new ITunesProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -69,6 +71,7 @@ TestITunesImporter::hasOddRatings() const
 void
 TestITunesImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = ITunesConfigWidget( QVariantMap() ).config();
 }
 
@@ -77,7 +80,7 @@ TestITunesImporter::providerShouldHandleNonexistentDbFile()
 {
     m_cfg.insert( "dbPath", "/wdawd\\wdadwgd/das4hutyf" );
 
-    ITunesProvider provider( m_cfg, 0 );
+    ITunesProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -86,7 +89,7 @@ TestITunesImporter::providerShouldHandleInvalidDbFile()
 {
     m_cfg.insert( "dbPath", QApplication::applicationFilePath() );
 
-    ITunesProvider provider( m_cfg, 0 );
+    ITunesProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -96,7 +99,7 @@ TestITunesImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbPath", "\\wd%aw@d/sdsd2'vodk0-=$$" );
     m_cfg.insert( "name", QColor( Qt::white ) );
 
-    ITunesProvider provider( m_cfg, 0 );
+    ITunesProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -106,6 +109,6 @@ TestITunesImporter::providerShouldHandleIllFormedDbFile()
     m_cfg.insert( "dbPath", QApplication::applicationDirPath()
                   + "/importers_files/illFormedLibrary.xml" );
 
-    ITunesProvider provider( m_cfg, 0 );
+    ITunesProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artistTracks( "NonSuch" ).empty() );
 }
