@@ -20,8 +20,9 @@
 #include "importers/rhythmbox/RhythmboxConfigWidget.h"
 #include "importers/rhythmbox/RhythmboxProvider.h"
 
-#include <QTest>
+#include <KLocalizedString>
 
+#include <QTest>
 
 QTEST_MAIN( TestRhythmboxImporter )
 
@@ -32,9 +33,9 @@ TestRhythmboxImporter::getProvider()
 {
     QVariantMap cfg = RhythmboxConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", QApplication::applicationDirPath()
-                          + "/importers_files/rhythmdb.xml" );
+                          + "/../tests/importers_files/rhythmdb.xml" );
 
-    return ProviderPtr( new RhythmboxProvider( cfg, 0 ) );
+    return ProviderPtr( new RhythmboxProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
@@ -45,12 +46,12 @@ TestRhythmboxImporter::getWritableProvider()
 
     const QString dst = base.filePath( "importers_tmp/rhythmdb.xml" );
     QFile( dst ).remove();
-    QFile( base.filePath( "importers_files/rhythmdb.xml" ) ).copy( dst );
+    QFile( base.filePath( "../tests/importers_files/rhythmdb.xml" ) ).copy( dst );
 
     QVariantMap cfg = RhythmboxConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbPath", dst );
 
-    return ProviderPtr( new RhythmboxProvider( cfg, 0 ) );
+    return ProviderPtr( new RhythmboxProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -68,6 +69,7 @@ TestRhythmboxImporter::hasOddRatings() const
 void
 TestRhythmboxImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = RhythmboxConfigWidget( QVariantMap() ).config();
 }
 
@@ -76,7 +78,7 @@ TestRhythmboxImporter::providerShouldHandleNonexistentDbFile()
 {
     m_cfg.insert( "dbPath", "/wdawd\\wdadwgd/das4hutyf" );
 
-    RhythmboxProvider provider( m_cfg, 0 );
+    RhythmboxProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -85,7 +87,7 @@ TestRhythmboxImporter::providerShouldHandleInvalidDbFile()
 {
     m_cfg.insert( "dbPath", QApplication::applicationFilePath() );
 
-    RhythmboxProvider provider( m_cfg, 0 );
+    RhythmboxProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -95,7 +97,7 @@ TestRhythmboxImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbPath", "\\wd%aw@d/sdsd2'vodk0-=$$" );
     m_cfg.insert( "name", QColor( Qt::white ) );
 
-    RhythmboxProvider provider( m_cfg, 0 );
+    RhythmboxProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -105,6 +107,6 @@ TestRhythmboxImporter::providerShouldHandleIllFormedDbFile()
     m_cfg.insert( "dbPath", QApplication::applicationDirPath()
                   + "/importers_files/illFormedLibrary.xml" );
 
-    RhythmboxProvider provider( m_cfg, 0 );
+    RhythmboxProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artistTracks( "NonSuch" ).empty() );
 }
